<?php
if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * Template Core Functions
 *
 * Template Core Functions specifically created for car listings
 *
 * @author 		Alex Gurghis
 * @category 	Core
 * @package 	casaroyal/Core Functions
 * @version     1.0.2
 */

/**
 * Get and include template files.
 *
 * @param mixed $template_name
 * @param array $args (default: array())
 * @param string $template_path (default: '')
 * @param string $default_path (default: '')
 * @return void
 */

/**
 * casaroyal_Admin_Setup_Wizard class.
 */
class casaroyal_Admin_Setup_Wizard {

	/** @var string Currenct Step */
	private $step   = '';

	/** @var array Steps for the setup wizard */
	private $steps  = array();

	/**
	 * Hook in tabs.
	 */
	public function __construct() {
		add_action( 'admin_menu', array( $this, 'admin_menus' ) );
		add_action( 'admin_init', array( $this, 'setup_wizard' ) );
	}

	/**
	 * Add admin menus/screens.
	 */
	public function admin_menus() {
		add_dashboard_page( '', '', 'manage_options', 'casaroyal-setup', '' );
	}

	/**
	 * Show the setup wizard.
	 */
	public function setup_wizard() {
		if ( empty( $_GET['page'] ) || 'casaroyal-setup' !== $_GET['page'] ) {
			return;
		}
		$default_steps = array(
			'introduction' => array(
				'name'    => __( 'Introduction', 'casaroyal' ),
				'view'    => array( $this, 'casaroyal_setup_introduction' ),
				'handler' => '',
			),
			'pages' => array(
				'name'    => __( 'Setup Pages', 'casaroyal' ),
				'view'    => array( $this, 'casaroyal_setup_pages' ),
				'handler' => array( $this, 'casaroyal_setup_pages_save' ),
			),
			'monetization' => array(
				'name'    => __( 'Monetization', 'casaroyal' ),
				'view'    => array( $this, 'casaroyal_monetization' ),
				'handler' => array( $this, 'casaroyal_monetization_save' ),
			),
			'miscellaneous' => array(
				'name'    => __( 'Miscellaneous', 'casaroyal' ),
				'view'    => array( $this, 'casaroyal_miscellaneous' ),
				'handler' => array( $this, 'casaroyal_miscellaneous_save' ),
			),
			'demo' => array(
				'name'    => __( 'Import Demo', 'casaroyal' ),
				'view'    => array( $this, 'casaroyal_demo' ),
				'handler' => array( $this, 'casaroyal_demo_save' ),
			),
			'next_steps' => array(
				'name'    => __( 'All Done!', 'casaroyal' ),
				'view'    => array( $this, 'casaroyal_setup_ready' ),
				'handler' => '',
			),
		);

		$this->steps = apply_filters( 'casaroyal_setup_wizard_steps', $default_steps );
		$this->step = isset( $_GET['step'] ) ? sanitize_key( $_GET['step'] ) : current( array_keys( $this->steps ) );

		wp_register_script( 'jquery-blockui', casaroyal_PLUGIN_URL . '/setup-wizard/assets/js/jquery.blockUI.min.js', array( 'jquery' ), '2.70', true );
		wp_register_script( 'select2', casaroyal_PLUGIN_URL . '/setup-wizard/assets/js/select2.min.js', array( 'jquery' ), '4.0.3' );
		wp_register_script( 'wc-enhanced-select', casaroyal_PLUGIN_URL . '/setup-wizard/assets/js/enhanced-select.min.js', array( 'jquery', 'select2' ) );
		wp_localize_script( 'wc-enhanced-select', 'casaroyal_enhanced_select_params', array(
			'i18n_no_matches'           => _x( 'No matches found', 'enhanced select', 'casaroyal' ),
			'i18n_ajax_error'           => _x( 'Loading failed', 'enhanced select', 'casaroyal' ),
			'i18n_input_too_short_1'    => _x( 'Please enter 1 or more characters', 'enhanced select', 'casaroyal' ),
			'i18n_input_too_short_n'    => _x( 'Please enter %qty% or more characters', 'enhanced select', 'casaroyal' ),
			'i18n_input_too_long_1'     => _x( 'Please delete 1 character', 'enhanced select', 'casaroyal' ),
			'i18n_input_too_long_n'     => _x( 'Please delete %qty% characters', 'enhanced select', 'casaroyal' ),
			'i18n_selection_too_long_1' => _x( 'You can only select 1 item', 'enhanced select', 'casaroyal' ),
			'i18n_selection_too_long_n' => _x( 'You can only select %qty% items', 'enhanced select', 'casaroyal' ),
			'i18n_load_more'            => _x( 'Loading more results&hellip;', 'enhanced select', 'casaroyal' ),
			'i18n_searching'            => _x( 'Searching&hellip;', 'enhanced select', 'casaroyal' ),
			'ajax_url'                  => admin_url( 'admin-ajax.php' ),
			'search_products_nonce'     => wp_create_nonce( 'search-products' ),
			'search_customers_nonce'    => wp_create_nonce( 'search-customers' ),
		) );
		wp_enqueue_style( 'casaroyal_admin_styles', casaroyal_PLUGIN_URL . '/setup-wizard/assets/css/setup-wizard.css', array() );
		wp_enqueue_style( 'casaroyal-setup', casaroyal_PLUGIN_URL . '/setup-wizard/assets/css/ft-setup.css', array( 'dashicons', 'install' ) );
		wp_enqueue_style( 'fontawesome',         casaroyal_PLUGIN_URL . '/setup-wizard/assets/css/font-awesome.min.css', array(), '4.5.0', 'all' );

		wp_register_script( 'casaroyal-setup', casaroyal_PLUGIN_URL . '/setup-wizard/assets/js/ft-setup.min.js', array( 'jquery', 'wc-enhanced-select', 'jquery-blockui' ) );
		wp_localize_script( 'casaroyal-setup', 'casaroyal_setup_params', array(
			'locale_info' => json_encode( include( casaroyal_PLUGIN_DIR . '/setup-wizard/i18n/locale-info.php' ) ),
		) );


		if ( ! empty( $_POST['save_step'] ) && isset( $this->steps[ $this->step ]['handler'] ) ) {
			call_user_func( $this->steps[ $this->step ]['handler'], $this );
		}

		ob_start();
		$this->setup_wizard_header();
		$this->setup_wizard_steps();
		$this->setup_wizard_content();
		$this->setup_wizard_footer();
		exit;
	}

	/**
	 * Get the URL for the next step's screen.
	 * @param string step   slug (default: current step)
	 * @return string       URL for next step if a next step exists.
	 *                      Admin URL if it's the last step.
	 *                      Empty string on failure.
	 * @since 3.0.0
	 */
	public function get_next_step_link( $step = '' ) {
		if ( ! $step ) {
			$step = $this->step;
		}

		$keys = array_keys( $this->steps );
		if ( end( $keys ) === $step ) {
			return admin_url();
		}

		$step_index = array_search( $step, $keys );
		if ( false === $step_index ) {
			return '';
		}

		return add_query_arg( 'step', $keys[ $step_index + 1 ] );
	}

	/**
	 * Setup Wizard Header.
	 */
	public function setup_wizard_header() {
		?>
		<!DOCTYPE html>
		<html <?php language_attributes(); ?>>
		<head>
			<meta name="viewport" content="width=device-width" />
			<meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
			<title><?php esc_html_e( 'casaroyal &rsaquo; Setup Wizard', 'casaroyal' ); ?></title>
			<?php wp_print_scripts( 'casaroyal-setup' ); ?>
			<?php do_action( 'admin_print_styles' ); ?>
			<?php do_action( 'admin_head' ); ?>
		</head>
		<body class="casaroyal-setup wp-core-ui">
			<h1 id="casaroyal-setup-wizard-logo">
				<a href="<?php echo esc_url( home_url( '/' ) );?>">
					<img src="<?php echo casaroyal_PLUGIN_URL; ?>/setup-wizard/assets/images/logo-setup-wizard-2.png" alt="casaroyal" />
				</a>
				<span><?php esc_html_e( 'Quick Setup Wizard', 'casaroyal' ); ?></span>
			</h1>
		<?php
	}

	/**
	 * Setup Wizard Footer.
	 */
	public function setup_wizard_footer() {
		// Nothing here
	}

	/**
	 * Output the steps.
	 */
	public function setup_wizard_steps() {
		$ouput_steps = $this->steps;
		array_shift( $ouput_steps );
		?>
		<ol class="casaroyal-setup-steps">
			<?php foreach ( $ouput_steps as $step_key => $step ) : ?>
				<li class="<?php
					if ( $step_key === $this->step ) {
						echo 'active';
					} elseif ( array_search( $this->step, array_keys( $this->steps ) ) > array_search( $step_key, array_keys( $this->steps ) ) ) {
						echo 'done';
					}
				?>"><?php echo esc_html( $step['name'] ); ?></li>
			<?php endforeach; ?>
		</ol>
		<?php
	}

	/**
	 * Output the content for the current step.
	 */
	public function setup_wizard_content() {
		echo '<div class="casaroyal-setup-content">';
		call_user_func( $this->steps[ $this->step ]['view'], $this );
		echo '</div>';
	}

	/**
	 * Introduction step.
	 */
	public function casaroyal_setup_introduction() {

		update_option( 'casaroyal_run_wizard', 'no' );

		?>
		<h1><?php esc_html_e( 'Overview!', 'casaroyal' ); ?></h1>
		<p><?php _e( 'This quick setup wizard will help you <strong>configure the basic settings</strong> and <strong>import demo content</strong> of the <strong>casaroyal WordPress Theme</strong>. It shouldn’t take more than 5 minutes and it’s optional, though recomendable.', 'casaroyal' ); ?></p>
		<p><?php _e( 'If you’re in a hurry now, don’t worry, just skip it and return to the WordPress Admin Dashboard. You can get back later.', 'casaroyal' ); ?></p>
		<p><?php esc_html_e( 'Thank you for choosing casaroyal WordPress Theme to power your real estate website or marketplace.', 'casaroyal' ); ?></p>
		<p class="casaroyal-setup-actions step">
			<a href="<?php echo esc_url( $this->get_next_step_link() ); ?>" class="button-primary button button-large button-next button-padding-right"><?php esc_html_e( 'Let’s do this!', 'casaroyal' ); ?><i class="fa fa-angle-right" aria-hidden="true"></i></a>
			<a href="<?php echo esc_url( admin_url() ); ?>" class="button button-clean align-left"><?php esc_html_e( 'Not now, I’ll do this later', 'casaroyal' ); ?></a>
		</p>
		<?php
	}

	/**
	 * Page setup.
	 */
	public function casaroyal_setup_pages() {
		?>
		<h1><?php esc_html_e( 'Page setup', 'casaroyal' ); ?></h1>
		<form method="post">
			<p><?php printf( __( 'Your website needs a few essential <a href="%s" target="_blank">pages</a>. The following will be created automatically ( if they do not already exist )', 'casaroyal' ), esc_url( admin_url( 'edit.php?post_type=page' ) ) ); ?></p>
			<table class="casaroyal-setup-pages" cellspacing="0">
				<thead>
					<tr>
						<th class="page-name"><?php esc_html_e( 'Page name', 'casaroyal' ); ?></th>
						<th class="page-description"><?php esc_html_e( 'Description', 'casaroyal' ); ?></th>
					</tr>
				</thead>
				<tbody>
					<tr>
						<td class="page-name"><?php echo _x( 'Properties Search Page', 'Page title', 'casaroyal' ); ?></td>
						<td><?php esc_html_e( 'This is properties search results page.', 'casaroyal' ); ?></td>
					</tr>
					<tr>
						<td class="page-name"><?php echo _x( 'Properties Compare Page', 'Page title', 'casaroyal' ); ?></td>
						<td><?php esc_html_e( 'This is properties compare page.', 'casaroyal' ); ?></td>
					</tr>
					<tr>
						<td class="page-name"><?php echo _x( 'Pending Review Page', 'Page title', 'casaroyal' ); ?></td>
						<td><?php esc_html_e( 'This is pending review page. Only seen by admins ( if anyone can submit properties )', 'casaroyal' ); ?></td>
					</tr>
					<tr>
						<td class="page-name"><?php echo _x( 'My Listings Page', 'Page title', 'casaroyal' ); ?></td>
						<td><?php esc_html_e( 'This is front-end my listings page.', 'casaroyal' ); ?></td>
					</tr>
					<tr>
						<td class="page-name"><?php echo _x( 'Submit Listing Page', 'Page title', 'casaroyal' ); ?></td>
						<td><?php esc_html_e( 'This is front-end submit/edit listing page.', 'casaroyal' ); ?></td>
					</tr>
					<tr>
						<td class="page-name"><?php echo _x( 'My Favorites Page', 'Page title', 'casaroyal' ); ?></td>
						<td><?php esc_html_e( "This page shows user's the favorites listings.", 'casaroyal' ); ?></td>
					</tr>
					<tr>
						<td class="page-name"><?php echo _x( 'Account Funds Page', 'Page title', 'casaroyal' ); ?></td>
						<td><?php esc_html_e( 'This is front-end account funds page. Suitable for marketplace website ( if monetization is enabled )', 'casaroyal' ); ?></td>
					</tr>
					<tr>
						<td class="page-name"><?php echo _x( 'Account Settings Page', 'Page title', 'casaroyal' ); ?></td>
						<td><?php esc_html_e( 'This is front-end account settings page.', 'casaroyal' ); ?></td>
					</tr>
					<tr>
						<td class="page-name"><?php echo _x( 'Notifications', 'Page title', 'casaroyal' ); ?></td>
						<td><?php esc_html_e( 'This is front-end notifications page.', 'casaroyal' ); ?></td>
					</tr>
					<tr>
						<td class="page-name"><?php echo _x( 'Notifications Subscribers', 'Page title', 'casaroyal' ); ?></td>
						<td><?php esc_html_e( 'This page is for admins only and it shows the list of subcsribers and the filter they subscribed to.', 'casaroyal' ); ?></td>
					</tr>
					<tr>
						<td class="page-name"><?php echo _x( 'My Active Advertised Listings', 'Page title', 'casaroyal' ); ?></td>
						<td><?php esc_html_e( 'This my active advertised listings page ( if monetization is enabled )', 'casaroyal' ); ?></td>
					</tr>
				</tbody>
			</table>

			<p><?php printf( __( 'Once created, these pages can be managed from your admin dashboard on the <a href="%1$s" target="_blank">Pages screen</a>. You can control which pages are shown on your website via <a href="%2$s" target="_blank">Appearance > Menus</a>.', 'casaroyal' ), esc_url( admin_url( 'edit.php?post_type=page' ) ), esc_url( admin_url( 'nav-menus.php' ) ) ); ?></p>

			<p class="casaroyal-setup-actions step">
				<input type="submit" class="button-primary button button-large button-next" value="<?php esc_attr_e( 'Continue', 'casaroyal' ); ?>" name="save_step" />
				<a href="<?php echo esc_url( $this->get_next_step_link() ); ?>" class="button button-large button-next"><?php esc_html_e( 'Skip this step', 'casaroyal' ); ?></a>
				<?php wp_nonce_field( 'casaroyal-setup' ); ?>
			</p>
		</form>
		<?php
	}

	/**
	 * Save Page Settings.
	 */
	public function casaroyal_setup_pages_save() {
		check_admin_referer( 'casaroyal-setup' );

		casaroyal_Import_Demo::create_pages();

		wp_redirect( esc_url_raw( $this->get_next_step_link() ) );
		exit;
	}

	/**
	 * Select website type step.
	 */
	public function casaroyal_monetization() {

		// Submit Fee
		$MODS = get_theme_mods();
		foreach(casaroyal_defaults() as $mod=>$def) {if(!isset($MODS[$mod])){$MODS[$mod]=$def;}}

		if(strlen($MODS['casaroyal_monetization_status'])>0) {
		    $casaroyal_monetization_status = $MODS['casaroyal_monetization_status'];
		} else {
			$casaroyal_monetization_status = '';
		}

		if(strlen($MODS['casaroyal_account_funds_min_topup'])>0) {
            $casaroyal_account_funds_min_topup = $MODS['casaroyal_account_funds_min_topup'];
        } else {
        	$casaroyal_account_funds_min_topup = '10';
        }

        if(strlen($MODS['casaroyal_account_funds_max_topup'])>0) {
            $casaroyal_account_funds_max_topup = $MODS['casaroyal_account_funds_max_topup'];
        } else {
        	$casaroyal_account_funds_max_topup = '100';
        }

        if(strlen($MODS['casaroyal_monetization_pending'])>0) {
		    $casaroyal_monetization_pending = $MODS['casaroyal_monetization_pending'];
		} else {
			$casaroyal_monetization_pending = '';
		}

		if(strlen($MODS['casaroyal_submit_listing_price'])>0) {
		    $casaroyal_submit_listing_price = $MODS['casaroyal_submit_listing_price'];
		} else {
			$casaroyal_submit_listing_price = '3';
		}

		if(strlen($MODS['casaroyal_promoted_listing_price'])>0) {
		    $casaroyal_promoted_listing_price = $MODS['casaroyal_promoted_listing_price'];
		} else {
			$casaroyal_promoted_listing_price = '1';
		}

		if(strlen($MODS['ft_featured_listing_price'])>0) {
		    $ft_featured_listing_price = $MODS['ft_featured_listing_price'];
		} else {
			$ft_featured_listing_price = '2';
		}

		?>
		<h1><?php esc_html_e( 'Monetization', 'casaroyal' ); ?></h1>
		<form method="post">
			<p><?php esc_html_e( 'Here you can setup casaroyal Theme. You can have it as a marketplace or a Real Estate Agency website.', 'casaroyal' ); ?></p>

			<div class="casaroyal-setup-full-width">

			  	<input id="_customize-input-casaroyal_monetization_status" type="checkbox" value="1" name="casaroyal_monetization_status" <?php if(!empty($casaroyal_monetization_status)) {?>checked="checked"<?php } ?>>
				<label for="_customize-input-casaroyal_monetization_status"><?php esc_html_e( 'Enable monetization', 'casaroyal' ); ?></label>

			</div>

			<div class="monetization-options-holder">

				<div class="casaroyal-setup-full-width">

					<label for="_customize-input-casaroyal_account_funds_min_topup" class="casaroyal-setup-full-widthno-margin"><?php esc_html_e( 'Minimum Top-up', 'casaroyal' ); ?></label>
					<input class="casaroyal-setup-full-widthno-margin" id="_customize-input-casaroyal_account_funds_min_topup" type="text" value="<?php echo esc_attr($casaroyal_account_funds_min_topup); ?>" name="casaroyal_account_funds_min_topup">
					<span id="_customize-description-casaroyal_account_funds_min_topup" class="description customize-control-description"><?php esc_html_e( 'Only digits. Setup currency in WooCommerce.', 'casaroyal' ); ?></span>

				</div>

				<div class="casaroyal-setup-full-width">

					<label for="_customize-input-casaroyal_account_funds_max_topup" class="casaroyal-setup-full-widthno-margin"><?php esc_html_e( 'Maximum Top-up', 'casaroyal' ); ?></label>
					<input class="casaroyal-setup-full-widthno-margin" id="_customize-input-casaroyal_account_funds_max_topup" type="text" value="<?php echo esc_attr($casaroyal_account_funds_max_topup); ?>" name="casaroyal_account_funds_max_topup">
					<span id="_customize-description-casaroyal_account_funds_max_topup" class="description customize-control-description"><?php esc_html_e( 'Only digits. Setup currency in WooCommerce.', 'casaroyal' ); ?></span>

				</div>

				<div class="casaroyal-setup-full-width">

				  	<input id="_customize-input-casaroyal_monetization_pending" type="checkbox" value="1" name="casaroyal_monetization_pending" <?php if(!empty($casaroyal_monetization_pending)) {?>checked="checked"<?php } ?>>
					<label for="_customize-input-casaroyal_monetization_pending"><?php esc_html_e( 'Admin Review.', 'casaroyal' ); ?></label>
					<span id="_customize-description-casaroyal_monetization_pending" class="description customize-control-description"><?php esc_html_e( 'Pending admin review on property submit.', 'casaroyal' ); ?></span>

				</div>

				<div class="casaroyal-setup-full-width">

					<label for="_customize-input-casaroyal_submit_listing_price" class="casaroyal-setup-full-widthno-margin"><?php esc_html_e( 'Submit listing fee', 'casaroyal' ); ?></label>
					<input class="casaroyal-setup-full-widthno-margin" id="_customize-input-casaroyal_submit_listing_price" type="text" value="<?php echo esc_attr($casaroyal_submit_listing_price); ?>" name="casaroyal_submit_listing_price">
					<span id="_customize-description-casaroyal_submit_listing_price" class="description customize-control-description"><?php esc_html_e( 'One time fee. Will be deducted from account funds. ( Only digits. Setup currency in WooCommerce )', 'casaroyal' ); ?></span>

				</div>

				<div class="casaroyal-setup-full-width">

					<label for="_customize-input-casaroyal_promoted_listing_price" class="casaroyal-setup-full-widthno-margin"><?php esc_html_e( 'Promoted listing price', 'casaroyal' ); ?></label>
					<input class="casaroyal-setup-full-widthno-margin" id="_customize-input-casaroyal_promoted_listing_price" type="text" value="<?php echo esc_attr($casaroyal_promoted_listing_price); ?>" name="casaroyal_promoted_listing_price">
					<span id="_customize-description-casaroyal_promoted_listing_price" class="description customize-control-description"><?php esc_html_e( 'Price per day. Will be deducted from account funds. Listing will be re-published every day and will appear among the first but after featured. ( Only digits. Setup currency in WooCommerce )', 'casaroyal' ); ?></span>

				</div>

				<div class="casaroyal-setup-full-width">

					<label for="_customize-input-ft_featured_listing_price" class="casaroyal-setup-full-widthno-margin"><?php esc_html_e( 'Featured listing price', 'casaroyal' ); ?></label>
					<input class="casaroyal-setup-full-widthno-margin" id="_customize-input-ft_featured_listing_price" type="text" value="<?php echo esc_attr($ft_featured_listing_price); ?>" name="ft_featured_listing_price">
					<span id="_customize-description-ft_featured_listing_price" class="description customize-control-description"><?php esc_html_e( 'Price per day. Will be deducted from account funds. Listing will appear first. ( Only digits. Setup currency in WooCommerce )', 'casaroyal' ); ?></span>

				</div>

			</div>

			<script>

				(function($){

  				'use strict';

					$(document).ready(function () {

						if ($('#_customize-input-casaroyal_monetization_status').is(':checked')) {
							jQuery( '.monetization-options-holder' ).addClass( "active" );
						} else {
							jQuery( '.monetization-options-holder' ).removeClass( "active" );
						}

						jQuery('#_customize-input-casaroyal_monetization_status').on('change', function(e){
							e.preventDefault();
							if ($('#_customize-input-casaroyal_monetization_status').is(':checked')) {
								jQuery( '.monetization-options-holder' ).addClass( "active" );
							} else {
								jQuery( '.monetization-options-holder' ).removeClass( "active" );
							}
						});

					});

				})(jQuery)

			</script>

			<p class="casaroyal-setup-actions step">
				<input type="submit" class="button-primary button button-large button-next" value="<?php esc_attr_e( 'Continue', 'casaroyal' ); ?>" name="save_step" />
				<a href="<?php echo esc_url( $this->get_next_step_link() ); ?>" class="button button-large button-next"><?php esc_html_e( 'Skip this step', 'casaroyal' ); ?></a>
				<?php wp_nonce_field( 'casaroyal-setup' ); ?>
			</p>
		</form>
		<?php
	}

	/**
	 * Save website type.
	 */
	public function casaroyal_monetization_save() {
		check_admin_referer( 'casaroyal-setup' );

		if( isset($_POST['casaroyal_monetization_status']) AND !empty($_POST['casaroyal_monetization_status']) ) {
			$casaroyal_monetization_status = sanitize_text_field( $_POST['casaroyal_monetization_status'] );
		} else {
			$casaroyal_monetization_status = "";
		}
		set_theme_mod('casaroyal_monetization_status', $casaroyal_monetization_status);

		$casaroyal_account_funds_min_topup = sanitize_text_field( $_POST['casaroyal_account_funds_min_topup'] );
		set_theme_mod('casaroyal_account_funds_min_topup', $casaroyal_account_funds_min_topup);

		$casaroyal_account_funds_max_topup = sanitize_text_field( $_POST['casaroyal_account_funds_max_topup'] );
		set_theme_mod('casaroyal_account_funds_max_topup', $casaroyal_account_funds_max_topup);

		if( isset($_POST['casaroyal_monetization_pending']) AND !empty($_POST['casaroyal_monetization_pending']) ) {
			$casaroyal_monetization_pending = sanitize_text_field( $_POST['casaroyal_monetization_pending'] );
		} else {
			$casaroyal_monetization_pending = "";
		}
		set_theme_mod('casaroyal_monetization_pending', $casaroyal_monetization_pending);

		$casaroyal_submit_listing_price = sanitize_text_field( $_POST['casaroyal_submit_listing_price'] );
		set_theme_mod('casaroyal_submit_listing_price', $casaroyal_submit_listing_price);

		$casaroyal_promoted_listing_price = sanitize_text_field( $_POST['casaroyal_promoted_listing_price'] );
		set_theme_mod('casaroyal_promoted_listing_price', $casaroyal_promoted_listing_price);

		$ft_featured_listing_price = sanitize_text_field( $_POST['ft_featured_listing_price'] );
		set_theme_mod('ft_featured_listing_price', $ft_featured_listing_price);

		wp_redirect( esc_url_raw( $this->get_next_step_link() ) );
		exit;
	}

	/**
	 * Locale settings.
	 */
	public function casaroyal_miscellaneous() {

		// Defaults
		// Submit Fee
		$MODS = get_theme_mods();
		foreach(casaroyal_defaults() as $mod=>$def) {if(!isset($MODS[$mod])){$MODS[$mod]=$def;}}

		if(isset($MODS['estate_submit_listing']) AND strlen($MODS['estate_submit_listing'])>0) {
            $estate_submit_listing = $MODS['estate_submit_listing'];
        } else {
        	$estate_submit_listing = 'anyone';
        }

		if( isset($MODS['number_of_properties']) AND strlen($MODS['number_of_properties'])>0) {
            $number_of_properties = $MODS['number_of_properties'];
        } else {
        	$number_of_properties = '6';
        }

        if( isset($MODS['estate_decimals']) AND strlen($MODS['estate_decimals'])>0) {
            $estate_decimals = $MODS['estate_decimals'];
        } else {
        	$estate_decimals = '0';
        }

        if(isset($MODS['estate_dec_point']) AND strlen($MODS['estate_dec_point'])>0) {
            $estate_dec_point = $MODS['estate_dec_point'];
        } else {
        	$estate_dec_point = '.';
        }

        if(isset($MODS['estate_thousands_sep']) AND strlen($MODS['estate_thousands_sep'])>0) {
            $estate_thousands_sep = $MODS['estate_thousands_sep'];
        } else {
        	$estate_thousands_sep = ',';
        }

        if(isset($MODS['estate_currency_position']) AND strlen($MODS['estate_currency_position'])>0) {
            $estate_currency_position = $MODS['estate_currency_position'];
        } else {
        	$estate_currency_position = 'before';
        }

        if(isset($MODS['color_version']) AND strlen($MODS['color_version'])>0) {
            $color_version = $MODS['color_version'];
        } else {
        	$color_version = 'default';
        }

        if( isset($MODS['casaroyal_ajax_loading_properties']) AND strlen($MODS['casaroyal_ajax_loading_properties'])>0 ) {
		    $casaroyal_ajax_loading_properties = $MODS['casaroyal_ajax_loading_properties'];
		} else {
			$casaroyal_ajax_loading_properties = '';
		}

		$casaroyal_google_maps_api_key = "";
		if(isset($MODS['casaroyal_google_maps_api_key']) AND strlen($MODS['casaroyal_google_maps_api_key'])>0) {
		    $casaroyal_google_maps_api_key = $MODS['casaroyal_google_maps_api_key'];
		}

		?>
		<h1><?php esc_html_e( 'Miscellaneous', 'casaroyal' ); ?></h1>
		<form method="post">

			<p><?php esc_html_e( 'Here you can setup the number of properties on page and other tweeks.', 'casaroyal' ); ?></p>

			<div class="casaroyal-setup-full-width">

				<label for="_customize-input-estate_submit_listing" class="casaroyal-setup-full-widthno-margin"><?php esc_html_e( 'Front-End Submit Listing', 'casaroyal' ); ?></label>
				<select id="_customize-input-estate_submit_listing" data-customize-setting-link="estate_submit_listing" name="estate_submit_listing">
					<option value="anyone" <?php if($estate_submit_listing == "anyone"){?>selected="selected"<?php } ?>><?php esc_html_e( 'Anyone', 'casaroyal' ); ?></option>
					<option value="admins" <?php if($estate_submit_listing == "after"){?>selected="selected"<?php } ?>><?php esc_html_e( 'Admins only', 'casaroyal' ); ?></option>
				</select>

			</div>

			<div class="casaroyal-setup-full-width">

				<label for="_customize-input-number_of_properties" class="casaroyal-setup-full-widthno-margin"><?php esc_html_e( 'Number of properties on page', 'casaroyal' ); ?></label>
				<input class="casaroyal-setup-full-widthno-margin" id="_customize-input-number_of_properties" type="text" value="<?php echo esc_attr($number_of_properties); ?>" name="number_of_properties">

			</div>

			<div class="casaroyal-setup-full-width">

				<label for="_customize-input-estate_decimals" class="casaroyal-setup-full-widthno-margin"><?php esc_html_e( 'Decimals', 'casaroyal' ); ?></label>
				<input class="casaroyal-setup-full-widthno-margin" id="_customize-input-estate_decimals" type="text" value="<?php echo esc_attr($estate_decimals); ?>" name="estate_decimals">

			</div>

			<div class="casaroyal-setup-full-width">

				<label for="_customize-input-estate_thousands_sep" class="casaroyal-setup-full-widthno-margin"><?php esc_html_e( 'Thousand separator', 'casaroyal' ); ?></label>
				<input class="casaroyal-setup-full-widthno-margin" id="_customize-input-estate_thousands_sep" type="text" value="<?php echo esc_attr($estate_thousands_sep); ?>" name="estate_thousands_sep">

			</div>

			<div class="casaroyal-setup-full-width">

				<label for="_customize-input-estate_currency_position" class="casaroyal-setup-full-widthno-margin"><?php esc_html_e( 'Currency Position', 'casaroyal' ); ?></label>
				<select id="_customize-input-estate_currency_position" data-customize-setting-link="estate_currency_position" name="estate_currency_position">
					<option value="before" <?php if($estate_currency_position == "before"){?>selected="selected"<?php } ?>><?php esc_html_e( 'Before', 'casaroyal' ); ?></option>
					<option value="after" <?php if($estate_currency_position == "after"){?>selected="selected"<?php } ?>><?php esc_html_e( 'After', 'casaroyal' ); ?></option>				
				</select>

			</div>

			<div class="casaroyal-setup-full-width">

				<label for="_customize-input-color_version" class="casaroyal-setup-full-widthno-margin"><?php esc_html_e( 'Night Mode', 'casaroyal' ); ?></label>
				<select id="_customize-input-color_version" data-customize-setting-link="color_version" name="color_version">
					<option value="default" <?php if($color_version == "default"){?>selected="selected"<?php } ?>><?php esc_html_e( 'Off', 'casaroyal' ); ?></option>
					<option value="dark" <?php if($color_version == "dark"){?>selected="selected"<?php } ?>><?php esc_html_e( 'On', 'casaroyal' ); ?></option>	
					<option value="auto" <?php if($color_version == "auto"){?>selected="selected"<?php } ?>><?php esc_html_e( 'Auto detection Day/Night', 'casaroyal' ); ?></option>				
				</select>

			</div>

			<div class="casaroyal-setup-full-width">

			  	<input id="_customize-input-casaroyal_ajax_loading_properties" type="checkbox" value="1" name="casaroyal_ajax_loading_properties" <?php if(!empty($casaroyal_ajax_loading_properties)) {?>checked="checked"<?php } ?>>
				<label for="_customize-input-casaroyal_ajax_loading_properties"><?php esc_html_e( 'Ajax Load More Properties', 'casaroyal' ); ?></label>

			</div>

			<div class="casaroyal-setup-full-width">

				<label for="_customize-input-casaroyal_google_maps_api_key" class="casaroyal-setup-full-widthno-margin"><?php esc_html_e( 'Google Maps API Key', 'casaroyal' ); ?></label>
				<input class="casaroyal-setup-full-widthno-margin" id="_customize-input-casaroyal_google_maps_api_key" type="text" value="<?php echo esc_attr($casaroyal_google_maps_api_key); ?>" name="casaroyal_google_maps_api_key">
				<span id="_customize-description-casaroyal_google_maps_api_key" class="description customize-control-description"><a href="https://developers.google.com/maps/documentation/javascript/get-api-key" target="_blank"><?php esc_html_e( 'Click here to get the key (New tab)', 'casaroyal' ); ?></a></span>

			</div>

			<p class="casaroyal-setup-actions step">
				<input type="submit" class="button-primary button button-large button-next" value="<?php esc_attr_e( 'Continue', 'casaroyal' ); ?>" name="save_step" />
				<a href="<?php echo esc_url( $this->get_next_step_link() ); ?>" class="button button-large button-next"><?php esc_html_e( 'Skip this step', 'casaroyal' ); ?></a>
				<?php wp_nonce_field( 'casaroyal-setup' ); ?>
			</p>

		</form>
		<?php
	}

	/**
	 * Save Locale Settings.
	 */
	public function casaroyal_miscellaneous_save() {
		check_admin_referer( 'casaroyal-setup' );

		$estate_submit_listing = sanitize_text_field( $_POST['estate_submit_listing'] );
		set_theme_mod('estate_submit_listing', $estate_submit_listing);

		$number_of_properties = sanitize_text_field( $_POST['number_of_properties'] );
		set_theme_mod('number_of_properties', $number_of_properties);

		$estate_decimals = sanitize_text_field( $_POST['estate_decimals'] );
		set_theme_mod('estate_decimals', $estate_decimals);

		$estate_thousands_sep = sanitize_text_field( $_POST['estate_thousands_sep'] );
		set_theme_mod('estate_thousands_sep', $estate_thousands_sep);

		$estate_currency_position = sanitize_text_field( $_POST['estate_currency_position'] );
		set_theme_mod('estate_currency_position', $estate_currency_position);

		$color_version = sanitize_text_field( $_POST['color_version'] );
		set_theme_mod('color_version', $color_version);

		if( isset($_POST['casaroyal_ajax_loading_properties']) AND !empty($_POST['casaroyal_ajax_loading_properties']) ) {
			$casaroyal_ajax_loading_properties = sanitize_text_field( $_POST['casaroyal_ajax_loading_properties'] );
		} else {
			$casaroyal_ajax_loading_properties = "";
		}
		set_theme_mod('casaroyal_ajax_loading_properties', $casaroyal_ajax_loading_properties);

		$casaroyal_google_maps_api_key = sanitize_text_field( $_POST['casaroyal_google_maps_api_key'] );
		set_theme_mod('casaroyal_google_maps_api_key', $casaroyal_google_maps_api_key);

		wp_redirect( esc_url_raw( $this->get_next_step_link() ) );
		exit;
	}

	/**
	 * Import Demo.
	 */
	public function casaroyal_demo() {

		// Defaults


		?>
		<h1><?php esc_html_e( 'Import Demo', 'casaroyal' ); ?></h1>
		<form method="post">

			<p><?php esc_html_e( 'For best results import demo on a clean wordpress instance.', 'casaroyal' ); ?></p>

			<div class="casaroyal-import-loading"><p><i class="fa fa-spinner fa-spin fa-3x fa-fw"></i> <?php esc_html_e( 'Importing demo, please wait.', 'casaroyal' ); ?></p></div>

			<p class="casaroyal-setup-actions step">
				<input type="submit" class="button-primary button button-large button-next casaroyal-import-demo-button" value="<?php esc_attr_e( 'Import Demo', 'casaroyal' ); ?>" name="save_step" />
				<a href="<?php echo esc_url( $this->get_next_step_link() ); ?>" class="button button-large button-next"><?php esc_html_e( 'Skip this step', 'casaroyal' ); ?></a>
				<?php wp_nonce_field( 'casaroyal-setup' ); ?>
			</p>

			<script>

				jQuery('.casaroyal-import-demo-button').click(function(e){
					console.log("ceva");
					jQuery(".casaroyal-import-loading").css("display", "inline-block");
				});

			</script>

		</form>
		<?php
	}

	/**
	 * Save Locale Settings.
	 */
	public function casaroyal_demo_save() {
		check_admin_referer( 'casaroyal-setup' );

		$menu = get_term_by( 'name', 'casaroyal Main Menu', 'nav_menu' );
		if( $menu ) {
			$menu_id = $menu->term_id;
			wp_delete_term( $menu_id, 'nav_menu' );
		}

		// Import Properties Images
		//casaroyal_Import_Demo::create_demo_properties_images();

		// Import Agents Images
		//casaroyal_Import_Demo::create_demo_agents_images();

		// Import Agents
		casaroyal_Import_Demo::create_demo_agents();

		// Import Testimonials
		casaroyal_Import_Demo::create_demo_testimonials();

		// Import Attachments
		//casaroyal_Import_Demo::create_demo_attachments();

		// Import Properties
		casaroyal_Import_Demo::create_demo_properties();

		// Import Posts
		casaroyal_Import_Demo::create_demo_posts();

		// Import Conact Form 7 Form
		casaroyal_Import_Demo::create_demo_contact_forms();

		// Import Pages
		casaroyal_Import_Demo::create_demo_pages();

		wp_redirect( esc_url_raw( $this->get_next_step_link() ) );
		exit;
	}

	/**
	 * Final step.
	 */
	public function casaroyal_setup_ready() {
		
		?>

		<h1><?php esc_html_e( 'Well Done!', 'casaroyal' ); ?></h1>

		<p><?php esc_html_e( 'Thank you for choosing casaroyal WordPress Theme.', 'casaroyal' ); ?></p>
		<p class="casaroyal-setup-actions step">
			<a href="<?php echo esc_url( admin_url( 'post-new.php?post_type=property' ) ); ?>" class="button-primary button button-large button-next button-padding-right"><?php esc_html_e( 'Submit your first property!', 'casaroyal' ); ?><i class="fa fa-angle-right" aria-hidden="true"></i></a>
			<a href="<?php echo esc_url( admin_url() ); ?>" class="button button-large button-next"><?php esc_html_e( 'Return to the WordPress Dashboard', 'casaroyal' ); ?></a>
		</p>
		<?php
	}
}

new casaroyal_Admin_Setup_Wizard();
