<?php

/**
 * The Shortcode
 */

/**
 * Shortcode attributes
 * @var $atts
 * @var $title
 * @var $images
 * @var $css
 * Shortcode class
 * @var $this WPBakeryShortCode_VC_gallery
 */

function casaroyal_map_shortcode_func( $atts ) {

	extract( shortcode_atts( array(
    	"lat" => "47.02552795015715",
        "lng" => "28.830285722137432",
    	"zoom" => 17,
    	'image' => '',
        "width" => "100",
        "width_type" => "%",
        "height" => "450",
        "height_type" => "px",
        "dragging_mobile" => "true",
        "dragging_desktop" => "true",
    	"css" => "",
   	), $atts ) );

	ob_start();

	$img_id = preg_replace( '/[^\d]/', '', $image );
	$link_image = wp_get_attachment_image_src( $img_id, 'large' );
	$img_src = $link_image[0];

	$class_to_filter = '';
	$class_to_filter .= vc_shortcode_custom_css_class( $css, ' ' );
	$css_class = $class_to_filter;

	$unique_id = uniqid();

	if($height != '')
    {
        $add_map_height = 'height: '. $height . $height_type.'; ';
    }

    if($width != '')
    {
        $add_map_width = 'width: '. $width . $width_type.'; ';

    }

    if(wp_is_mobile())
    {
        $dragging = $dragging_mobile;
    }
    else
    {
        $dragging = $dragging_desktop;
    }

    $get_directions_link = '//maps.google.com/maps?daddr=' . $lat . ',' . $lng;

   	?>

   	<div class="casaroyal-custom-maps">

	   	<a class="show-directions-map" href="<?php echo esc_url($get_directions_link); ?>" target="_blank"><?php esc_html_e( 'Get Directions', 'casaroyal' ); ?></a>

	   	<div id="main-map-<?php echo esc_attr($unique_id); ?>" class="<?php echo esc_attr($css_class); ?>" style="<?php echo esc_attr($add_map_height); echo ' '; echo esc_attr($add_map_width); ?>"></div>

	    <script type="text/javascript">
			var mapDiv,
				map,
				infobox;
			jQuery(document).ready(function($) {

				mapDiv = $("#main-map-<?php echo esc_attr($unique_id); ?>");
				mapDiv.height(<?php echo esc_attr($height); ?>).gmap3({
					map: {
						options: {
							"center": [<?php echo esc_attr($lat); ?>,<?php echo esc_attr($lng); ?>]
							,"zoom": <?php echo esc_attr($zoom); ?>
							,"mapTypeControl": true
							,"mapTypeId": google.maps.MapTypeId.ROADMAP
							,"scrollwheel": false
							,"panControl": true
							,"rotateControl": false
							,"scaleControl": true
							,"streetViewControl": true
							,"zoomControl": true
							,"draggable": <?php echo esc_attr($dragging); ?>
						}
					}
					,marker: {
						values: [

						{

							latLng: [<?php echo esc_attr($lat); ?>,<?php echo esc_attr($lng); ?>],
							options: {
								icon: "<?php echo esc_url($img_src); ?>",
								shadow: "<?php echo get_template_directory_uri() ?>/images/shadow.png",
							}
						}	
								
						],
						options:{
							draggable: false
						}
					}
				});

				map = mapDiv.gmap3("get");
			    infobox = new InfoBox({
			    	pixelOffset: new google.maps.Size(-50, -65),
			    	closeBoxURL: '',
			    	enableEventPropagation: true
			    });
			    mapDiv.delegate('.infoBox .close','click',function () {
			    	infobox.close();
			    });

			});
		</script>

	</div>

    <?php

    return ob_get_clean();

}
add_shortcode( 'casaroyal_map_shortcode', 'casaroyal_map_shortcode_func' );

vc_map( array(
  	'name' => esc_html__( 'Google Map', 'casaroyal' ),
	'base' => 'casaroyal_map_shortcode',
	'icon' => get_template_directory_uri().'/images/vc-icon.png',
	'category' => esc_html__( 'casaroyal', 'casaroyal' ),
	'description' => esc_html__( 'Custom casaroyal google map', 'casaroyal' ),
	'params' => array(
		array(
            "type" => "textfield",
            "class" => "",
            "heading" => esc_html__("Latitude", "casaroyal"),
            "param_name" => "lat",
            "admin_label" => false,
            "value" => "47.02552795015715",
            "group" => "Location"
        ),
        array(
            "type" => "textfield",
            "class" => "",
            "heading" => esc_html__("Longitude", "casaroyal"),
            "param_name" => "lng",
            "admin_label" => false,
            "value" => "28.830285722137432",
            "group" => "Location"
        ),
        array(
            "type" => "textfield",
            "class" => "",
            "heading" => esc_html__("Zoom", "casaroyal"),
            "param_name" => "zoom",
            "admin_label" => false,
            "value" => "17",
            "group" => "Styling",
            "description" => "Map zoom level"
        ),
        array(
			'type' => 'attach_image',
			'heading' => esc_html__( 'Map pin', 'casaroyal' ),
			'param_name' => 'image',
			'value' => '',
			'description' => esc_html__( 'Use .png file for best results', 'casaroyal' ),
		),
        array(
            "type" => "textfield",
            "class" => "",
            "heading" => esc_html__("Width", "casaroyal"),
            "param_name" => "width",
            "admin_label" => false,
            "value" => "100",
            "group" => "Styling",
            'edit_field_class' => 'vc_col-sm-6 vc_column'
        ),
        array(
            "type" => "dropdown",
            "class" => "",
            "heading" => esc_html__("Width Type", "casaroyal"),
            "param_name" => "width_type",
            "admin_label" => false,
            "value" => array( esc_html__("Pixels", "casaroyal") => "px", esc_html__("Percentage", "casaroyal") => "%"),
            "group" => "Styling",
            'edit_field_class' => 'vc_col-sm-6 vc_column',
            "std" => "%"
        ),
        array(
            "type" => "textfield",
            "class" => "",
            "heading" => esc_html__("Height", "casaroyal"),
            "param_name" => "height",
            "admin_label" => false,
            "value" => "450",
            "group" => "Styling",
            'edit_field_class' => 'vc_col-sm-6 vc_column'
        ),
        array(
            "type" => "dropdown",
            "class" => "",
            "heading" => esc_html__("Height Type", "casaroyal"),
            "param_name" => "height_type",
            "admin_label" => false,
            "value" => array( esc_html__("Pixels", "casaroyal") => "px", esc_html__("Percentage", "casaroyal") => "%"),
            "group" => "Styling",
            'edit_field_class' => 'vc_col-sm-6 vc_column',
            "std" => "px"
        ),
        array(
            "type" => "dropdown",
            "class" => "",
            "heading" => esc_html__("Dragging on Mobile", "casaroyal"),
            "param_name" => "dragging_mobile",
            "value" => array( esc_html__("Enable", "casaroyal") => "true", esc_html__("Disable", "casaroyal") => "false"),
            "group" => "Advanced",
            "std" => "true"
        ),
        array(
            "type" => "dropdown",
            "class" => "",
            "heading" => esc_html__("Dragging on Desktop", "casaroyal"),
            "param_name" => "dragging_desktop",
            "value" => array( esc_html__("Enable", "casaroyal") => "true", esc_html__("Disable", "casaroyal") => "false"),
            "group" => "Advanced",
            "std" => "true"
        ),
		array(
			'type' => 'css_editor',
			'heading' => esc_html__( 'CSS box', 'casaroyal' ),
			'param_name' => 'css',
			'group' => esc_html__( 'Design Options', 'casaroyal' ),
		),
	),
));

?>