<?php

/**
 * The Shortcode
 */

/**
 * Shortcode attributes
 * @var $atts
 * @var $title
 * @var $images
 * @var $css
 * Shortcode class
 * @var $this WPBakeryShortCode_VC_gallery
 */

function casaroyal_instagram_func( $atts ) {

	extract( shortcode_atts( array(
		"username" => "",
    	"css" => "",
   	), $atts ) );

	ob_start();

	$class_to_filter = '';
	$class_to_filter .= vc_shortcode_custom_css_class( $css, ' ' );
	$css_class = $class_to_filter;

	// based on https://gist.github.com/cosmocatalano/4544576
	function scrape_instagram( $username ) {

		$username = strtolower( $username );
		$username = str_replace( '@', '', $username );

		if ( false === ( $instagram = get_transient( 'instagram-a5-'.sanitize_title_with_dashes( $username ) ) ) ) {

			$remote = wp_remote_get( 'http://instagram.com/'.trim( $username ) );

			if ( is_wp_error( $remote ) )
				return new WP_Error( 'site_down', esc_html__( 'Unable to communicate with Instagram.', 'casaroyal' ) );

			if ( 200 != wp_remote_retrieve_response_code( $remote ) )
				return new WP_Error( 'invalid_response', esc_html__( 'Instagram did not return a 200.', 'casaroyal' ) );

			$shards = explode( 'window._sharedData = ', $remote['body'] );
			$insta_json = explode( ';</script>', $shards[1] );
			$insta_array = json_decode( $insta_json[0], TRUE );

			if ( ! $insta_array )
				return new WP_Error( 'bad_json', esc_html__( 'Instagram has returned invalid data.', 'casaroyal' ) );

			if ( isset( $insta_array['entry_data']['ProfilePage'][0]['user']['media']['nodes'] ) ) {
				$images = $insta_array['entry_data']['ProfilePage'][0]['user']['media']['nodes'];
			} else {
				return new WP_Error( 'bad_json_2', esc_html__( 'Instagram has returned invalid data.', 'casaroyal' ) );
			}

			if ( ! is_array( $images ) )
				return new WP_Error( 'bad_array', esc_html__( 'Instagram has returned invalid data.', 'casaroyal' ) );

			$instagram = array();

			foreach ( $images as $image ) {

				$image['thumbnail_src'] = preg_replace( '/^https?\:/i', '', $image['thumbnail_src'] );
				$image['display_src'] = preg_replace( '/^https?\:/i', '', $image['display_src'] );

				// handle both types of CDN url
				if ( ( strpos( $image['thumbnail_src'], 's640x640' ) !== false ) ) {
					$image['thumbnail'] = str_replace( 's640x640', 's160x160', $image['thumbnail_src'] );
					$image['small'] = str_replace( 's640x640', 's320x320', $image['thumbnail_src'] );
				} else {
					$urlparts = wp_parse_url( $image['thumbnail_src'] );
					$pathparts = explode( '/', $urlparts['path'] );
					array_splice( $pathparts, 3, 0, array( 's160x160' ) );
					$image['thumbnail'] = '//' . $urlparts['host'] . implode( '/', $pathparts );
					$pathparts[3] = 's320x320';
					$image['small'] = '//' . $urlparts['host'] . implode( '/', $pathparts );
				}

				$image['large'] = $image['thumbnail_src'];

				if ( $image['is_video'] == true ) {
					$type = 'video';
				} else {
					$type = 'image';
				}

				$caption = esc_html__( 'Instagram Image', 'casaroyal' );
				if ( ! empty( $image['caption'] ) ) {
					$caption = $image['caption'];
				}

				$instagram[] = array(
					'description'   => $caption,
					'link'		  	=> trailingslashit( '//instagram.com/p/' . $image['code'] ),
					'time'		  	=> $image['date'],
					'comments'	  	=> $image['comments']['count'],
					'likes'		 	=> $image['likes']['count'],
					'thumbnail'	 	=> $image['thumbnail'],
					'small'			=> $image['small'],
					'large'			=> $image['large'],
					'original'		=> $image['display_src'],
					'type'		  	=> $type
				);
			}

			// do not set an empty transient - should help catch private or empty accounts
			if ( ! empty( $instagram ) ) {
				$instagram = base64_encode( serialize( $instagram ) );
				set_transient( 'instagram-a5-'.sanitize_title_with_dashes( $username ), $instagram, apply_filters( 'null_instagram_cache_time', HOUR_IN_SECONDS*2 ) );
			}
		}

		if ( ! empty( $instagram ) ) {

			return unserialize( base64_decode( $instagram ) );

		} else {

			return new WP_Error( 'no_images', esc_html__( 'Instagram did not return any images.', 'casaroyal' ) );

		}
	}

	function images_only( $media_item ) {

		if ( $media_item['type'] == 'image' )
			return true;

		return false;
	}

	if ( $username != '' ) {

		$limit = empty( $instance['number'] ) ? 6 : $instance['number'];
		$size = empty( $instance['size'] ) ? 'large' : $instance['size'];
		$target = empty( $instance['target'] ) ? '_blank' : $instance['target'];
		$link = empty( $instance['link'] ) ? '' : $instance['link'];

		$media_array = scrape_instagram( $username );

		if ( is_wp_error( $media_array ) ) {

			echo wp_kses_post( $media_array->get_error_message() );

		} else {

			// filter for images only?
			if ( $images_only = apply_filters( 'wpiw_images_only', FALSE ) ) {
				$media_array = array_filter( $media_array, array( $this, 'images_only' ) );
			}

			// slice list down to required limit
			$media_array = array_slice( $media_array, 0, $limit );

			?>
			<div class="row instagram-section <?php echo esc_attr($css_class); ?>">
				
				<ul class="list-inline instagram-feed">

				<?php
					foreach ( $media_array as $item ) {
						// copy the else line into a new file (parts/wp-instagram-widget.php) within your theme and customise accordingly
						echo '<li class="col-md-2 col-sm-4"><a href="'. esc_url( $item['link'] ) .'" target="<?php echo esc_attr($target); ?>"><img src="'. esc_url( $item[$size] ) .'"  alt="'. esc_attr( $item['description'] ) .'" title="'. esc_attr( $item['description'] ).'"  class="img-responsive"/></a></li>';
					}
				?>
					
				</ul>

			</div>

			<div class="row footer-instagram-follow"> 
				<div class="col-md-12">
					<a href="https://www.instagram.com/<?php echo esc_attr($username); ?>/" target="<?php echo esc_attr($target); ?>"><?php esc_html_e( 'Follow me on instagram', 'casaroyal'); ?></a>
					<span class="pull-right user-name">@<?php echo esc_attr($username); ?></span>
				</div> 
			</div>

			<?php
		}
	}

	return ob_get_clean();

}
add_shortcode( 'casaroyal_instagram', 'casaroyal_instagram_func' );

vc_map( array(
  	'name' => esc_html__( 'Instagram', 'casaroyal' ),
	'base' => 'casaroyal_instagram',
	'icon' => get_template_directory_uri().'/images/vc-icon.png',
	'category' => esc_html__( 'casaroyal', 'casaroyal' ),
	'description' => esc_html__( 'Custom casaroyal instagram', 'casaroyal' ),
	'params' => array(
		array(
			'type' => 'textfield',
			'heading' => esc_html__( 'Username', 'casaroyal' ),
			'param_name' => 'username',
			'value' => '',
			'admin_label' => true,
			'description' => esc_html__( 'Enter instagram username', 'casaroyal' ),
			"group" => "Settings",
		),
        array(
			'type' => 'css_editor',
			'heading' => esc_html__( 'CSS box', 'casaroyal' ),
			'param_name' => 'css',
			'group' => esc_html__( 'Design Options', 'casaroyal' ),
		),
	),
));

