<?php

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/*
Plugin Name: casaRoyal Plugin
Plugin URI: https://fantasythemes.net/
Description: Declares custom post types for casaroyal WordPress Theme.
Version: 1.0.0
Author: Alex Gurghis
Author URI: http://alexgurghis.com/
Text Domain: casaroyal-plugin
License: Commercial
*/

// Define constants
define( 'casaroyal_PLUGIN_DIR', untrailingslashit( plugin_dir_path( __FILE__ ) ) );
define( 'casaroyal_PLUGIN_URL', untrailingslashit( plugins_url( basename( plugin_dir_path( __FILE__ ) ), basename( __FILE__ ) ) ) );

function casaroyal_activate() {
    unset( $_COOKIE['casaroyal_compare_ids'] );
}
register_activation_hook( __FILE__, 'casaroyal_activate' );

function casaroyal_admin_add_custom_menu(){    
    add_theme_page('casaRoyal Quick Setup Wizard', 'casaRoyal Quick Setup Wizard', 'manage_options', 'casaroyal-setup', 'admin_add_custom_content');
}
add_action( 'admin_menu', 'casaroyal_admin_add_custom_menu');

add_action( 'init', 'casaroyal_init_setup_wizard' );
/**
 * Include any classes we need within admin.
 */
function casaroyal_init_setup_wizard() {
	// Setup/welcome
	if ( ! empty( $_GET['page'] ) ) {
		switch ( $_GET['page'] ) {
			case 'casaroyal-setup' :
				include_once( dirname( __FILE__ ) . '/setup-wizard/class-ft-setup-wizard.php' );
			break;
		}
	}
}

// Register and enqueue Javascript files
add_action( 'wp_enqueue_scripts', 'casaroyal_sharrre_files' );
function casaroyal_sharrre_files() {

	wp_enqueue_script( 'casaroyal_sharre-core',   plugin_dir_url( __FILE__ ) . '/sharrre/sharrre-core.js', array('jquery'), '', true );
	wp_enqueue_script( 'casaroyal_sharrre',   plugin_dir_url( __FILE__ ) . '/sharrre/sharrre.min.js', '1.0.0', '', true );

	$settings = array(
		'url_plugin' => plugin_dir_url( __FILE__ ),
	);

	wp_localize_script( 'casaroyal_sharrre', 'casaroyalSharrreSettings', apply_filters( 'casaroyal_sharrre', $settings ) );
}

// Start wp_mail functions - plugin teritory

/*
|--------------------------------------------------------------------------
| Add New Notification
|--------------------------------------------------------------------------
*/
function casaroyal_addNotificationFunction() {

	$response['status'] = 'success';
	$response['response'] = esc_html__( "Notification has been added.", 'casaroyal' );

	$casaroyal_notification_user_id = get_current_user_id();

	$my_post = array(
	  	'post_type'     => 'notification',
	  	'post_status'   => 'publish',
	);
	// Insert the post into the database
	$notification_id = wp_insert_post( $my_post );

	update_post_meta( $notification_id, 'casaroyal_notification_location', sanitize_text_field($_POST['casaroyal_notification_location']) );
	update_post_meta( $notification_id, 'casaroyal_notification_status', sanitize_text_field($_POST['casaroyal_notification_status']) );
	update_post_meta( $notification_id, 'casaroyal_notification_type', sanitize_text_field($_POST['casaroyal_notification_type']) );
	update_post_meta( $notification_id, 'casaroyal_notification_min_beds', sanitize_text_field($_POST['casaroyal_notification_min_beds']) );
	update_post_meta( $notification_id, 'casaroyal_notification_min_baths', sanitize_text_field($_POST['casaroyal_notification_min_baths']) );
	update_post_meta( $notification_id, 'casaroyal_notification_min_price', sanitize_text_field($_POST['casaroyal_notification_min_price']) );
	update_post_meta( $notification_id, 'casaroyal_notification_max_price', sanitize_text_field($_POST['casaroyal_notification_max_price']) );
	update_post_meta( $notification_id, 'casaroyal_notification_min_area', sanitize_text_field($_POST['casaroyal_notification_min_area']) );
	update_post_meta( $notification_id, 'casaroyal_notification_max_area', sanitize_text_field($_POST['casaroyal_notification_max_area']) );
	update_post_meta( $notification_id, 'casaroyal_notification_email_alert', sanitize_text_field($_POST['casaroyal_notification_email_alert']) );
	update_post_meta( $notification_id, 'casaroyal_notification_user_id', $casaroyal_notification_user_id );

	// Sene email to admin
	if (strtoupper(substr(PHP_OS,0,3)=='WIN')) {
		$eol="\r\n";
	} elseif (strtoupper(substr(PHP_OS,0,3)=='MAC')) {
		$eol="\r";
	} else {
		$eol="\n";
	}

	$site_name = get_bloginfo('name');
	$filter_email = get_the_author_meta( 'user_email', get_current_user_id() );

	//
	$email = get_option('admin_email');
	$from = $filter_email;
  	$subject = esc_html__('Filter notification from ', 'casaroyal').$site_name;
  	$headers = "From: " . $from . $eol;
	$headers .= "Reply-To: " . $from . $eol;
	$headers .= "MIME-Version: 1.0".$eol;
	$headers .= "Content-Type: text/html; charset=ISO-8859-1".$eol;

	$email_content = ""
		.__('New filter subscription', 'casaroyal')."<br><br>"
		.__('Email', 'casaroyal').": ".$filter_email."<br>"
		.__('Location', 'casaroyal').": ".$casaroyal_notification_location."<br>"
		.__('Status', 'casaroyal').": ".$casaroyal_notification_status."<br>"
		.__('Type', 'casaroyal').": ".$casaroyal_notification_type."<br>"
		.__('Min beds', 'casaroyal').": ".$casaroyal_notification_min_beds."<br>"
		.__('Min baths', 'casaroyal').": ".$casaroyal_notification_min_baths."<br>"
		.__('Min price', 'casaroyal').": ".$casaroyal_notification_min_price."<br>"
		.__('Max price', 'casaroyal').": ".$casaroyal_notification_max_price."<br>"
		.__('Min area', 'casaroyal').": ".$casaroyal_notification_min_area."<br>"
		.__('Max area', 'casaroyal').": ".$casaroyal_notification_max_area;

  	add_filter('wp_mail_content_type', create_function('', 'return "text/html";'));
  	$mail_sent = wp_mail( $email, $subject, $email_content, $headers );

	echo json_encode($response);

	exit;

}
add_action( 'wp_ajax_casaroyal_addNotificationFunction', 'casaroyal_addNotificationFunction' );
add_action( 'wp_ajax_nopriv_casaroyal_addNotificationFunction', 'casaroyal_addNotificationFunction' );


/*
|--------------------------------------------------------------------------
| Register Form
|--------------------------------------------------------------------------
*/
function casaroyal_register() {

	$MODS = get_theme_mods();
    foreach(casaroyal_defaults() as $mod=>$def) {if(!isset($MODS[$mod])){$MODS[$mod]=$def;}}

	// My Listings
    global $my_listings_page;
    if(strlen($MODS['my_listings_page'])>0) {
        $my_listings_page = $MODS['my_listings_page'];
    }

	$response['status'] = '';
	$response['error_user'] = '';
	$response['error_email'] = '';
	$response['error_default'] = '';
	$response['redirect'] = get_permalink( $my_listings_page );

  	$username = sanitize_text_field($_POST['casaroyal_user_login']);
  	$email = sanitize_email($_POST['casaroyal_user_email']);
  	$password = $_POST['casaroyal_user_pass'];


  	if ( username_exists($username) ) {

	  	$response['status'] = 'error';
		$response['error_user'] = '<span class="error-title">Error:</span> Username exists. Please try another one.';

  	} 

  	if( email_exists( $email )) {

	  	$response['status'] = 'error';
		$response['error_email'] = '<span class="error-title">Error:</span> Email exists. Please try another one.';

  	} 

  	$user_ID = wp_create_user( $username, $password, $email );

  	$login_data = array();
  	$login_data['user_login'] = $username;
  	$login_data['user_password'] = $password;
  	$user = wp_signon( $login_data, false );

  	if ( ! is_wp_error( $user ) ) {

		$response['status'] = 'success';

		$from = get_option('admin_email');
	  	$headers = 'From: '.$from . "\r\n";
	  	$subject = "Registration successful";
	  	$msg = "Registration successful.\nYour login details\nUsername: $username\nPassword: $password";
	  	wp_mail( $email, $subject, $msg, $headers );

	}

  	echo json_encode($response);

	exit;

}
add_action( 'wp_ajax_casaroyal_register', 'casaroyal_register' );
add_action( 'wp_ajax_nopriv_casaroyal_register', 'casaroyal_register' );




/*
|--------------------------------------------------------------------------
| Reset Password
|--------------------------------------------------------------------------
*/
function casaroyal_reset_password() {

	$response['status'] = '';
	$response['error_user'] = '';
	$response['error_default'] = '';
	$response['success'] = '';

  	$email = sanitize_email($_POST['user_login']);
  
  	$user = get_user_by( 'email', $email );
  	$user_ID = $user->ID;

  	if( !empty($user_ID)) {

		$new_password = wp_generate_password( 12, false ); 

		if ( isset($new_password) ) {

	  		wp_set_password( $new_password, $user_ID );

	  		$from = get_option('admin_email');
	  		$headers = 'From: '.$from . "\r\n";
	  		$subject = "Password reset!";
	  		$msg = "Reset password.\nYour login details\nNew Password: $new_password";
	  		wp_mail( $email, $subject, $msg, $headers );

	  		$response['status'] = 'success';
	  		$response['success'] = '<span class="error-title">Success:</span> Check your email for new password.';

		}

  	} else {

		$response['status'] = 'error';
		$response['error_user'] = '<span class="error-title">Error:</span> There is no user available for this email.';

  	} // end if/else

  	echo json_encode($response);

	exit;

}
add_action( 'wp_ajax_casaroyal_reset_password', 'casaroyal_reset_password' );
add_action( 'wp_ajax_nopriv_casaroyal_reset_password', 'casaroyal_reset_password' );


/*-----------------------------------------------------------------------------------*/
/*	Send Notifications
/*-----------------------------------------------------------------------------------*/
// Update _sold and _submit_fee meta on post creation
add_action( 'transition_post_status', 'casaroyal_change_post_status', 10, 3 );
function casaroyal_change_post_status( $new_status, $old_status, $post ) {

    if ( 'publish' !== $new_status )
        return;

    $post_id = $post->ID;
    casaroyal_send_property_notifications( $post_id );

}

function casaroyal_send_property_notifications( $property_id ) {

	if ( get_post_type( $property_id ) == 'property' ) {
		
		$ft_property_location = esc_attr(get_post_meta($property_id, 'ft_property_address_city',true));
		$ft_property_price = esc_attr(get_post_meta($property_id, 'ft_property_price',true));
		$ft_property_size = esc_attr(get_post_meta($property_id, 'ft_property_size',true));
		$ft_property_bedrooms = esc_attr(get_post_meta($property_id, 'ft_property_bedrooms',true));
		$ft_property_bathrooms = esc_attr(get_post_meta($property_id, 'ft_property_bathrooms',true));

		$status_terms = get_the_terms( $property_id, "property-status" );
		if( !empty($status_terms) ) {
			$casaroyal_property_status = $status_terms[0]->term_id;
		} else {
			$casaroyal_property_status = "";
		}

        $type_terms = get_the_terms( $property_id, "property-type" );
        if( !empty($type_terms) ) {
        	$casaroyal_property_type = $type_terms[0]->term_id;
        } else {
        	$casaroyal_property_type = "";
        }

		$property_url = get_permalink( $property_id );
		$property_name = get_the_title( $property_id );

	    //
		$site_name = get_bloginfo('name');

		$email_list = array();

		// New
		$filter_args = array(
			'post_type'           => 'notification',
			'posts_per_page'      => -1,
			'post_status'         => array( 'publish' ),
			'orderby'             => 'ID',
			'order'               => 'DESC'
		);

		$filters_query = new WP_Query;
		$filters = $filters_query->query( $filter_args );

		if ( $filters ) :

			foreach ( $filters as $filter ) :

				$filter_ID = $filter->ID; 

				$casaroyal_notification_location = get_post_meta($filter_ID, 'casaroyal_notification_location',true);
				$casaroyal_notification_status = get_post_meta($filter_ID, 'casaroyal_notification_status',true);
				$casaroyal_notification_type = get_post_meta($filter_ID, 'casaroyal_notification_type',true);
				$casaroyal_notification_min_beds = get_post_meta($filter_ID, 'casaroyal_notification_min_beds',true);
				$casaroyal_notification_min_baths = get_post_meta($filter_ID, 'casaroyal_notification_min_baths',true);
				$casaroyal_notification_min_price = get_post_meta($filter_ID, 'casaroyal_notification_min_price',true);
				$casaroyal_notification_max_price = get_post_meta($filter_ID, 'casaroyal_notification_max_price',true);
				$casaroyal_notification_min_area = get_post_meta($filter_ID, 'casaroyal_notification_min_area',true);
				$casaroyal_notification_max_area = get_post_meta($filter_ID, 'casaroyal_notification_max_area',true);
				$casaroyal_notification_user_id = get_post_meta($filter_ID, 'casaroyal_notification_user_id',true);
				$casaroyal_notification_email_alert = get_post_meta($filter_ID, 'casaroyal_notification_email_alert',true);
				$user_email = get_the_author_meta( 'user_email', $casaroyal_notification_user_id );

		        if( sanitize_title($casaroyal_notification_location) == sanitize_title($ft_property_location) ) {
					$filter_by_location = 1;
				} else {
					$filter_by_location = 0;
				}

				if( $casaroyal_notification_type == $casaroyal_property_type ) {
					$filter_by_type = 1;
				} else {
					$filter_by_type = 0;
				}

				if( $casaroyal_notification_status == $casaroyal_property_status ) {
					$filter_by_status = 1;
				} else {
					$filter_by_status = 0;
				}

				if( $ft_property_bedrooms >= $casaroyal_notification_min_beds ) {
					$filter_by_beds = 1;
				} else {
					$filter_by_beds = 0;
				}

				if( $casaroyal_notification_min_baths <= $ft_property_bathrooms ) {
					$filter_by_baths = 1;
				} else {
					$filter_by_baths = 0;
				}

				if( $casaroyal_notification_min_price <= $ft_property_price AND $casaroyal_notification_max_price >= $ft_property_price ) {
					$filter_by_price = 1;
				} else {
					$filter_by_price = 0;
				}

				if( $casaroyal_notification_min_area <= $ft_property_size AND $casaroyal_notification_max_area >= $ft_property_size ) {
					$filter_by_area = 1;
				} else {
					$filter_by_area = 0;
				}

		        if ( $filter_by_location == 1 AND $filter_by_type == 1 AND $filter_by_status == 1 AND $filter_by_beds == 1 AND $filter_by_baths == 1 AND $filter_by_price == 1 AND $filter_by_area == 1 ) { 

		        	if( $casaroyal_notification_email_alert == "on" ) {
		        		$email_list[] = $user_email;
		        	}

		        	// Add to car filter id and view = new;
		        	$filter_IDs = array();
		        	$filter_IDs = get_post_meta($property_id, 'filter_ids',true);
		        	array_push($filter_IDs, $filter_ID);
		        	$filter_IDs = array_unique($filter_IDs);

		        	update_post_meta($property_id, 'filter_ids', $filter_IDs);
		        	update_post_meta($property_id, 'filter_user_'.$casaroyal_notification_user_id, 'new');

		        }

			endforeach;

		endif;
		// End New

		$email_list_unique = array_unique($email_list);

	    if( !empty($email_list_unique)) {

	    	foreach($email_list_unique as $email) {

	    		// Send Email
		    	if (strtoupper(substr(PHP_OS,0,3)=='WIN')) {
					$eol="\r\n";
				} elseif (strtoupper(substr(PHP_OS,0,3)=='MAC')) {
					$eol="\r";
				} else {
					$eol="\n";
				}

				//
				$from = get_option('admin_email');
			  	$subject = esc_html__('Property notification from ', 'casaroyal').$site_name;
			  	$headers = "From: " . $from . $eol;
				$headers .= "Reply-To: " . $from . $eol;
				$headers .= "MIME-Version: 1.0".$eol;
				$headers .= "Content-Type: text/html; charset=ISO-8859-1".$eol;

				$email_content = "".__('New property added matching your criteria', 'casaroyal')."<br><br><a href='".$property_url."'>".$property_name."</a>";

			  	$msg = $email_content;

			  	add_filter('wp_mail_content_type',create_function('', 'return "text/html"; '));
			  	$mail_sent = wp_mail( $email, $subject, $msg, $headers );

	    	}

	    }

	}

}

// End wp_mail functions - plugin teritory


/******************************************************************************/
/****** Add LightBox to Galleries *********************************************/
/******************************************************************************/
function add_rel_to_gallery($link, $id) {
  	$image_url = wp_get_attachment_url( $id );
  	return str_replace('<a href=', '<a data-lightbox="gallery" style="background-image: url('.$image_url.');" href=', $link);
}
add_filter( 'wp_get_attachment_link', 'add_rel_to_gallery', 10, 2 );

add_shortcode( 'gallery', 'modified_gallery_shortcode' );
function modified_gallery_shortcode($attr) {
    $attr['link'] = "file";
    $output = gallery_shortcode($attr);
    return $output; 
}


if ( ! function_exists( 'rwmb_meta_shortcode' ) )
{
	/**
	 * Shortcode to display meta value
	 *
	 * @param array $atts Shortcode attributes, same as meta() function, but has more "meta_key" parameter
	 *
	 * @see meta() function below
	 *
	 * @return string
	 */
	function rwmb_meta_shortcode( $atts )
	{
		$atts = wp_parse_args( $atts, array(
			'post_id' => get_the_ID(),
		) );
		if ( empty( $atts['meta_key'] ) )
			return '';

		$field_id = $atts['meta_key'];
		$post_id  = $atts['post_id'];
		unset( $atts['meta_key'], $atts['post_id'] );

		return rwmb_the_value( $field_id, $atts, $post_id, false );
	}

	add_shortcode( 'rwmb_meta', 'rwmb_meta_shortcode' );
}


$file = dirname(__FILE__) . '/casaroyal.php';
$plugin_path = plugin_dir_path($file);

// Post Types
/**
 * Custom Post Types - Real Estate
 */
require_once( $plugin_path . '/post-types/real-estate/agent-post-type.php' );        // Agent
require_once( $plugin_path . '/post-types/real-estate/property-post-type.php' );     // Property
require_once( $plugin_path . '/post-types/real-estate/partners-post-type.php' );     // Partner
require_once( $plugin_path . '/post-types/real-estate/testimonial-post-type.php' );  // Testimonials
require_once( $plugin_path . '/post-types/real-estate/notifications-post-type.php' );  // Notifications

$notification_post_meta = new casaroyal_Notifications_Post_Type();


/**
 * Remove "Design options", "Custom CSS" tabs and prompt message to activate Visual Composer.
 */
add_action( 'vc_before_init', 'vc_before_init_actions' );
 
function vc_before_init_actions() {
     
    // Setup VC to be part of a theme
    if( function_exists('vc_set_as_theme') ){ 
        vc_set_as_theme( true );    
    }

    $file = dirname(__FILE__) . '/casaroyal.php';
	$plugin_path = plugin_dir_path($file);

	// Shortcodes
	/*
	|--------------------------------------------------------------------------
	| casaroyal: Video Player Shortcode
	|--------------------------------------------------------------------------
	*/
	include_once( $plugin_path . '/shortcodes/td-shortcode-video-player.php' );

	/*
	|--------------------------------------------------------------------------
	| casaroyal: Video Button Default
	|--------------------------------------------------------------------------
	*/
	include_once( $plugin_path . '/shortcodes/td-shortcode-button-video-default.php' );

	/*
	|--------------------------------------------------------------------------
	| casaroyal: Video Button Advanced
	|--------------------------------------------------------------------------
	*/
	include_once( $plugin_path . '/shortcodes/td-shortcode-button-video.php' );


	/*
	|--------------------------------------------------------------------------
	| casaroyal: Gallery Shortcode
	|--------------------------------------------------------------------------
	*/
	include_once( $plugin_path . '/shortcodes/td-shortcode-gallery.php' );


	/*
	|--------------------------------------------------------------------------
	| casaroyal: Map
	|--------------------------------------------------------------------------
	*/
	include_once( $plugin_path . '/shortcodes/td-shortcode-gmap.php' );

	/*
	|--------------------------------------------------------------------------
	| casaroyal: Social
	|--------------------------------------------------------------------------
	*/
	include_once( $plugin_path . '/shortcodes/td-shortcode-social.php' );

	/*
	|--------------------------------------------------------------------------
	| casaroyal: Testimonials
	|--------------------------------------------------------------------------
	*/
	include_once( $plugin_path . '/shortcodes/td-shortcode-testimonials.php' );

	/*
	|--------------------------------------------------------------------------
	| casaroyal: Agents
	|--------------------------------------------------------------------------
	*/
	include_once( $plugin_path . '/shortcodes/td-shortcode-agents.php' );

	/*
	|--------------------------------------------------------------------------
	| casaroyal: Banner
	|--------------------------------------------------------------------------
	*/
	include_once( $plugin_path . '/shortcodes/td-shortcode-banner.php' );

	/*
	|--------------------------------------------------------------------------
	| casaroyal: Partners
	|--------------------------------------------------------------------------
	*/
	include_once( $plugin_path . '/shortcodes/td-shortcode-partners.php' );

	/*
	|--------------------------------------------------------------------------
	| casaroyal: Partners
	|--------------------------------------------------------------------------
	*/
	include_once( $plugin_path . '/shortcodes/td-shortcode-woocommerce-categories.php' );

	/*
	|--------------------------------------------------------------------------
	| casaroyal: Button
	|--------------------------------------------------------------------------
	*/
	include_once( $plugin_path . '/shortcodes/td-shortcode-button.php' );

	/*
	|--------------------------------------------------------------------------
	| casaroyal: Share Buttons
	|--------------------------------------------------------------------------
	*/
	include_once( $plugin_path . '/shortcodes/td-shortcode-share.php' );

	/*
	|--------------------------------------------------------------------------
	| casaroyal: Share Buttons 2
	|--------------------------------------------------------------------------
	*/
	include_once( $plugin_path . '/shortcodes/td-shortcode-share-v2.php' );

	/*
	|--------------------------------------------------------------------------
	| casaroyal: Properties Slider
	|--------------------------------------------------------------------------
	*/
	include_once( $plugin_path . '/shortcodes/td-shortcode-properties-slider.php' );

	/*
	|--------------------------------------------------------------------------
	| casaroyal: Properties Map
	|--------------------------------------------------------------------------
	*/
	include_once( $plugin_path . '/shortcodes/td-shortcode-properties-map.php' );

	/*
	|--------------------------------------------------------------------------
	| casaroyal: Properties Advanced Search form
	|--------------------------------------------------------------------------
	*/
	include_once( $plugin_path . '/shortcodes/td-shortcode-properties-asf.php' );

	/*
	|--------------------------------------------------------------------------
	| casaroyal: Properties Grid
	|--------------------------------------------------------------------------
	*/
	include_once( $plugin_path . '/shortcodes/td-shortcode-properties-grid.php' );

	/*
	|--------------------------------------------------------------------------
	| casaroyal: Properties Carousel
	|--------------------------------------------------------------------------
	*/
	include_once( $plugin_path . '/shortcodes/td-shortcode-properties-carousel.php' );

	/*
	|--------------------------------------------------------------------------
	| casaroyal: Properties Cities (Blocks)
	|--------------------------------------------------------------------------
	*/
	include_once( $plugin_path . '/shortcodes/td-shortcode-properties-cities.php' );

	/*
	|--------------------------------------------------------------------------
	| casaroyal: Properties Types (Blocks)
	|--------------------------------------------------------------------------
	*/
	include_once( $plugin_path . '/shortcodes/td-shortcode-properties-types.php' );

	/*
	|--------------------------------------------------------------------------
	| casaroyal: Single Property
	|--------------------------------------------------------------------------
	*/
	include_once( $plugin_path . '/shortcodes/td-shortcode-single-property.php' );

	/*
	|--------------------------------------------------------------------------
	| casaroyal: Promo Block
	|--------------------------------------------------------------------------
	*/
	include_once( $plugin_path . '/shortcodes/td-shortcode-promo.php' );

	/*
	|--------------------------------------------------------------------------
	| casaroyal: Accordion
	|--------------------------------------------------------------------------
	*/
	include_once( $plugin_path . '/shortcodes/td-shortcode-accordion.php' );

	/*
	|--------------------------------------------------------------------------
	| casaroyal: Accordion Section
	|--------------------------------------------------------------------------
	*/
	include_once( $plugin_path . '/shortcodes/td-shortcode-accordion-section.php' );

	/*
	|--------------------------------------------------------------------------
	| casaroyal: Sortable Accordion
	|--------------------------------------------------------------------------
	*/
	include_once( $plugin_path . '/shortcodes/td-shortcode-accordion-sortable.php' );

	/*
	|--------------------------------------------------------------------------
	| casaroyal: Sortable Accordion Section
	|--------------------------------------------------------------------------
	*/
	include_once( $plugin_path . '/shortcodes/td-shortcode-accordion-section-sortable.php' );

	/*
	|--------------------------------------------------------------------------
	| casaroyal: Tabs
	|--------------------------------------------------------------------------
	*/
	include_once( $plugin_path . '/shortcodes/td-shortcode-tabs.php' );

	/*
	|--------------------------------------------------------------------------
	| casaroyal: Tab
	|--------------------------------------------------------------------------
	*/
	include_once( $plugin_path . '/shortcodes/td-shortcode-tab.php' );

	/*
	|--------------------------------------------------------------------------
	| casaroyal: Progress Circle
	|--------------------------------------------------------------------------
	*/
	include_once( $plugin_path . '/shortcodes/td-shortcode-progress-circle.php' );

	/*
	|--------------------------------------------------------------------------
	| casaroyal: Progress Bar
	|--------------------------------------------------------------------------
	*/
	include_once( $plugin_path . '/shortcodes/td-shortcode-progress-bar.php' );

	/*
	|--------------------------------------------------------------------------
	| casaroyal: Icon Box
	|--------------------------------------------------------------------------
	*/
	include_once( $plugin_path . '/shortcodes/td-shortcode-icon-box.php' );

	/*
	|--------------------------------------------------------------------------
	| casaroyal: Notification Box
	|--------------------------------------------------------------------------
	*/
	include_once( $plugin_path . '/shortcodes/td-shortcode-notification-box.php' );

	/*
	|--------------------------------------------------------------------------
	| casaroyal: Animated Number Box
	|--------------------------------------------------------------------------
	*/
	include_once( $plugin_path . '/shortcodes/td-shortcode-animated-number.php' );

	/*
	|--------------------------------------------------------------------------
	| casaroyal: Price Box
	|--------------------------------------------------------------------------
	*/
	include_once( $plugin_path . '/shortcodes/td-shortcode-price-box.php' );

	/*
	|--------------------------------------------------------------------------
	| casaroyal: Blog Posts
	|--------------------------------------------------------------------------
	*/
	include_once( $plugin_path . '/shortcodes/td-shortcode-blog-posts.php' );

	/*
	|--------------------------------------------------------------------------
	| casaroyal: Instagram
	|--------------------------------------------------------------------------
	*/
	include_once( $plugin_path . '/shortcodes/td-shortcode-instagram.php' );

	/*
	|--------------------------------------------------------------------------
	| casaroyal: Image Slider
	|--------------------------------------------------------------------------
	*/
	include_once( $plugin_path . '/shortcodes/td-shortcode-slider.php' );

	/*
	|--------------------------------------------------------------------------
	| casaroyal: Sortable Accordion Section
	|--------------------------------------------------------------------------
	*/
	include_once( $plugin_path . '/shortcodes/td-shortcode-slider-section.php' );

	/*
	|--------------------------------------------------------------------------
	| casaroyal: Flipclock
	|--------------------------------------------------------------------------
	*/
	include_once( $plugin_path . '/shortcodes/td-shortcode-flipclock.php' );

	/*
	|--------------------------------------------------------------------------
	| casaroyal: Entry Title
	|--------------------------------------------------------------------------
	*/
	include_once( $plugin_path . '/shortcodes/td-shortcode-entry-title.php' );
	

	// Disable Instructional/Help Pointers
    if( function_exists('vc_pointer_load') ){ 
        remove_action( 'admin_enqueue_scripts', 'vc_pointer_load' );        
    }
     
}

/*
|--------------------------------------------------------------------------
| Contact Form
|--------------------------------------------------------------------------
*/
if ( ! function_exists( 'casaroyal_ContactForm' ) ) {

	function casaroyal_ContactForm() {

		$name = sanitize_text_field($_POST['name']);
		$phone = sanitize_text_field($_POST['phone']);
		$email = sanitize_email($_POST['email']);
		$message = wp_kses_data($_POST['message']);
		$receiverEmail = sanitize_email($_POST['receiverEmail']);

		$email_subject = esc_html__( 'New message sent by', 'casaroyal' ) . ' ' . $name . ' ' . esc_html__( 'using agent contact form at', 'casaroyal' ) . ' ' . get_bloginfo( 'name' );
		$email_body = esc_html__( "You have received a message from: ", 'casaroyal' ) . $name . "\r\n";

		if ( ! empty( $property_title ) ) {
			$email_body .= "\r\n" . esc_html__( "Property Title : ", 'casaroyal' ) . $property_title . "\r\n";
		}

		if ( ! empty( $property_permalink ) ) {
			$email_body .= esc_html__( "Property URL : ", 'casaroyal' ) . $property_permalink . "\r\n";
		}

		$email_body .= "\r\n" . esc_html__( "Their additional message is as follows.", 'casaroyal' ) . "\r\n";
		$email_body .= $message . "\r\n\r\n";
		$email_body .= esc_html__( "You can contact ", 'casaroyal' ) . $name . esc_html__( " via email: ", 'casaroyal' ) . $email;

		$headers = 'From <'.$emailTo.'>' . "\r\n" . 'Reply-To: ' . $email;
		  
		wp_mail($receiverEmail, $email_subject, $email_body, $headers);

	  	die(); // this is required to return a proper result

	}
	add_action( 'wp_ajax_ContactForm', 'casaroyal_ContactForm' );
	add_action( 'wp_ajax_nopriv_ContactForm', 'casaroyal_ContactAgentForm' );
}

/*
|--------------------------------------------------------------------------
| Contact Agent Form
|--------------------------------------------------------------------------
*/
if ( ! function_exists( 'casaroyal_ContactAgentForm' ) ) {

	function casaroyal_ContactAgentForm() {

		$name = sanitize_text_field($_POST['name']);
		$phone = sanitize_text_field($_POST['phone']);
		$email = sanitize_email($_POST['email']);
		$message = wp_kses_data($_POST['message']);
		$property_title = sanitize_text_field($_POST['property_title']);
		$property_permalink = $_POST['property_permalink'];
		$receiverEmail = sanitize_email($_POST['receiverEmail']);

		$email_subject = esc_html__( 'New message sent by', 'casaroyal' ) . ' ' . $name . ' ' . esc_html__( 'using agent contact form at', 'casaroyal' ) . ' ' . get_bloginfo( 'name' );
		$email_body = esc_html__( "You have received a message from: ", 'casaroyal' ) . $name . "\r\n";

		if ( ! empty( $property_title ) ) {
			$email_body .= "\r\n" . esc_html__( "Property Title : ", 'casaroyal' ) . $property_title . "\r\n";
		}

		if ( ! empty( $property_permalink ) ) {
			$email_body .= esc_html__( "Property URL : ", 'casaroyal' ) . $property_permalink . "\r\n";
		}

		$email_body .= "\r\n" . esc_html__( "Their additional message is as follows.", 'casaroyal' ) . "\r\n";
		$email_body .= $message . "\r\n\r\n";
		$email_body .= esc_html__( "You can contact ", 'casaroyal' ) . $name . esc_html__( " via email: ", 'casaroyal' ) . $email;

		$headers = 'From <'.$emailTo.'>' . "\r\n" . 'Reply-To: ' . $email;
		  
		wp_mail($receiverEmail, $email_subject, $email_body, $headers);

	  	die(); // this is required to return a proper result

	}
	add_action( 'wp_ajax_ContactAgentForm', 'casaroyal_ContactAgentForm' );
	add_action( 'wp_ajax_nopriv_ContactAgentForm', 'casaroyal_ContactAgentForm' );
}

// Submit Fee
$MODS = get_theme_mods();
if(isset($MODS['casaroyal_monetization_status']) AND strlen($MODS['casaroyal_monetization_status'])>0) {
    $casaroyal_monetization_status = $MODS['casaroyal_monetization_status'];
} else {
	$casaroyal_monetization_status = '';
}

if( !empty($casaroyal_monetization_status) AND $casaroyal_monetization_status == "on" ) {

	// Start Cron Jobs
	function casaroyal_add_cron_recurrence_interval( $schedules ) {

	    $schedules['casaroyal_every_five_minutes'] = array(
	            'interval'  => 300,
	            'display'   => __( 'Every 5 Minutes', 'casaroyal' )
	    );
	     
	    return $schedules;
	}
	add_filter( 'cron_schedules', 'casaroyal_add_cron_recurrence_interval' );

	if ( ! wp_next_scheduled( 'casaroyal_every_five_minutes' ) ) {
	    wp_schedule_event( time(), 'casaroyal_every_five_minutes', 'casaroyal_payments_cron_jobs' );
	}
	add_action('casaroyal_payments_cron_jobs', 'casaroyal_payments_cron_jobs');

}


/**
 * Cron Featured & Promoted Listings
 */
function casaroyal_payments_cron_jobs() {
	global $wpdb;

	$MODS = get_theme_mods();
	foreach(casaroyal_defaults() as $mod=>$def) {if(!isset($MODS[$mod])){$MODS[$mod]=$def;}}

	if(strlen($MODS['casaroyal_monetization_status'])>0) {
	    $casaroyal_monetization_status = $MODS['casaroyal_monetization_status'];
	} else {
		$casaroyal_monetization_status = '';
	}

	if(strlen($MODS['casaroyal_submit_listing_price'])>0) {
	    $casaroyal_submit_listing_price = $MODS['casaroyal_submit_listing_price'];
	} else {
		$casaroyal_submit_listing_price = '';
	}

	if(strlen($MODS['casaroyal_promoted_listing_price'])>0) {
	    $casaroyal_promoted_listing_price = $MODS['casaroyal_promoted_listing_price'];
	} else {
		$casaroyal_promoted_listing_price = '';
	}

	if(strlen($MODS['ft_featured_listing_price'])>0) {
	    $ft_featured_listing_price = $MODS['ft_featured_listing_price'];
	} else {
		$ft_featured_listing_price = '';
	}

	/**
	 * Featured Listings
	 */
	$featured_cron_jobs = array();
	$featured_cron_jobs = get_option( 'featured_cron_jobs' );
	$featured_cron_jobs[] = date("Y-m-d H:i:s");
	update_option( 'featured_cron_jobs', $featured_cron_jobs );

	// Change status to expired
	$search_args = array(
		'post_type'           => 'property',
		'posts_per_page'      => -1,
		'post_status'         => array( 'publish' ),
		'meta_query' => array(
		    array(
		        'key' => '_paid_ft_featured',
		        'value' => 1
		    )
		)
	);

	$cars_query = new WP_Query( $search_args );
	if ( $cars_query->have_posts() ) :

		while ( $cars_query->have_posts() ) : $cars_query->the_post();

			$car_id = get_the_ID();
			$user_id = get_the_author_meta( 'ID' );
			$user_meta = get_userdata($user_id); 
			$user_roles = $user_meta->roles; 

			$now = strtotime(date("Y-m-d H:i:s"));
			$next_payment = get_post_meta( $car_id, '_featured_next_payment', true );

			$amount = $ft_featured_listing_price;

			if( $now >= $next_payment ) {

				if( !in_array("administrator", $user_roles) AND !empty($casaroyal_monetization_status)  ) {

					if( casaroyal_user_sufficient_funds( $user_id, $amount ) ) {

						update_post_meta( $car_id, '_promoted', 0 );
						update_post_meta( $car_id, 'ft_featured', 1 );
						update_post_meta( $car_id, '_paid_ft_featured', 1 );
						casaroyal_update_menu_order( $car_id, 'ft_featured', 1 );

						$new_date_payment = strtotime("+ 1 day");
						update_post_meta( $car_id, '_featured_next_payment', $new_date_payment );

						if ( is_woocommerce_active() ) {

							casaroyal_WC_Account_Funds::remove_funds( $user_id, $amount );

						}

						casaroyal_user_save_payout( $user_id, $amount, $car_id, 'Featured' );

					} else {

						update_post_meta( $car_id, '_promoted', 0 );
						update_post_meta( $car_id, 'ft_featured', 0 );
						update_post_meta( $car_id, '_paid_ft_featured', 0 );
						casaroyal_update_menu_order( $car_id, 'ft_featured', 0 );

						update_post_meta( $car_id, '_featured_next_payment', '' );

					}

				} else {

					update_post_meta( $car_id, '_promoted', 0 );
					update_post_meta( $car_id, 'ft_featured', 1 );
					update_post_meta( $car_id, '_paid_ft_featured', 1 );
					casaroyal_update_menu_order( $car_id, 'ft_featured', 1 );

					$new_date_payment = strtotime("+ 1 day");
					update_post_meta( $car_id, '_featured_next_payment', $new_date_payment );

				}

			}

		endwhile;

	endif; wp_reset_postdata();

	/**
	 * Promoted Listings
	 */
	$promoted_cron_jobs = array();
	$promoted_cron_jobs = get_option( 'promoted_cron_jobs' );
	$promoted_cron_jobs[] = date("Y-m-d H:i:s");
	update_option( 'promoted_cron_jobs', $promoted_cron_jobs );

	// Change status to expired
	$search_args = array(
		'post_type'           => 'property',
		'posts_per_page'      => -1,
		'post_status'         => array( 'publish' ),
		'meta_query' => array(
		    array(
		        'key' => '_promoted',
		        'value' => 1
		    )
		)
	);

	$cars_query = new WP_Query( $search_args );
	if ( $cars_query->have_posts() ) :

		while ( $cars_query->have_posts() ) : $cars_query->the_post();

			$car_id = get_the_ID();
			$user_id = get_the_author_meta( 'ID' );
			$user_meta = get_userdata($user_id); 
			$user_roles = $user_meta->roles;

			$now = strtotime(date("Y-m-d H:i:s"));
			$next_payment = get_post_meta( $car_id, '_promoted_next_payment', true );

			$amount = $casaroyal_promoted_listing_price;

			if( $now >= $next_payment ) {

				if( !in_array("administrator", $user_roles) AND !empty($casaroyal_monetization_status) ) {

					if( casaroyal_user_sufficient_funds( $user_id, $amount ) ) {

						update_post_meta( $car_id, '_promoted', 1 );

						$time = current_time('mysql');

						$my_post = array(
						  	'ID' => $car_id,
						  	'post_status' => 'publish',
						  	'post_date'     => $time,
			        		'post_date_gmt' => get_gmt_from_date( $time )
					  	);

					  	wp_update_post( $my_post );

						$new_date_payment = strtotime("+ 1 day");
						update_post_meta( $car_id, '_promoted_next_payment', $new_date_payment );

						if ( is_woocommerce_active() ) {

							casaroyal_WC_Account_Funds::remove_funds( $user_id, $amount );

						}

						casaroyal_user_save_payout( $user_id, $amount, $car_id, 'Promoted' );

					} else {

						update_post_meta( $car_id, '_promoted', 0 );
						update_post_meta( $car_id, '_promoted_next_payment', '' );

					}

				} else {

					update_post_meta( $car_id, '_promoted', 1 );

					$time = current_time('mysql');

					$my_post = array(
					  	'ID' => $car_id,
					  	'post_status' => 'publish',
					  	'post_date'     => $time,
		        		'post_date_gmt' => get_gmt_from_date( $time )
				  	);

				  	wp_update_post( $my_post );

					$new_date_payment = strtotime("+ 1 day");
					update_post_meta( $car_id, '_promoted_next_payment', $new_date_payment );
					
				}

			}

		endwhile;

	endif; wp_reset_postdata();
}

// casaroyal Acount Funds Functions
/**
 * Required functions
 */
if ( ! function_exists( 'woothemes_queue_update' ) ) {
	require_once( 'account-funds/class-ft-wc-functions.php' );
}

if ( is_woocommerce_active() ) {

	/**
	 * casaroyal_WC_Account_Funds
	 */
	class casaroyal_WC_Account_Funds {

		/**
		 * Plugin's version.
		 *
		 * @var string
		 */

		/**
		 * Constructor
		 */
		public function __construct() {

			add_action( 'plugins_loaded', array( $this, 'init_early' ) );
			add_action( 'init', array( $this, 'init' ) );
			add_action( 'plugins_loaded', array( $this, 'gateway_init' ), 0 );
			add_action( 'init', array( $this, 'admin_init' ) );
			add_filter( 'woocommerce_email_classes', array( $this, 'add_email_classes' ), 99 );
			add_filter( 'woocommerce_payment_gateways', array( $this, 'register_gateway' ) );
			add_filter( 'woocommerce_data_stores', array( $this, 'add_data_stores' ) );
			
		}

		/**
		 * Classes that need to be loaded early.
		 *
		 * @since 2.0.12
		 */
		public function init_early() {
			include_once( 'account-funds/class-ft-account-funds-my-account.php' );
		}

		/**
		 * Load classes
		 */
		public function init() {
			include_once( 'account-funds/class-ft-product-deposit.php' );
			include_once( 'account-funds/class-ft-product-topup.php' );
			include_once( 'account-funds/class-ft-account-funds-cart-manager.php' );
			include_once( 'account-funds/class-ft-account-funds-deposits-manager.php' );
			include_once( 'account-funds/class-ft-account-funds-order-manager.php' );
			//include_once( 'account-funds/class-ft-account-funds-integration.php' );
			//include_once( 'account-funds/class-ft-account-funds-shortcodes.php' );
		}

		/**
		 * Init Gateway
		 */
		public function gateway_init() {
			if ( ! class_exists( 'WC_Payment_Gateway' ) ) {
				return;
			}
			include_once( 'account-funds/class-ft-gateway-account-funds.php' );
		}

		/**
		 * Load admin
		 */
		public function admin_init() {
			if ( is_admin() ) {
				include_once( 'account-funds/class-ft-account-funds-admin.php' );
				include_once( 'account-funds/class-ft-account-funds-admin-product.php' );
				include_once( 'account-funds/class-ft-account-funds-reports.php' );
			}
		}

		/**
		 *  Add email to the list of emails WooCommerce should load.
		 */
		public function add_email_classes( $email_classes ) {
			include_once( 'account-funds/class-ft-account-funds-email-account-funds-increase.php' );
			$email_classes['casaroyal_WC_Account_Funds_Email_Account_Funds_Increase'] = new casaroyal_WC_Account_Funds_Email_Account_Funds_Increase();
			return $email_classes;
		}

		/**
		 * Activation
		 */
		public function activate() {
			if ( ! class_exists( 'WC_Account_Funds_Installer' ) ) {
				include_once( 'account-funds/class-ft-account-funds-installer.php' );
			}
			WC_Account_Funds_Installer::install( $this->version );
			WC_Account_Funds_Installer::flush_rewrite_rules();
		}

		/**
		 * Get a users funds amount
		 * @param  int  $user_id
		 * @param  boolean $formatted
		 * @return string
		 */
		public static function get_account_funds( $user_id = null, $formatted = true, $exclude_order_id = 0 ) {
			$user_id = $user_id ? $user_id : get_current_user_id();

			if ( $user_id ) {
				$funds = max( 0, get_user_meta( $user_id, 'account_funds', true ) );

				// Account for pending orders
				$orders_with_pending_funds = get_posts( array(
					'numberposts' => -1,
					'post_type'   => 'shop_order',
					'post_status' => array_keys( wc_get_order_statuses() ),
					'fields'      => 'ids',
					'meta_query'  => array(
						array(
							'key'   => '_customer_user',
							'value' => $user_id
						),
						array(
							'key'   => '_funds_removed',
							'value' => '0',
						),
						array(
							'key'     => '_funds_used',
							'value'   => '0',
							'compare' => '>'
						)
					)
				) );

				foreach ( $orders_with_pending_funds as $order_id ) {
					if ( null !== WC()->session && ! empty( WC()->session->order_awaiting_payment ) && $order_id == WC()->session->order_awaiting_payment ) {
						continue;
					}
					if ( $exclude_order_id === $order_id ) {
						continue;
					}
					$funds = $funds - floatval( get_post_meta( $order_id, '_funds_used', true ) );
				}
			} else {
				$funds = 0;
			}

			return $formatted ? wc_price( $funds ) : $funds;
		}

		/**
		 * Add funds to user account
		 * @param int $customer_id
		 * @param float $amount
		 */
		public static function add_funds( $customer_id, $amount ) {
			$funds = get_user_meta( $customer_id, 'account_funds', true );
			$funds = $funds ? $funds : 0;
			$funds += floatval( $amount );
			update_user_meta( $customer_id, 'account_funds', $funds );
		}

		/**
		 * Remove funds from user account
		 * @param int $customer_id
		 * @param float $amount
		 */
		public static function remove_funds( $customer_id, $amount ) {
			$funds = get_user_meta( $customer_id, 'account_funds', true );
			$funds = $funds ? $funds : 0;
			$funds = $funds - floatval( $amount );
			update_user_meta( $customer_id, 'account_funds', max( 0, $funds ) );
		}

		/**
		 * Register the gateway for use
		 */
		public function register_gateway( $methods ) {
			$methods[] = 'casaroyal_WC_Gateway_Account_Funds';
			return $methods;
		}

		/**
		 * Add AF-related data stores.
		 *
		 * @param array $data_stores Data stores.
		 *
		 * @return array Data stores.
		 */
		public function add_data_stores( $data_stores ) {
			if ( ! class_exists( 'casaroyal_WC_Product_Topup_Data_Store' ) ) {
				require_once( 'account-funds/class-ft-product-topup-data-store.php' );
			}

			$data_stores['product-topup'] = 'casaroyal_WC_Product_Topup_Data_Store';

			return $data_stores;
		}

	}

	new casaroyal_WC_Account_Funds();

}

/**
 * casaroyal_Import_Demo
 */
class casaroyal_Import_Demo {

	public static function casaroyal_create_page( $slug, $option = '', $page_title = '', $page_content = '', $post_parent = 0, $template = '', $theme_mod = '' ) {
		global $wpdb;

		$option_value = get_option( $option );

		if ( $option_value > 0 && ( $page_object = get_post( $option_value ) ) ) {
			if ( 'page' === $page_object->post_type && ! in_array( $page_object->post_status, array( 'pending', 'trash', 'future', 'auto-draft' ) ) ) {
				// Valid page is already in place
				return $page_object->ID;
			}
		}

		if ( strlen( $page_content ) > 0 ) {
			// Search for an existing page with the specified page content (typically a shortcode)
			$valid_page_found = $wpdb->get_var( $wpdb->prepare( "SELECT ID FROM $wpdb->posts WHERE post_type='page' AND post_status NOT IN ( 'pending', 'trash', 'future', 'auto-draft' ) AND post_content LIKE %s LIMIT 1;", "%{$page_content}%" ) );
		} else {
			// Search for an existing page with the specified page slug
			$valid_page_found = $wpdb->get_var( $wpdb->prepare( "SELECT ID FROM $wpdb->posts WHERE post_type='page' AND post_status NOT IN ( 'pending', 'trash', 'future', 'auto-draft' )  AND post_name = %s LIMIT 1;", $slug ) );
		}

		$valid_page_found = apply_filters( 'casaroyal_create_page_id', $valid_page_found, $slug, $page_content );

		if ( $valid_page_found ) {
			if ( $option ) {
				update_option( $option, $valid_page_found );
			}
			return $valid_page_found;
		}

		// Search for a matching valid trashed page
		if ( strlen( $page_content ) > 0 ) {
			// Search for an existing page with the specified page content (typically a shortcode)
			$trashed_page_found = $wpdb->get_var( $wpdb->prepare( "SELECT ID FROM $wpdb->posts WHERE post_type='page' AND post_status = 'trash' AND post_content LIKE %s LIMIT 1;", "%{$page_content}%" ) );
		} else {
			// Search for an existing page with the specified page slug
			$trashed_page_found = $wpdb->get_var( $wpdb->prepare( "SELECT ID FROM $wpdb->posts WHERE post_type='page' AND post_status = 'trash' AND post_name = %s LIMIT 1;", $slug ) );
		}

		if ( $trashed_page_found ) {
			$page_id   = $trashed_page_found;
			$page_data = array(
				'ID'             => $page_id,
				'post_status'    => 'publish',
			);
		 	wp_update_post( $page_data );
		} else {
			$page_data = array(
				'post_status'    => 'publish',
				'post_type'      => 'page',
				'post_author'    => 1,
				'post_name'      => $slug,
				'post_title'     => $page_title,
				'post_content'   => $page_content,
				'post_parent'    => $post_parent,
				'comment_status' => 'closed',
			);
			$page_id = wp_insert_post( $page_data );
		}

		if ( $option ) {
			update_option( $option, $page_id );
		}

		if( $template ) {
			update_post_meta( $page_id, '_wp_page_template', $template );
		}

		if( $theme_mod ) {
			set_theme_mod($theme_mod, $page_id);
		}

		return $page_id;

	}

	public static function casaroyal_create_primary_menu( $slug, $page_id, $page_title, $parent_name, $is_parent, $menu_badge, $type, $url ) {

		$name = 'casaroyal Main Menu';
		$menu_id = wp_create_nav_menu($name);

		$menu = get_term_by( 'name', $name, 'nav_menu' );

		if( !empty($parent_name) ) {
			$parent_id = get_option( $parent_name.'_id' );
		} else {
			$parent = '';
			$parent_id = '';
		}

		if( $type == "custom" ) {
			$menuitem_id = wp_update_nav_menu_item($menu->term_id, 0, array(
				'menu-item-title' => $page_title,
				'menu-item-object-id' => $page_id,
				'menu-item-db-id' => 0,
				'menu-item-parent-id' => $parent_id,
				'menu-item-url' => $url,
				'menu-item-status' => 'publish',
				'menu-item-type' => 'custom',
			));
		} else {
			$page_name = get_the_title( $page_id );
			$menuitem_id = wp_update_nav_menu_item($menu->term_id, 0, array(
				'menu-item-title' => $page_name,
				'menu-item-object-id' => $page_id,
				'menu-item-db-id' => 0,
				'menu-item-parent-id' => $parent_id,
				'menu-item-object' => 'page',
				'menu-item-status' => 'publish',
				'menu-item-type' => 'post_type',
			));
		}

		if( $is_parent ) {
			update_option( $slug.'_id', $menuitem_id );
		}
		if( $menu_badge ) {
			update_post_meta( $menuitem_id, '_menu_item_'.$menu_badge, $menu_badge );
		}

		//then you set the wanted theme location
		$locations = get_theme_mod('nav_menu_locations');
		$locations['primary'] = $menu->term_id;
		set_theme_mod( 'nav_menu_locations', $locations );

	}

	public static function casaroyal_create_demo_page( $slug, $option = '', $page_title = '', $page_content = '', $is_parent = 0, $post_parent = 0, $template = '', $theme_mod = '', $homepage = 0, $hide_title = 0, $menu_badge = 0, $type = '', $url = '#' ) {
		global $wpdb;

		$page_id = '';

		if( $type == 'page' ) {

			if( $post_parent ) {
				$page = get_page_by_path($post_parent);
				if ($page) {
			        $post_parent_id = $page->ID;
			        $post_parent_name = get_the_title($post_parent_id);
			    } else {
			        $post_parent_id = '';
			        $post_parent_name = '';
			    }
			} else {
				$post_parent_id = '';
				$post_parent_name = '';
			}

			$page_data = array(
				'post_status'    => 'publish',
				'post_type'      => 'page',
				'post_author'    => 1,
				'post_name'      => $slug,
				'post_title'     => $page_title,
				'post_content'   => $page_content,
				'post_parent'    => $post_parent_id,
				'comment_status' => 'closed',
			);
			$page_id = wp_insert_post( $page_data );

			if ( $option ) {
				update_option( $option, $page_id );
			}

			if( $template ) {
				update_post_meta( $page_id, '_wp_page_template', $template );
			}

			if( $theme_mod ) {
				set_theme_mod($theme_mod, $page_id);
			}

			if( $homepage ) {
				update_option( 'page_on_front', $page_id );
				update_option( 'show_on_front', 'page' );
			}

			if( $hide_title ) {
				update_post_meta( $page_id, 'page_title', $hide_title );
			}

			self::casaroyal_create_primary_menu( $slug, $page_id, $page_title, $post_parent, $is_parent, $menu_badge, $type, $url );

			return $page_id;

		} elseif( $type == 'custom' ){

			self::casaroyal_create_primary_menu( $slug, $page_id, $page_title, $post_parent, $is_parent, $menu_badge, $type, $url );

		}

	}

	public static function casaroyal_get_page_id( $page ) {

		$page = apply_filters( 'casaroyal_get_' . $page . '_page_id', get_option( 'casaroyal_' . $page . '_page_id' ) );

		return $page ? absint( $page ) : -1;
	}

	/**
	 * Create pages that the plugin relies on, storing page IDs in variables.
	 */
	public static function create_pages() {

		$pages = apply_filters( 'casaroyal_import_demo', array(
			'search_properties' => array(
				'name'      => _x( 'search-properties', 'Page slug', 'casaroyal' ),
				'title'     => _x( 'Search Properties', 'Page title', 'casaroyal' ),
				'content'   => '',
				'template'  => 'templates/template-search-property.php',
				'theme_mod' => 'properties_search_url',
			),
			'compare_properties' => array(
				'name'      => _x( 'compare', 'Page slug', 'casaroyal' ),
				'title'     => _x( 'Compare', 'Page title', 'casaroyal' ),
				'content'   => '',
				'template'  => 'templates/template-compare.php',
				'theme_mod' => 'properties_compare_url',
			),
			'pending_review' => array(
				'name'      => _x( 'pending-review', 'Page slug', 'casaroyal' ),
				'title'     => _x( 'Pending Review', 'Page title', 'casaroyal' ),
				'content'   => '',
				'template'  => 'templates/template-pending-review.php',
				'theme_mod' => 'pending_review_page',
			),
			'my_listings' => array(
				'name'      => _x( 'my-listings', 'Page slug', 'casaroyal' ),
				'title'     => _x( 'My Listings', 'Page title', 'casaroyal' ),
				'content'   => '',
				'template'  => 'templates/template-my-listings.php',
				'theme_mod' => 'my_listings_page',
			),
			'submit_listing' => array(
				'name'      => _x( 'submit-listing', 'Page slug', 'casaroyal' ),
				'title'     => _x( 'Submit Listing', 'Page title', 'casaroyal' ),
				'content'   => '',
				'template'  => 'templates/template-submit-listing.php',
				'theme_mod' => 'submit_listing_page',
			),
			'my_favorites' => array(
				'name'      => _x( 'my-favorites', 'Page slug', 'casaroyal' ),
				'title'     => _x( 'My Favorites', 'Page title', 'casaroyal' ),
				'content'   => '',
				'template'  => 'templates/template-my-favorites.php',
				'theme_mod' => 'my_favorites_page',
			),
			'account_funds' => array(
				'name'      => _x( 'account-funds', 'Page slug', 'casaroyal' ),
				'title'     => _x( 'Account Funds', 'Page title', 'casaroyal' ),
				'content'   => '',
				'template'  => 'templates/template-account-funds.php',
				'theme_mod' => 'account_funds_page',
			),
			'account_settings' => array(
				'name'      => _x( 'account-settings', 'Page slug', 'casaroyal' ),
				'title'     => _x( 'Account Settings', 'Page title', 'casaroyal' ),
				'content'   => '',
				'template'  => 'templates/template-account-settings.php',
				'theme_mod' => 'account_settings',
			),
			'notifications' => array(
				'name'      => _x( 'notifications', 'Page slug', 'casaroyal' ),
				'title'     => _x( 'Notifications', 'Page title', 'casaroyal' ),
				'content'   => '',
				'template'  => 'templates/template-notifications.php',
				'theme_mod' => 'notifications_page',
			),
			'notification_subscribers' => array(
				'name'      => _x( 'notification-subscribers', 'Page slug', 'casaroyal' ),
				'title'     => _x( 'Notifications Subscribers', 'Page title', 'casaroyal' ),
				'content'   => '',
				'template'  => 'templates/template-notification-subscribers.php',
				'theme_mod' => 'notifications_subscribers',
			),
			'active_advertised_listings' => array(
				'name'      => _x( 'my-active-advertised-listings', 'Page slug', 'casaroyal' ),
				'title'     => _x( 'My Active Advertised Listings', 'Page title', 'casaroyal' ),
				'content'   => '',
				'template'  => 'templates/template-my-active-advertised-listings.php',
				'theme_mod' => 'my_advertised_listings_page',
			),
		) );

		foreach ( $pages as $key => $page ) {
			self::casaroyal_create_page( esc_sql( $page['name'] ), 'casaroyal_' . $key . '_page_id', $page['title'], $page['content'], ! empty( $page['parent'] ) ? casaroyal_get_page_id( $page['parent'] ) : '', $page['template'], $page['theme_mod'] );
		}

	}

	/**
	 * Create pages that the plugin relies on, storing page IDs in variables.
	 */
	public static function create_demo_pages() {

		$testimonial_bg_id = '';
		$testimonial_bg = get_option('testimonial_bg_id');
		if( !empty($testimonial_bg) ) {
			$testimonial_bg_id = $testimonial_bg;
		}
		$testimonial_bg_url = '';
		$testimonial_bg_u = get_option('testimonial_bg_url');
		if( !empty($testimonial_bg_u) ) {
			$testimonial_bg_url = $testimonial_bg_u;
		}

		$homepage = '[vc_row full_width="stretch_row_content_no_spaces" el_class="casaroyal-index"][vc_column][casaroyal_properties_asf title_color="#ffffff" subtitle_color="#ffffff" asf_type="minimalist" image="212" css=".vc_custom_1537882099197{margin-top: 150px !important;margin-bottom: 250px !important;}"][/vc_column][/vc_row][vc_row css=".vc_custom_1536142530607{margin-top: 60px !important;}"][vc_column][casaroyal_entry_title pretitle="casaroyal Real Estate Agency" title="Featured Properties" align="center"][/vc_column][/vc_row][vc_row css=".vc_custom_1536150331146{margin-bottom: 90px !important;}"][vc_column][casaroyal_properties_grid number="6" col="3col" type="featured"][vc_row_inner css=".vc_custom_1536150322080{margin-top: 30px !important;}"][vc_column_inner][casaroyal_button title="All Properties" align="center" use_theme_fonts="yes" button_size="medium" link="url:https%3A%2F%2Ffantasythemes.net%2Fthemes%2Fcasaroyal%2Fproperties%2Fproperties-grid-view%2F|||"][/vc_column_inner][/vc_row_inner][/vc_column][/vc_row][vc_row full_width="stretch_row" disable_element="yes" css=".vc_custom_1538396086652{padding-top: 60px !important;padding-bottom: 170px !important;background-color: #f3f3f3 !important;}"][vc_column][casaroyal_entry_title pretitle="casaroyal Real Estate Agency" title="About Us" align="center"][vc_row_inner][vc_column_inner width="1/3"][casaroyal_icon_box title="Our Goal" style="icon_top" box_style="boxed" add_icon="true" icon_type="linecons" icon_linecons="vc_li vc_li-location"]Is to meet every client needs and to offer him a great service. Nothing makes us happy than a satisfied client.[/casaroyal_icon_box][/vc_column_inner][vc_column_inner width="1/3"][casaroyal_icon_box title="Our Team" style="icon_top" box_style="boxed" animation_delay="150" add_icon="true" icon_type="linecons" icon_linecons="vc_li vc_li-user"]Of dedicated experts offer you the most innovative boutique-style service in the business.[/casaroyal_icon_box][/vc_column_inner][vc_column_inner width="1/3"][casaroyal_icon_box title="We Implement" style="icon_top" box_style="boxed" animation_delay="300" add_icon="true" icon_type="linecons" icon_linecons="vc_li vc_li-pen"]Creative marketing techniques, making the most of cutting-edge technology and social media.[/casaroyal_icon_box][/vc_column_inner][/vc_row_inner][/vc_column][/vc_row][vc_row][vc_column][casaroyal_entry_title pretitle="casaroyal Real Estate Agency" title="Hot Deal" align="center"][/vc_column][/vc_row][vc_row css=".vc_custom_1538396192247{padding-bottom: 120px !important;}"][vc_column][casaroyal_single_property post_id="48"][/vc_column][/vc_row][vc_row css=".vc_custom_1538425742289{padding-bottom: 90px !important;}"][vc_column][casaroyal_entry_title pretitle="casaroyal Real Estate Agency" title="Properties by Area" align="center"][casaroyal_properties_cities][/vc_column][/vc_row][vc_row full_width="stretch_row" el_class="casaroyal-background-grey" css=".vc_custom_1537953601951{padding-top: 30px !important;padding-bottom: 90px !important;}"][vc_column][casaroyal_entry_title pretitle="Meet our team" title="Our Agents" align="center"][ft_agents][/vc_column][/vc_row][vc_row full_width="stretch_row_content_no_spaces"][vc_column css=".vc_custom_1537948195154{padding-top: 0px !important;}"][casaroyal_promo title="Want to Sell Property?" title_color="#ffffff" content_text="Let us create a tailored strategic marketing plan and keep track of the selling process." content_color="#c6cbea" content_bg_color="#2842cd" add_button="true" button_text="More Details" add_icon="true" icon_fontawesome="fa fa-angle-right" image="516" bg_color="#2a41e8" css=".vc_custom_1537953461238{padding-top: 180px !important;padding-bottom: 180px !important;}"][/vc_column][/vc_row][vc_row full_width="stretch_row" css=".vc_custom_1538468481430{padding-top: 30px !important;background-color: #f3f3f3 !important;}" el_class="casaroyal-background-grey"][vc_column][casaroyal_entry_title pretitle="casaroyal News" title="Articles &amp; Tips" align="center"][/vc_column][/vc_row][vc_row full_width="stretch_row" css=".vc_custom_1538468487996{padding-bottom: 90px !important;background-color: #f3f3f3 !important;}" el_class="casaroyal-background-grey"][vc_column][casaroyal_blog_posts][/vc_column][/vc_row][vc_row full_width="stretch_row" css=".vc_custom_1538468487996{padding-bottom: 90px !important;background-color: #f3f3f3 !important;}" el_class="casaroyal-background-grey"][vc_column][vc_row_inner][vc_column_inner][casaroyal_button title="More Articles &amp; Tips" align="center" use_theme_fonts="yes" button_size="medium" link="url:https%3A%2F%2Ffantasythemes.net%2Fthemes%2Fcasaroyal%2Fblog%2Fblog-masonry%2F|||"][/vc_column_inner][/vc_row_inner][/vc_column][/vc_row][vc_row full_width="stretch_row" css=".vc_custom_1536155858713{padding-top: 30px !important;padding-bottom: 90px !important;background-color: #ffffff !important;}" el_class="casaroyal-background-grey"][vc_column][casaroyal_entry_title pretitle="casaroyal Real Estate Agency" title="Our Values" align="center"][vc_row_inner][vc_column_inner width="1/3"][casaroyal_icon_box title="Ensuring clear communication" style="icon_top" box_style="boxed" animation_delay="150" add_icon="true" icon_type="linecons" icon_linecons="vc_li vc_li-bubble"]We keep you in the loop every step of the way. You can rely on a transparent, comprehensible flow of information.[/casaroyal_icon_box][/vc_column_inner][vc_column_inner width="1/3"][casaroyal_icon_box title="Making the most of technology" style="icon_top" box_style="boxed" animation_delay="300" add_icon="true" icon_type="linecons" icon_linecons="vc_li vc_li-paperplane"]Time is precious. We guarantee a high degree of efficiency and a premium level of service by using the right tools.[/casaroyal_icon_box][/vc_column_inner][vc_column_inner width="1/3"][casaroyal_icon_box title="Providing excellent customer service" style="icon_top" box_style="boxed" animation_delay="450" add_icon="true" icon_type="linecons" icon_linecons="vc_li vc_li-heart"]We are passionate about what we do and we take pride in achieving the personalised results that you have in mind.[/casaroyal_icon_box][/vc_column_inner][/vc_row_inner][vc_row_inner][vc_column_inner][casaroyal_button title="Read More" align="center" use_theme_fonts="yes" button_size="medium" link="url:%23|||"][/vc_column_inner][/vc_row_inner][/vc_column][/vc_row][vc_row full_width="stretch_row" css=".vc_custom_1537869909373{padding-top: 60px !important;padding-bottom: 120px !important;background: #333333 url('.$testimonial_bg_u.'?id='.$testimonial_bg_id.') !important;background-position: center !important;background-repeat: no-repeat !important;background-size: cover !important;}"][vc_column][casaroyal_entry_title pretitle="Clients Reviews" pre_title_color="#f4f4f4" title="What Our Clients Say" title_color="#ffffff"][casaroyal_testimonial style="version_3" background="dark"][/vc_column][/vc_row]';

		$home_alt_header = '[vc_row full_width="stretch_row_content_no_spaces"][vc_column][casaroyal_properties_asf asf_type="minimalist" css=".vc_custom_1537172581276{margin-top: 150px !important;margin-bottom: 190px !important;}"][/vc_column][/vc_row][vc_row full_width="stretch_row" css=".vc_custom_1537173222033{padding-bottom: 120px !important;}"][vc_column][casaroyal_properties_carousel number="8"][/vc_column][/vc_row][vc_row full_width="stretch_row" css=".vc_custom_1537175672531{padding-top: 60px !important;padding-bottom: 90px !important;}" el_class="casaroyal-background-grey"][vc_column][casaroyal_entry_title pretitle="casaroyal Real Estate Agency" title="Properties by Area" align="center"][casaroyal_properties_cities][/vc_column][/vc_row][vc_row full_width="stretch_row" css=".vc_custom_1536155858713{padding-top: 30px !important;padding-bottom: 90px !important;background-color: #ffffff !important;}" el_class="casaroyal-background-grey"][vc_column][casaroyal_entry_title pretitle="casaroyal Real Estate Agency" title="Our Values" align="center"][vc_row_inner][vc_column_inner width="1/3"][casaroyal_icon_box title="Ensuring clear communication" style="icon_top" box_style="boxed" animation_delay="150" add_icon="true" icon_type="linecons" icon_linecons="vc_li vc_li-bubble"]We keep you in the loop every step of the way. You can rely on a transparent, comprehensible flow of information.[/casaroyal_icon_box][/vc_column_inner][vc_column_inner width="1/3"][casaroyal_icon_box title="Making the most of technology" style="icon_top" box_style="boxed" animation_delay="300" add_icon="true" icon_type="linecons" icon_linecons="vc_li vc_li-paperplane"]Time is precious. We guarantee a high degree of efficiency and a premium level of service by using the right tools.[/casaroyal_icon_box][/vc_column_inner][vc_column_inner width="1/3"][casaroyal_icon_box title="Providing excellent customer service" style="icon_top" box_style="boxed" animation_delay="450" add_icon="true" icon_type="linecons" icon_linecons="vc_li vc_li-heart"]We are passionate about what we do and we take pride in achieving the personalised results that you have in mind.[/casaroyal_icon_box][/vc_column_inner][/vc_row_inner][vc_row_inner][vc_column_inner][casaroyal_button title="Read More" align="center" use_theme_fonts="yes" button_size="medium" link="url:%23|||"][/vc_column_inner][/vc_row_inner][/vc_column][/vc_row][vc_row full_width="stretch_row_content_no_spaces"][vc_column css=".vc_custom_1537955442650{padding-top: 0px !important;}"][casaroyal_promo title="Want to Sell Property?" title_color="#ffffff" content_text="Let us create a tailored strategic marketing plan and keep track of the selling process." content_color="#c6cbea" content_bg_color="#2842cd" content_align="right" image="516" undefined="" css=".vc_custom_1537955499483{padding-top: 180px !important;padding-bottom: 180px !important;}"][/vc_column][/vc_row][vc_row css=".vc_custom_1537175769501{padding-bottom: 60px !important;}"][vc_column][casaroyal_entry_title pretitle="casaroyal News" title="Articles &amp; Tips" align="center"][vc_row_inner][vc_column_inner][casaroyal_blog_posts][/vc_column_inner][/vc_row_inner][/vc_column][/vc_row][vc_row full_width="stretch_row" css=".vc_custom_1537176174869{padding-top: 60px !important;padding-bottom: 60px !important;background-color: #ffffff !important;}"][vc_column][vc_column_text]
<h2 style="text-align: center;"><strong>Have Questions?</strong></h2>
<h4 style="text-align: center;">Call us for a Free Consultation at <a href="callto:#">(123) 456-7890</a></h4>
[/vc_column_text][/vc_column][/vc_row]';

		$home_map = '[vc_row full_width="stretch_row_content_no_spaces"][vc_column][casaroyal_properties_map height="560"][/vc_column][/vc_row][vc_row css=".vc_custom_1536142530607{margin-top: 60px !important;}"][vc_column][casaroyal_entry_title pretitle="casaroyal Real Estate Agency" title="Featured Properties" align="center"][/vc_column][/vc_row][vc_row css=".vc_custom_1536150331146{margin-bottom: 90px !important;}"][vc_column][casaroyal_properties_grid number="6" col="3col" type="featured"][vc_row_inner css=".vc_custom_1536150322080{margin-top: 30px !important;}"][vc_column_inner][casaroyal_button title="All Properties" align="center" use_theme_fonts="yes" button_size="medium" link="url:https%3A%2F%2Ffantasythemes.net%2Fthemes%2Fcasaroyal%2Fproperties%2Fproperties-grid-view%2F|||"][/vc_column_inner][/vc_row_inner][/vc_column][/vc_row][vc_row full_width="stretch_row" disable_element="yes" css=".vc_custom_1538396086652{padding-top: 60px !important;padding-bottom: 170px !important;background-color: #f3f3f3 !important;}"][vc_column][casaroyal_entry_title pretitle="casaroyal Real Estate Agency" title="About Us" align="center"][vc_row_inner][vc_column_inner width="1/3"][casaroyal_icon_box title="Our Goal" style="icon_top" box_style="boxed" add_icon="true" icon_type="linecons" icon_linecons="vc_li vc_li-location"]Is to meet every client needs and to offer him a great service. Nothing makes us happy than a satisfied client.[/casaroyal_icon_box][/vc_column_inner][vc_column_inner width="1/3"][casaroyal_icon_box title="Our Team" style="icon_top" box_style="boxed" animation_delay="150" add_icon="true" icon_type="linecons" icon_linecons="vc_li vc_li-user"]Of dedicated experts offer you the most innovative boutique-style service in the business.[/casaroyal_icon_box][/vc_column_inner][vc_column_inner width="1/3"][casaroyal_icon_box title="We Implement" style="icon_top" box_style="boxed" animation_delay="300" add_icon="true" icon_type="linecons" icon_linecons="vc_li vc_li-pen"]Creative marketing techniques, making the most of cutting-edge technology and social media.[/casaroyal_icon_box][/vc_column_inner][/vc_row_inner][/vc_column][/vc_row][vc_row][vc_column][casaroyal_entry_title pretitle="casaroyal Real Estate Agency" title="Hot Deal" align="center"][/vc_column][/vc_row][vc_row css=".vc_custom_1538396192247{padding-bottom: 120px !important;}"][vc_column][casaroyal_single_property post_id="48"][/vc_column][/vc_row][vc_row css=".vc_custom_1538425742289{padding-bottom: 90px !important;}"][vc_column][casaroyal_entry_title pretitle="casaroyal Real Estate Agency" title="Properties by Area" align="center"][casaroyal_properties_cities][/vc_column][/vc_row][vc_row full_width="stretch_row" el_class="casaroyal-background-grey" css=".vc_custom_1537953601951{padding-top: 30px !important;padding-bottom: 90px !important;}"][vc_column][casaroyal_entry_title pretitle="Meet our team" title="Our Agents" align="center"][ft_agents][/vc_column][/vc_row][vc_row full_width="stretch_row_content_no_spaces"][vc_column css=".vc_custom_1537948195154{padding-top: 0px !important;}"][casaroyal_promo title="Want to Sell Property?" title_color="#ffffff" content_text="Let us create a tailored strategic marketing plan and keep track of the selling process." content_color="#c6cbea" content_bg_color="#2842cd" add_button="true" button_text="More Details" add_icon="true" icon_fontawesome="fa fa-angle-right" image="516" bg_color="#2a41e8" css=".vc_custom_1537953461238{padding-top: 180px !important;padding-bottom: 180px !important;}"][/vc_column][/vc_row][vc_row full_width="stretch_row" css=".vc_custom_1538468481430{padding-top: 30px !important;background-color: #f3f3f3 !important;}" el_class="casaroyal-background-grey"][vc_column][casaroyal_entry_title pretitle="casaroyal News" title="Articles &amp; Tips" align="center"][/vc_column][/vc_row][vc_row full_width="stretch_row" css=".vc_custom_1538468487996{padding-bottom: 90px !important;background-color: #f3f3f3 !important;}" el_class="casaroyal-background-grey"][vc_column][casaroyal_blog_posts][/vc_column][/vc_row][vc_row full_width="stretch_row" css=".vc_custom_1538468487996{padding-bottom: 90px !important;background-color: #f3f3f3 !important;}" el_class="casaroyal-background-grey"][vc_column][vc_row_inner][vc_column_inner][casaroyal_button title="More Articles &amp; Tips" align="center" use_theme_fonts="yes" button_size="medium" link="url:https%3A%2F%2Ffantasythemes.net%2Fthemes%2Fcasaroyal%2Fblog%2Fblog-masonry%2F|||"][/vc_column_inner][/vc_row_inner][/vc_column][/vc_row][vc_row full_width="stretch_row" css=".vc_custom_1536155858713{padding-top: 30px !important;padding-bottom: 90px !important;background-color: #ffffff !important;}" el_class="casaroyal-background-grey"][vc_column][casaroyal_entry_title pretitle="casaroyal Real Estate Agency" title="Our Values" align="center"][vc_row_inner][vc_column_inner width="1/3"][casaroyal_icon_box title="Ensuring clear communication" style="icon_top" box_style="boxed" animation_delay="150" add_icon="true" icon_type="linecons" icon_linecons="vc_li vc_li-bubble"]We keep you in the loop every step of the way. You can rely on a transparent, comprehensible flow of information.[/casaroyal_icon_box][/vc_column_inner][vc_column_inner width="1/3"][casaroyal_icon_box title="Making the most of technology" style="icon_top" box_style="boxed" animation_delay="300" add_icon="true" icon_type="linecons" icon_linecons="vc_li vc_li-paperplane"]Time is precious. We guarantee a high degree of efficiency and a premium level of service by using the right tools.[/casaroyal_icon_box][/vc_column_inner][vc_column_inner width="1/3"][casaroyal_icon_box title="Providing excellent customer service" style="icon_top" box_style="boxed" animation_delay="450" add_icon="true" icon_type="linecons" icon_linecons="vc_li vc_li-heart"]We are passionate about what we do and we take pride in achieving the personalised results that you have in mind.[/casaroyal_icon_box][/vc_column_inner][/vc_row_inner][vc_row_inner][vc_column_inner][casaroyal_button title="Read More" align="center" use_theme_fonts="yes" button_size="medium" link="url:%23|||"][/vc_column_inner][/vc_row_inner][/vc_column][/vc_row][vc_row full_width="stretch_row" css=".vc_custom_1537869909373{padding-top: 60px !important;padding-bottom: 120px !important;background: #333333 url('.$testimonial_bg_u.'?id='.$testimonial_bg_id.''.$testimonial_bg_u.'?id='.$testimonial_bg_id.') !important;background-position: center !important;background-repeat: no-repeat !important;background-size: cover !important;}"][vc_column][casaroyal_entry_title pretitle="Clients Reviews" pre_title_color="#f4f4f4" title="What Our Clients Say" title_color="#ffffff"][casaroyal_testimonial style="version_3" background="dark"][/vc_column][/vc_row]';

		$home_with_slider = '[vc_row full_width="stretch_row_content_no_spaces"][vc_column][casaroyal_property_slider][/vc_column][/vc_row][vc_row full_width="stretch_row" css=".vc_custom_1512385950210{margin-bottom: 60px !important;}"][vc_column][vc_row_inner][vc_column_inner][casaroyal_entry_title pretitle="casaroyal Real Estate Agency" title="We are Offering the Best Estate Deals" align="center" css=".vc_custom_1537179379382{margin-top: 60px !important;margin-bottom: 90px !important;}"][/vc_column_inner][/vc_row_inner][/vc_column][/vc_row][vc_row full_width="stretch_row" css=".vc_custom_1512386112131{padding-top: 90px !important;padding-bottom: 30px !important;}" el_class="casaroyal-background-grey"][vc_column][casaroyal_properties_asf css=".vc_custom_1537179302503{margin-top: -230px !important;margin-bottom: 120px !important;}"][vc_row_inner][vc_column_inner width="1/3"][casaroyal_icon_box title="Whole World" style="icon_top_center_alt" icon_bg_color="#b88b58" box_style="boxed" animation_delay="150" add_icon="true" icon_type="linecons" icon_linecons="vc_li vc_li-world"]Deinde prima illa, quae in congressu solemus: Quid tu, inquit, huc? Est enim tanti philosophi tamque nobilis audacter sua decreta.[/casaroyal_icon_box][/vc_column_inner][vc_column_inner width="1/3"][casaroyal_icon_box title="Confidentially" style="icon_top_center_alt" icon_bg_color="#b88b58" box_style="boxed" animation_delay="300" add_icon="true" icon_type="linecons" icon_linecons="vc_li vc_li-lock"]Deinde prima illa, quae in congressu solemus: Quid tu, inquit, huc? Est enim tanti philosophi tamque nobilis audacter sua decreta.[/casaroyal_icon_box][/vc_column_inner][vc_column_inner width="1/3"][casaroyal_icon_box title="Good Previews" style="icon_top_center_alt" icon_bg_color="#b88b58" box_style="boxed" animation_delay="450" add_icon="true" icon_type="linecons" icon_linecons="vc_li vc_li-like"]Deinde prima illa, quae in congressu solemus: Quid tu, inquit, huc? Est enim tanti philosophi tamque nobilis audacter sua decreta.[/casaroyal_icon_box][/vc_column_inner][/vc_row_inner][/vc_column][/vc_row][vc_row css=".vc_custom_1512386269428{margin-bottom: 60px !important;}"][vc_column][casaroyal_entry_title pretitle="casaroyal Real Estate Agency" title="Featured Properties" align="center"][casaroyal_properties_grid number="6" col="3col" type="featured"][/vc_column][/vc_row][vc_row full_width="stretch_row" el_class="casaroyal-background-grey" css=".vc_custom_1537178815278{padding-top: 60px !important;padding-bottom: 120px !important;}"][vc_column][casaroyal_entry_title pretitle="Meet Our Team" title="Our Agents" align="center"][ft_agents][/vc_column][/vc_row][vc_row full_width="stretch_row"][vc_column][vc_row_inner][vc_column_inner][vc_column_text el_class="casaroyal-section-title"]
<h2>Get Started on Buying Your <strong>New Home</strong></h2>
[/vc_column_text][/vc_column_inner][/vc_row_inner][/vc_column][/vc_row]';

		$homepage_video_header = '[vc_row full_width="stretch_row_content_no_spaces" video_bg="yes" video_bg_url="https://www.youtube.com/watch?v=pY2CWYxUbrM"][vc_column][casaroyal_properties_asf title_color="#ffffff" subtitle_color="#ffffff" asf_type="minimalist" css=".vc_custom_1537186857498{margin-top: 150px !important;margin-bottom: 190px !important;}"][/vc_column][/vc_row][vc_row full_width="stretch_row" css=".vc_custom_1537881315687{padding-top: 60px !important;padding-bottom: 170px !important;background-color: #f3f3f3 !important;}"][vc_column][casaroyal_entry_title pretitle="casaroyal Real Estate Agency" title="About Us" align="center"][vc_row_inner][vc_column_inner width="1/3"][casaroyal_icon_box title="Our Goal" style="icon_top" box_style="boxed" add_icon="true" icon_type="linecons" icon_linecons="vc_li vc_li-location"]Is to meet every client needs and to offer him a great service. Nothing makes us happy than a satisfied client.[/casaroyal_icon_box][/vc_column_inner][vc_column_inner width="1/3"][casaroyal_icon_box title="Our Team" style="icon_top" box_style="boxed" animation_delay="150" add_icon="true" icon_type="linecons" icon_linecons="vc_li vc_li-user"]Of dedicated experts offer you the most innovative boutique-style service in the business.[/casaroyal_icon_box][/vc_column_inner][vc_column_inner width="1/3"][casaroyal_icon_box title="We Implement" style="icon_top" box_style="boxed" animation_delay="300" add_icon="true" icon_type="linecons" icon_linecons="vc_li vc_li-pen"]Creative marketing techniques, making the most of cutting-edge technology and social media.[/casaroyal_icon_box][/vc_column_inner][/vc_row_inner][casaroyal_entry_title pretitle="casaroyal Real Estate Agency" title="Hot Deal" align="center"][/vc_column][/vc_row][vc_row css=".vc_custom_1537953110468{padding-bottom: 120px !important;}"][vc_column][casaroyal_single_property post_id="48" css=".vc_custom_1537877615188{margin-top: -200px !important;}"][/vc_column][/vc_row][vc_row css=".vc_custom_1536142530607{margin-top: 60px !important;}"][vc_column][casaroyal_entry_title pretitle="casaroyal Real Estate Agency" title="Featured Properties" align="center"][/vc_column][/vc_row][vc_row css=".vc_custom_1536150331146{margin-bottom: 90px !important;}"][vc_column][casaroyal_properties_grid number="6" col="3col" type="featured"][vc_row_inner css=".vc_custom_1536150322080{margin-top: 30px !important;}"][vc_column_inner][casaroyal_button title="All Properties" align="center" use_theme_fonts="yes" button_size="medium" link="url:https%3A%2F%2Ffantasythemes.net%2Fthemes%2Fcasaroyal%2Fproperties%2Fproperties-grid-view%2F|||"][/vc_column_inner][/vc_row_inner][/vc_column][/vc_row][vc_row full_width="stretch_row_content_no_spaces"][vc_column css=".vc_custom_1537948195154{padding-top: 0px !important;}"][casaroyal_promo title="Want to Sell Property?" title_color="#ffffff" content_text="Let us create a tailored strategic marketing plan and keep track of the selling process." content_color="#c6cbea" content_bg_color="#2842cd" add_button="true" button_text="More Details" add_icon="true" icon_fontawesome="fa fa-angle-right" image="516" bg_color="#2a41e8" css=".vc_custom_1537953461238{padding-top: 180px !important;padding-bottom: 180px !important;}"][/vc_column][/vc_row][vc_row full_width="stretch_row" el_class="casaroyal-background-grey" css=".vc_custom_1537953601951{padding-top: 30px !important;padding-bottom: 90px !important;}"][vc_column][casaroyal_entry_title pretitle="Meet our team" title="Our Agents" align="center"][ft_agents][/vc_column][/vc_row][vc_row full_width="stretch_row" css=".vc_custom_1536155858713{padding-top: 30px !important;padding-bottom: 90px !important;background-color: #ffffff !important;}" el_class="casaroyal-background-grey"][vc_column][casaroyal_entry_title pretitle="casaroyal Real Estate Agency" title="Our Values" align="center"][vc_row_inner][vc_column_inner width="1/3"][casaroyal_icon_box title="Ensuring clear communication" style="icon_top" box_style="boxed" animation_delay="150" add_icon="true" icon_type="linecons" icon_linecons="vc_li vc_li-bubble"]We keep you in the loop every step of the way. You can rely on a transparent, comprehensible flow of information.[/casaroyal_icon_box][/vc_column_inner][vc_column_inner width="1/3"][casaroyal_icon_box title="Making the most of technology" style="icon_top" box_style="boxed" animation_delay="300" add_icon="true" icon_type="linecons" icon_linecons="vc_li vc_li-paperplane"]Time is precious. We guarantee a high degree of efficiency and a premium level of service by using the right tools.[/casaroyal_icon_box][/vc_column_inner][vc_column_inner width="1/3"][casaroyal_icon_box title="Providing excellent customer service" style="icon_top" box_style="boxed" animation_delay="450" add_icon="true" icon_type="linecons" icon_linecons="vc_li vc_li-heart"]We are passionate about what we do and we take pride in achieving the personalised results that you have in mind.[/casaroyal_icon_box][/vc_column_inner][/vc_row_inner][vc_row_inner][vc_column_inner][casaroyal_button title="Read More" align="center" use_theme_fonts="yes" button_size="medium" link="url:%23|||"][/vc_column_inner][/vc_row_inner][/vc_column][/vc_row][vc_row full_width="stretch_row" css=".vc_custom_1537869909373{padding-top: 60px !important;padding-bottom: 120px !important;background: #333333 url('.$testimonial_bg_u.'?id='.$testimonial_bg_id.') !important;background-position: center !important;background-repeat: no-repeat !important;background-size: cover !important;}"][vc_column][casaroyal_entry_title pretitle="Clients Reviews" pre_title_color="#f4f4f4" title="What Our Clients Say" title_color="#ffffff"][casaroyal_testimonial style="version_3" background="dark"][/vc_column][/vc_row]';

		$homepage_extended_search = '[vc_row full_width="stretch_row_content_no_spaces" el_class="casaroyal-index"][vc_column][casaroyal_properties_asf title_color="#ffffff" subtitle_color="#ffffff" image="287" css=".vc_custom_1538053123849{margin-top: 380px !important;margin-bottom: -190px !important;}"][/vc_column][/vc_row][vc_row full_width="stretch_row" css=".vc_custom_1538053203750{padding-top: 260px !important;padding-bottom: 30px !important;}" el_class="casaroyal-background-grey"][vc_column][casaroyal_entry_title pretitle="casaroyal Real Estate Agency" title="About Us" align="center"][vc_row_inner][vc_column_inner width="1/3"][casaroyal_icon_box title="Our Goal" style="icon_top" box_style="boxed" animation_delay="150" add_icon="true" icon_type="linecons" icon_linecons="vc_li vc_li-location"]Is to meet every client needs and to offer him a great service. Nothing makes us happy than a satisfied client.[/casaroyal_icon_box][/vc_column_inner][vc_column_inner width="1/3"][casaroyal_icon_box title="Our Team" style="icon_top" box_style="boxed" animation_delay="300" add_icon="true" icon_type="linecons" icon_linecons="vc_li vc_li-user"]Of dedicated experts offer you the most innovative boutique-style service in the business.[/casaroyal_icon_box][/vc_column_inner][vc_column_inner width="1/3"][casaroyal_icon_box title="We Implement" style="icon_top" box_style="boxed" animation_delay="450" add_icon="true" icon_type="linecons" icon_linecons="vc_li vc_li-pen"]Creative marketing techniques, making the most of cutting-edge technology and social media.[/casaroyal_icon_box][/vc_column_inner][/vc_row_inner][/vc_column][/vc_row][vc_row css=".vc_custom_1536142530607{margin-top: 60px !important;}"][vc_column][casaroyal_entry_title pretitle="casaroyal Real Estate Agency" title="Featured Properties" align="center"][/vc_column][/vc_row][vc_row css=".vc_custom_1536150331146{margin-bottom: 90px !important;}"][vc_column][casaroyal_properties_grid number="6" col="3col" type="featured"][vc_row_inner css=".vc_custom_1536150322080{margin-top: 30px !important;}"][vc_column_inner][casaroyal_button title="All Properties" align="center" use_theme_fonts="yes" button_size="medium" link="url:https%3A%2F%2Ffantasythemes.net%2Fthemes%2Fcasaroyal%2Fproperties%2Fproperties-grid-view%2F|||"][/vc_column_inner][/vc_row_inner][/vc_column][/vc_row][vc_row full_width="stretch_row" el_class="casaroyal-background-grey" css=".vc_custom_1512386880060{padding-bottom: 60px !important;}"][vc_column][casaroyal_entry_title pretitle="Meet our team" title="Our Agents" align="center"][ft_agents][/vc_column][/vc_row][vc_row full_width="stretch_row" css=".vc_custom_1536155858713{padding-top: 30px !important;padding-bottom: 90px !important;background-color: #ffffff !important;}" el_class="casaroyal-background-grey"][vc_column][casaroyal_entry_title pretitle="casaroyal Real Estate Agency" title="Our Values" align="center"][vc_row_inner][vc_column_inner width="1/3"][casaroyal_icon_box title="Ensuring clear communication" style="icon_top" box_style="boxed" animation_delay="150" add_icon="true" icon_type="linecons" icon_linecons="vc_li vc_li-bubble"]We keep you in the loop every step of the way. You can rely on a transparent, comprehensible flow of information.[/casaroyal_icon_box][/vc_column_inner][vc_column_inner width="1/3"][casaroyal_icon_box title="Making the most of technology" style="icon_top" box_style="boxed" animation_delay="300" add_icon="true" icon_type="linecons" icon_linecons="vc_li vc_li-paperplane"]Time is precious. We guarantee a high degree of efficiency and a premium level of service by using the right tools.[/casaroyal_icon_box][/vc_column_inner][vc_column_inner width="1/3"][casaroyal_icon_box title="Providing excellent customer service" style="icon_top" box_style="boxed" animation_delay="450" add_icon="true" icon_type="linecons" icon_linecons="vc_li vc_li-heart"]We are passionate about what we do and we take pride in achieving the personalised results that you have in mind.[/casaroyal_icon_box][/vc_column_inner][/vc_row_inner][vc_row_inner][vc_column_inner][casaroyal_button title="Read More" align="center" use_theme_fonts="yes" button_size="medium" link="url:%23|||"][/vc_column_inner][/vc_row_inner][/vc_column][/vc_row][vc_row full_width="stretch_row" css=".vc_custom_1536142602634{padding-top: 60px !important;padding-bottom: 90px !important;background: #333333 url('.$testimonial_bg_u.'?id='.$testimonial_bg_id.') !important;background-position: center !important;background-repeat: no-repeat !important;background-size: cover !important;}"][vc_column][casaroyal_entry_title pretitle="Clients Reviews" pre_title_color="#f4f4f4" title="What Our Clients Say" title_color="#ffffff" align="center" css=".vc_custom_1536132336175{margin-bottom: 60px !important;}"][casaroyal_testimonial style="version_3" background="dark"][/vc_column][/vc_row]';

		$coming_soon = '[vc_row full_width="stretch_row" full_height="yes" css=".vc_custom_1511358732709{background-image: url('.$testimonial_bg_u.'?id='.$testimonial_bg_id.') !important;background-position: center !important;background-repeat: no-repeat !important;background-size: cover !important;}"][vc_column][vc_row_inner][vc_column_inner width="1/6" offset="vc_hidden-sm vc_hidden-xs"][/vc_column_inner][vc_column_inner width="1/2"][vc_column_text css_animation="bottom-to-top" el_class="hero-content"]
<h2>LAUNCHING <strong>VERY SOON</strong></h2>
We’re currently working on our new website! Subscribe to our newsletter to get notified when we will go live.[/vc_column_text][casaroyal_social_shortcode facebook_link="#" twitter_link="#" dribbble_link="#" youtube_link="#" pinterest_link="#" instagram_link="#" linkedin_link="#" css=".vc_custom_1474638144747{margin-top: -20px !important;margin-left: -6px !important;padding-bottom: 30px !important;}"][/vc_column_inner][vc_column_inner width="1/3" offset="vc_hidden-sm vc_hidden-xs"][/vc_column_inner][/vc_row_inner][/vc_column][/vc_row]';

		$coming_soon_2 = '[vc_row full_width="stretch_row" full_height="yes" css=".vc_custom_1482450264041{background-color: #202125 !important;background-position: center !important;background-repeat: no-repeat !important;background-size: cover !important;}"][vc_column][vc_row_inner][vc_column_inner width="1/6" offset="vc_hidden-xs"][/vc_column_inner][vc_column_inner width="2/3"][casaroyal_flipclock end_date="2018/12/24 12:25:10" background="dark" css=".vc_custom_1536245002428{margin-top: -30px !important;padding-bottom: 30px !important;}"][vc_column_text css_animation="bottom-to-top"]
<h4 style="text-align: center;"><span style="color: #64666b;">LAUNCHING VERY SOON.</span></h4>
[/vc_column_text][/vc_column_inner][vc_column_inner width="1/6" offset="vc_hidden-xs"][/vc_column_inner][/vc_row_inner][/vc_column][/vc_row]';

		$maintenance = '[vc_row full_width="stretch_row" full_height="yes" css=".vc_custom_1511359593662{background-image: url('.$testimonial_bg_u.'?id='.$testimonial_bg_id.') !important;background-position: center !important;background-repeat: no-repeat !important;background-size: cover !important;}"][vc_column][vc_column_text css_animation="bottom-to-top" el_class="hero-content"]
<h2 style="text-align: center;">WE ARE UNDER</h2>
<h2 style="text-align: center;"><span class="highlight">MAINTENANCE</span></h2>
&nbsp;
<p style="text-align: center;">We are performing scheduled maintenance. We should be back online shortly.
<strong>Thanks for your patience.</strong>

[/vc_column_text][/vc_column][/vc_row]';

		$about = '[vc_row css_animation="none"][vc_column][vc_row_inner css=".vc_custom_1512399531693{padding-top: 60px !important;padding-bottom: 90px !important;}"][vc_column_inner][vc_column_text el_class="casaroyal-section-title"]
<h2 style="text-align: center;">We are Offering the <strong>Best Estate Deals</strong></h2>
[/vc_column_text][casaroyal_property_slider][/vc_column_inner][/vc_row_inner][/vc_column][/vc_row][vc_row css=".vc_custom_1512399585176{padding-bottom: 90px !important;}"][vc_column][vc_column_text el_class="casaroyal-section-title"]
<h2 style="text-align: center;">Our <strong>Services</strong></h2>
[/vc_column_text][vc_row_inner][vc_column_inner width="1/3"][casaroyal_icon_box title="Whole World" style="icon_top" box_style="boxed" add_icon="true" icon_type="linecons" icon_linecons="vc_li vc_li-world"]Pellentesque accumsan semper consectetur. Nullam volutpat euismod molestie. Vestibulum ante ipsum primis in faucibus.[/casaroyal_icon_box][/vc_column_inner][vc_column_inner width="1/3"][casaroyal_icon_box title="Confidentially" style="icon_top" box_style="boxed" add_icon="true" icon_type="linecons" icon_linecons="vc_li vc_li-lock"]Pellentesque accumsan semper consectetur. Nullam volutpat euismod molestie. Vestibulum ante ipsum primis in faucibus.[/casaroyal_icon_box][/vc_column_inner][vc_column_inner width="1/3"][casaroyal_icon_box title="Good Previews" style="icon_top" box_style="boxed" add_icon="true" icon_type="linecons" icon_linecons="vc_li vc_li-like"]Pellentesque accumsan semper consectetur. Nullam volutpat euismod molestie. Vestibulum ante ipsum primis in faucibus.[/casaroyal_icon_box][/vc_column_inner][/vc_row_inner][vc_row_inner][vc_column_inner width="1/3"][casaroyal_icon_box title="Investment Consulting" style="icon_top" box_style="boxed" add_icon="true" icon_type="linecons" icon_linecons="vc_li vc_li-banknote"]Pellentesque accumsan semper consectetur. Nullam volutpat euismod molestie. Vestibulum ante ipsum primis in faucibus .[/casaroyal_icon_box][/vc_column_inner][vc_column_inner width="1/3"][casaroyal_icon_box title="Construction Services" style="icon_top" box_style="boxed" add_icon="true" icon_fontawesome="fa fa-home"]Pellentesque accumsan semper consectetur. Nullam volutpat euismod molestie. Vestibulum ante ipsum primis in faucibus.[/casaroyal_icon_box][/vc_column_inner][vc_column_inner width="1/3"][casaroyal_icon_box title="Maintenance" style="icon_top" box_style="boxed" add_icon="true" icon_type="linecons" icon_linecons="vc_li vc_li-settings"]Pellentesque accumsan semper consectetur. Nullam volutpat euismod molestie. Vestibulum ante ipsum primis in faucibus.[/casaroyal_icon_box][/vc_column_inner][/vc_row_inner][/vc_column][/vc_row][vc_row css_animation="none" css=".vc_custom_1512399912183{padding-bottom: 30px !important;}"][vc_column][vc_column_text el_class="casaroyal-section-title"]
<h2 style="text-align: center;">Our <strong>Agents</strong></h2>
[/vc_column_text][ft_agents][/vc_column][/vc_row][vc_row css=".vc_custom_1512400168697{padding-top: 60px !important;padding-bottom: 90px !important;}"][vc_column][vc_column_text el_class="casaroyal-section-title"]
<h2 style="text-align: center;">Our <strong>Offices</strong></h2>
[/vc_column_text][vc_row_inner][vc_column_inner width="1/2"][casaroyal_map_shortcode lat="40.758058" lng=" -73.985582" image="112"][casaroyal_icon_box title="New York" style="icon_side" box_style="boxed" add_icon="true" icon_fontawesome="fa fa-dot-circle-o" css=".vc_custom_1482403334719{margin-top: 30px !important;}"]1545 Broadway
New York, NY 10036
+1 012 345 6789 newyork@casaroyal.com
<div class="casaroyal-button-container casaroyal-button-align-left casaroyal-button-icon-align-left casaroyal-button-style-default casaroyal-button-size-medium "><a class="btn-casaroyal" style="border-radius: 100px; text-align: left; margin-bottom: 0;" title="Get Directions" href="https://www.google.com/maps/dir/1545+Broadway,+New+York,+NY+10036/" target="">Get Directions</a></div>
[/casaroyal_icon_box][/vc_column_inner][vc_column_inner width="1/2"][casaroyal_map_shortcode lat="37.780119" lng="-122.434940" image="112"][casaroyal_icon_box title="San Francisco" style="icon_side" box_style="boxed" add_icon="true" icon_fontawesome="fa fa-dot-circle-o" css=".vc_custom_1482403481923{margin-top: 30px !important;}"]39 Lombard Street
San Francisco, CA94115
+1 812 345 6789 sanfrancisco@casaroyal.com
<div class="casaroyal-button-container casaroyal-button-align-left casaroyal-button-icon-align-left casaroyal-button-style-default casaroyal-button-size-medium "><a class="btn-casaroyal" style="border-radius: 100px; text-align: left; margin-bottom: 0;" title="Get Directions" href="https://www.google.com/maps/dir/1545+Broadway,+New+York,+NY+10036/" target="">Get Directions</a></div>
[/casaroyal_icon_box][/vc_column_inner][/vc_row_inner][/vc_column][/vc_row][vc_row css_animation="none" css=".vc_custom_1512399768178{padding-bottom: 30px !important;}"][vc_column][vc_column_text el_class="casaroyal-section-title"]
<h2 style="text-align: center;">Testimonials</h2>
[/vc_column_text][casaroyal_testimonial style="version_2"][/vc_column][/vc_row]';
	
		$contact_map_pin_id = '1418';
		$contact_map_pin = get_option('house-map-pin');
		if( !empty($contact_map_pin) ) {
			$contact_map_pin_id = $contact_map_pin;
		}

		$contact_form_id = '921';
		$contact_form = get_option('contact_form_7_id');
		if( !empty($contact_form) ) {
			$contact_form_id = $contact_form;
		}

		$contact = '[vc_row css=".vc_custom_1512390939253{margin-top: 60px !important;}"][vc_column][casaroyal_map_shortcode image="'.$contact_map_pin_id.'" height="670"][/vc_column][/vc_row][vc_row css=".vc_custom_1474626981153{padding-top: 60px !important;padding-bottom: 120px !important;}"][vc_column width="1/3"][vc_row_inner][vc_column_inner][vc_column_text css_animation="bottom-to-top"]
<h4>San Francisco</h4>
<strong>Address:</strong> 263 Clinton Park, San Francisco

<strong>Phone:</strong> +1 234 567 8901

<strong>Email:</strong> <em>email@yourcompany.com</em>

&nbsp;
<h4>New York</h4>
<strong>Address:</strong> 801 7th Avenue, New York, NY 10019

<strong>Phone:</strong> +1 908 765 4321

<strong>Email:</strong> <em>email@yourcompany.com</em>[/vc_column_text][/vc_column_inner][/vc_row_inner][/vc_column][vc_column width="2/3"][vc_column_text]
<h4>Drop us a message</h4>
[/vc_column_text][contact-form-7 id="'.$contact_form_id.'"][/vc_column][/vc_row]';
		
		$agent_page_url = '#';
		$agent_page_url = get_option( "agent_page_url" );

		$MODS = get_theme_mods();
	    foreach(casaroyal_defaults() as $mod=>$def) {if(!isset($MODS[$mod])){$MODS[$mod]=$def;}}
	    if( isset($MODS['properties_compare_url']) AND strlen($MODS['properties_compare_url'])>0) {
            $compare_page_url = get_permalink( $MODS['properties_compare_url'] );
        } else {
        	$compare_page_url = "#";
        }

        $error404_page_url = home_url( '/' ).'404';

        $search_results_url = home_url( '/' ).'?s=lorem';

		$pages = apply_filters( 'casaroyal_import_demo', array(
			'homepage' => array(
				'name'       => _x( 'homepage', 'Page slug', 'casaroyal' ),
				'title'      => _x( 'Homepage', 'Page title', 'casaroyal' ),
				'content'    => $homepage,
				'is_parent'  => 1,
				'parent'     => '',
				'template'   => 'templates/template-full-width.php',
				'theme_mod'  => '',
				'homepage'   => 1,
				'hide_title' => 2,
				'menu_badge' => 'hot_badge',
				'type'       => 'page',
				'url'        => '',
			),
			'homepage_alt_header' => array(
				'name'       => _x( 'homepage-alt-header', 'Page slug', 'casaroyal' ),
				'title'      => _x( 'Homepage - Alt Header', 'Page title', 'casaroyal' ),
				'content'    => $home_alt_header,
				'is_parent'  => 0,
				'parent'     => 'homepage',
				'template'   => 'templates/template-full-width.php',
				'theme_mod'  => '',
				'homepage'   => 0,
				'hide_title' => 2,
				'menu_badge' => '',
				'type'       => 'page',
				'url'        => '',
			),
			'homepage_map' => array(
				'name'       => _x( 'homepage-map', 'Page slug', 'casaroyal' ),
				'title'      => _x( 'Homepage - Map', 'Page title', 'casaroyal' ),
				'content'    => $home_map,
				'is_parent'  => 0,
				'parent'     => 'homepage',
				'template'   => 'templates/template-full-width.php',
				'theme_mod'  => '',
				'homepage'   => 0,
				'hide_title' => 2,
				'menu_badge' => 'new_badge',
				'type'       => 'page',
				'url'        => '',
			),
			'home_with_slider' => array(
				'name'       => _x( 'homepage-property-slider', 'Page slug', 'casaroyal' ),
				'title'      => _x( 'Homepage - Property Slider', 'Page title', 'casaroyal' ),
				'content'    => $home_with_slider,
				'is_parent'  => 0,
				'parent'     => 'homepage',
				'template'   => 'templates/template-full-width.php',
				'theme_mod'  => '',
				'homepage'   => 0,
				'hide_title' => 2,
				'menu_badge' => 'hot_badge',
				'type'       => 'page',
				'url'        => '',
			),
			'homepage_video_header' => array(
				'name'       => _x( 'homepage-video-header', 'Page slug', 'casaroyal' ),
				'title'      => _x( 'Homepage - Video Header', 'Page title', 'casaroyal' ),
				'content'    => $homepage_video_header,
				'is_parent'  => 0,
				'parent'     => 'homepage',
				'template'   => 'templates/template-full-width.php',
				'theme_mod'  => '',
				'homepage'   => 0,
				'hide_title' => 2,
				'menu_badge' => '',
				'type'       => 'page',
				'url'        => '',
			),
			'homepage_extended_search' => array(
				'name'       => _x( 'homepage-extended-search', 'Page slug', 'casaroyal' ),
				'title'      => _x( 'Homepage - Extended Search', 'Page title', 'casaroyal' ),
				'content'    => $homepage_extended_search,
				'is_parent'  => 0,
				'parent'     => 'homepage',
				'template'   => 'templates/template-full-width.php',
				'theme_mod'  => '',
				'homepage'   => 0,
				'hide_title' => 2,
				'menu_badge' => '',
				'type'       => 'page',
				'url'        => '',
			),
			'properties' => array(
				'name'       => _x( 'properties', 'Page slug', 'casaroyal' ),
				'title'      => _x( 'Properties', 'Page title', 'casaroyal' ),
				'content'    => '',
				'is_parent'  => 1,
				'parent'     => '',
				'template'   => 'templates/template-property-grid-listing.php',
				'theme_mod'  => '',
				'homepage'   => 0,
				'hide_title' => 1,
				'menu_badge' => '',
				'type'       => 'page',
				'url'        => '',
			),
			'properties_half_map_right' => array(
				'name'       => _x( 'properties-half-map-right', 'Page slug', 'casaroyal' ),
				'title'      => _x( 'Half Map Right', 'Page title', 'casaroyal' ),
				'content'    => '',
				'is_parent'  => 0,
				'parent'     => 'properties',
				'template'   => 'templates/template-property-half-map-right.php',
				'theme_mod'  => '',
				'homepage'   => 0,
				'hide_title' => 2,
				'menu_badge' => 'hot_badge',
				'type'       => 'page',
				'url'        => '',
			),
			'properties_half_map_left' => array(
				'name'       => _x( 'properties-half-map-left', 'Page slug', 'casaroyal' ),
				'title'      => _x( 'Half Map Left', 'Page title', 'casaroyal' ),
				'content'    => '',
				'is_parent'  => 0,
				'parent'     => 'properties',
				'template'   => 'templates/template-property-half-map-left.php',
				'theme_mod'  => '',
				'homepage'   => 0,
				'hide_title' => 2,
				'menu_badge' => 'new_badge',
				'type'       => 'page',
				'url'        => '',
			),
			'properties_grid_view' => array(
				'name'       => _x( 'properties-grid-view', 'Page slug', 'casaroyal' ),
				'title'      => _x( 'Grid View', 'Page title', 'casaroyal' ),
				'content'    => '',
				'is_parent'  => 0,
				'parent'     => 'properties',
				'template'   => 'templates/template-property-grid-listing.php',
				'theme_mod'  => '',
				'homepage'   => 0,
				'hide_title' => 1,
				'menu_badge' => '',
				'type'       => 'page',
				'url'        => '',
			),
			'properties_grid_view_map' => array(
				'name'       => _x( 'properties-grid-view-with-map', 'Page slug', 'casaroyal' ),
				'title'      => _x( 'Grid View With Map', 'Page title', 'casaroyal' ),
				'content'    => '',
				'is_parent'  => 0,
				'parent'     => 'properties',
				'template'   => 'templates/template-property-grid-listing-map.php',
				'theme_mod'  => '',
				'homepage'   => 0,
				'hide_title' => 1,
				'menu_badge' => '',
				'type'       => 'page',
				'url'        => '',
			),
			'properties_list_view' => array(
				'name'       => _x( 'properties-list-view', 'Page slug', 'casaroyal' ),
				'title'      => _x( 'List View', 'Page title', 'casaroyal' ),
				'content'    => '',
				'is_parent'  => 0,
				'parent'     => 'properties',
				'template'   => 'templates/template-property-list-listing.php',
				'theme_mod'  => '',
				'homepage'   => 0,
				'hide_title' => 1,
				'menu_badge' => '',
				'type'       => 'page',
				'url'        => '',
			),
			'properties_list_view_map' => array(
				'name'       => _x( 'properties-list-view-with-map', 'Page slug', 'casaroyal' ),
				'title'      => _x( 'List View With Map', 'Page title', 'casaroyal' ),
				'content'    => '',
				'is_parent'  => 0,
				'parent'     => 'properties',
				'template'   => 'templates/template-property-list-listing-map.php',
				'theme_mod'  => '',
				'homepage'   => 0,
				'hide_title' => 1,
				'menu_badge' => '',
				'type'       => 'page',
				'url'        => '',
			),
			'agents' => array(
				'name'       => _x( 'agents', 'Page slug', 'casaroyal' ),
				'title'      => _x( 'Agents', 'Page title', 'casaroyal' ),
				'content'    => '',
				'is_parent'  => 1,
				'parent'     => '',
				'template'   => 'templates/template-all-agent.php',
				'theme_mod'  => '',
				'homepage'   => 0,
				'hide_title' => 1,
				'menu_badge' => '',
				'type'       => 'page',
				'url'        => '',
			),
			'agents_list' => array(
				'name'       => _x( 'agents-list', 'Page slug', 'casaroyal' ),
				'title'      => _x( 'List View', 'Page title', 'casaroyal' ),
				'content'    => '',
				'is_parent'  => 0,
				'parent'     => 'agents',
				'template'   => 'templates/template-all-agent-v2.php',
				'theme_mod'  => '',
				'homepage'   => 0,
				'hide_title' => 1,
				'menu_badge' => '',
				'type'       => 'page',
				'url'        => '',
			),
			'agent_page' => array(
				'name'       => _x( 'agent-page', 'Page slug', 'casaroyal' ),
				'title'      => _x( 'Agent Page', 'Page title', 'casaroyal' ),
				'content'    => '',
				'is_parent'  => 0,
				'parent'     => 'agents',
				'template'   => '',
				'theme_mod'  => '',
				'homepage'   => 0,
				'hide_title' => 1,
				'menu_badge' => '',
				'type'       => 'custom',
				'url'        => $agent_page_url,
			),
			'pages' => array(
				'name'       => _x( 'pages', 'Page slug', 'casaroyal' ),
				'title'      => _x( 'Pages', 'Page title', 'casaroyal' ),
				'content'    => '',
				'is_parent'  => 1,
				'parent'     => '',
				'template'   => '',
				'theme_mod'  => '',
				'homepage'   => 0,
				'hide_title' => 1,
				'menu_badge' => 'megamenu',
				'type'       => 'custom',
				'url'        => '#',
			),
			'utility' => array(
				'name'       => _x( 'utility', 'Page slug', 'casaroyal' ),
				'title'      => _x( 'Utility', 'Page title', 'casaroyal' ),
				'content'    => '',
				'is_parent'  => 1,
				'parent'     => 'pages',
				'template'   => '',
				'theme_mod'  => '',
				'homepage'   => 0,
				'hide_title' => 1,
				'menu_badge' => '',
				'type'       => 'custom',
				'url'        => '#',
			),
			'utility_compare' => array(
				'name'       => _x( 'utility-compare-properties', 'Page slug', 'casaroyal' ),
				'title'      => _x( 'Compare Properties', 'Page title', 'casaroyal' ),
				'content'    => '',
				'is_parent'  => 0,
				'parent'     => 'utility',
				'template'   => '',
				'theme_mod'  => '',
				'homepage'   => 0,
				'hide_title' => 1,
				'menu_badge' => '',
				'type'       => 'custom',
				'url'        => $compare_page_url,
			),
			'utility_error_404' => array(
				'name'       => _x( 'utility-404', 'Page slug', 'casaroyal' ),
				'title'      => _x( 'Error 404', 'Page title', 'casaroyal' ),
				'content'    => '',
				'is_parent'  => 0,
				'parent'     => 'utility',
				'template'   => '',
				'theme_mod'  => '',
				'homepage'   => 0,
				'hide_title' => 1,
				'menu_badge' => '',
				'type'       => 'custom',
				'url'        => $error404_page_url,
			),
			'utility_coming_soon' => array(
				'name'       => _x( 'coming-soon', 'Page slug', 'casaroyal' ),
				'title'      => _x( 'Coming Soon', 'Page title', 'casaroyal' ),
				'content'    => $coming_soon,
				'is_parent'  => 0,
				'parent'     => 'utility',
				'template'   => 'template-blank-page.php',
				'theme_mod'  => '',
				'homepage'   => 0,
				'hide_title' => 1,
				'menu_badge' => '',
				'type'       => 'page',
				'url'        => '',
			),
			'utility_coming_soon_2' => array(
				'name'       => _x( 'coming-soon-2', 'Page slug', 'casaroyal' ),
				'title'      => _x( 'Coming Soon 2', 'Page title', 'casaroyal' ),
				'content'    => $coming_soon_2,
				'is_parent'  => 0,
				'parent'     => 'utility',
				'template'   => 'template-blank-page.php',
				'theme_mod'  => '',
				'homepage'   => 0,
				'hide_title' => 1,
				'menu_badge' => '',
				'type'       => 'page',
				'url'        => '',
			),
			'utility_maintenance' => array(
				'name'       => _x( 'maintenance', 'Page slug', 'casaroyal' ),
				'title'      => _x( 'Maintenance', 'Page title', 'casaroyal' ),
				'content'    => $maintenance,
				'is_parent'  => 0,
				'parent'     => 'utility',
				'template'   => 'template-blank-page.php',
				'theme_mod'  => '',
				'homepage'   => 0,
				'hide_title' => 1,
				'menu_badge' => '',
				'type'       => 'page',
				'url'        => '',
			),
			'utility_search_results' => array(
				'name'       => _x( 'search-results', 'Page slug', 'casaroyal' ),
				'title'      => _x( 'Search Results', 'Page title', 'casaroyal' ),
				'content'    => '',
				'is_parent'  => 0,
				'parent'     => 'utility',
				'template'   => '',
				'theme_mod'  => '',
				'homepage'   => 0,
				'hide_title' => 1,
				'menu_badge' => '',
				'type'       => 'custom',
				'url'        => $search_results_url,
			),
			'mega_menu_properties' => array(
				'name'       => _x( 'mega-properties', 'Page slug', 'casaroyal' ),
				'title'      => _x( 'Properties', 'Page title', 'casaroyal' ),
				'content'    => '',
				'is_parent'  => 1,
				'parent'     => 'pages',
				'template'   => '',
				'theme_mod'  => '',
				'homepage'   => 0,
				'hide_title' => 1,
				'menu_badge' => '',
				'type'       => 'custom',
				'url'        => '#',
			),
			'mega_properties_half_map_right' => array(
				'name'       => _x( 'mega-half-map-right', 'Page slug', 'casaroyal' ),
				'title'      => _x( 'Half Map Right', 'Page title', 'casaroyal' ),
				'content'    => '',
				'is_parent'  => 0,
				'parent'     => 'mega-properties',
				'template'   => 'templates/template-property-half-map-right.php',
				'theme_mod'  => '',
				'homepage'   => 0,
				'hide_title' => 2,
				'menu_badge' => 'hot_badge',
				'type'       => 'page',
				'url'        => '',
			),
			'mega_properties_half_map_left' => array(
				'name'       => _x( 'mega-half-map-left', 'Page slug', 'casaroyal' ),
				'title'      => _x( 'Half Map Left', 'Page title', 'casaroyal' ),
				'content'    => '',
				'is_parent'  => 0,
				'parent'     => 'mega-properties',
				'template'   => 'templates/template-property-half-map-left.php',
				'theme_mod'  => '',
				'homepage'   => 0,
				'hide_title' => 2,
				'menu_badge' => 'new_badge',
				'type'       => 'page',
				'url'        => '',
			),
			'mega_properties_grid_view' => array(
				'name'       => _x( 'mega-grid-view', 'Page slug', 'casaroyal' ),
				'title'      => _x( 'Grid View', 'Page title', 'casaroyal' ),
				'content'    => '',
				'is_parent'  => 0,
				'parent'     => 'mega-properties',
				'template'   => 'templates/template-property-grid-listing.php',
				'theme_mod'  => '',
				'homepage'   => 0,
				'hide_title' => 1,
				'menu_badge' => '',
				'type'       => 'page',
				'url'        => '',
			),
			'mega_properties_grid_view_map' => array(
				'name'       => _x( 'mega-grid-view-with-map', 'Page slug', 'casaroyal' ),
				'title'      => _x( 'Grid View With Map', 'Page title', 'casaroyal' ),
				'content'    => '',
				'is_parent'  => 0,
				'parent'     => 'mega-properties',
				'template'   => 'templates/template-property-grid-listing-map.php',
				'theme_mod'  => '',
				'homepage'   => 0,
				'hide_title' => 1,
				'menu_badge' => '',
				'type'       => 'page',
				'url'        => '',
			),
			'mega_properties_list_view' => array(
				'name'       => _x( 'mega-list-view', 'Page slug', 'casaroyal' ),
				'title'      => _x( 'List View', 'Page title', 'casaroyal' ),
				'content'    => '',
				'is_parent'  => 0,
				'parent'     => 'mega-properties',
				'template'   => 'templates/template-property-list-listing.php',
				'theme_mod'  => '',
				'homepage'   => 0,
				'hide_title' => 1,
				'menu_badge' => '',
				'type'       => 'page',
				'url'        => '',
			),
			'mega_properties_list_view_map' => array(
				'name'       => _x( 'mega-list-view-with-map', 'Page slug', 'casaroyal' ),
				'title'      => _x( 'List View With Map', 'Page title', 'casaroyal' ),
				'content'    => '',
				'is_parent'  => 0,
				'parent'     => 'mega-properties',
				'template'   => 'templates/template-property-list-listing-map.php',
				'theme_mod'  => '',
				'homepage'   => 0,
				'hide_title' => 1,
				'menu_badge' => '',
				'type'       => 'page',
				'url'        => '',
			),
			'blog' => array(
				'name'       => _x( 'blog', 'Page slug', 'casaroyal' ),
				'title'      => _x( 'Blog', 'Page title', 'casaroyal' ),
				'content'    => '',
				'is_parent'  => 1,
				'parent'     => 'pages',
				'template'   => 'templates/template-blog-big-cards.php',
				'theme_mod'  => '',
				'homepage'   => 0,
				'hide_title' => 1,
				'menu_badge' => '',
				'type'       => 'page',
				'url'        => '',
			),
			'blog_masonry' => array(
				'name'       => _x( 'blog-masonry', 'Page slug', 'casaroyal' ),
				'title'      => _x( 'Masonry', 'Page title', 'casaroyal' ),
				'content'    => '',
				'is_parent'  => 0,
				'parent'     => 'blog',
				'template'   => 'templates/template-blog.php',
				'theme_mod'  => '',
				'homepage'   => 0,
				'hide_title' => 1,
				'menu_badge' => '',
				'type'       => 'page',
				'url'        => '',
			),
			'blog_masonry_left' => array(
				'name'       => _x( 'blog-masonry-left', 'Page slug', 'casaroyal' ),
				'title'      => _x( 'Masonry Left Sidebar', 'Page title', 'casaroyal' ),
				'content'    => '',
				'is_parent'  => 0,
				'parent'     => 'blog',
				'template'   => 'templates/template-blog-left-sidebar.php',
				'theme_mod'  => '',
				'homepage'   => 0,
				'hide_title' => 1,
				'menu_badge' => '',
				'type'       => 'page',
				'url'        => '',
			),
			'blog_masonry_right' => array(
				'name'       => _x( 'blog-masonry-right', 'Page slug', 'casaroyal' ),
				'title'      => _x( 'Masonry Right Sidebar', 'Page title', 'casaroyal' ),
				'content'    => '',
				'is_parent'  => 0,
				'parent'     => 'blog',
				'template'   => 'templates/template-blog-right-sidebar.php',
				'theme_mod'  => '',
				'homepage'   => 0,
				'hide_title' => 1,
				'menu_badge' => '',
				'type'       => 'page',
				'url'        => '',
			),
			'blog_big_cards' => array(
				'name'       => _x( 'blog-big-cards', 'Page slug', 'casaroyal' ),
				'title'      => _x( 'Blog Big Cards', 'Page title', 'casaroyal' ),
				'content'    => '',
				'is_parent'  => 0,
				'parent'     => 'blog',
				'template'   => 'templates/template-blog-big-cards.php',
				'theme_mod'  => '',
				'homepage'   => 0,
				'hide_title' => 1,
				'menu_badge' => '',
				'type'       => 'page',
				'url'        => '',
			),
			'blog_big_cards_left' => array(
				'name'       => _x( 'blog-big-cards-left-sidebar', 'Page slug', 'casaroyal' ),
				'title'      => _x( 'Big Cards Left Sidebar', 'Page title', 'casaroyal' ),
				'content'    => '',
				'is_parent'  => 0,
				'parent'     => 'blog',
				'template'   => 'templates/template-blog-big-cards-left-sidebar.php',
				'theme_mod'  => '',
				'homepage'   => 0,
				'hide_title' => 1,
				'menu_badge' => '',
				'type'       => 'page',
				'url'        => '',
			),
			'blog_big_cards_right' => array(
				'name'       => _x( 'blog-big-cards-right-sidebar', 'Page slug', 'casaroyal' ),
				'title'      => _x( 'Big Cards Righ Sidebar', 'Page title', 'casaroyal' ),
				'content'    => '',
				'is_parent'  => 0,
				'parent'     => 'blog',
				'template'   => 'templates/template-blog-big-cards-right-sidebar.php',
				'theme_mod'  => '',
				'homepage'   => 0,
				'hide_title' => 1,
				'menu_badge' => '',
				'type'       => 'page',
				'url'        => '',
			),
			'about' => array(
				'name'       => _x( 'about-us', 'Page slug', 'casaroyal' ),
				'title'      => _x( 'About', 'Page title', 'casaroyal' ),
				'content'    => $about,
				'is_parent'  => 0,
				'parent'     => '',
				'template'   => 'templates/template-full-width.php',
				'theme_mod'  => '',
				'homepage'   => 0,
				'hide_title' => 2,
				'menu_badge' => '',
				'type'       => 'page',
				'url'        => '',
			),
			'contact' => array(
				'name'       => _x( 'our-contact', 'Page slug', 'casaroyal' ),
				'title'      => _x( 'Contact', 'Page title', 'casaroyal' ),
				'content'    => $contact,
				'is_parent'  => 0,
				'parent'     => '',
				'template'   => 'templates/template-full-width.php',
				'theme_mod'  => '',
				'homepage'   => 0,
				'hide_title' => 2,
				'menu_badge' => '',
				'type'       => 'page',
				'url'        => '',
			),
		) );

		foreach ( $pages as $key => $page ) {
			self::casaroyal_create_demo_page( esc_sql( $page['name'] ), 'casaroyal_' . $key . '_page_id', $page['title'], $page['content'], $page['is_parent'], $page['parent'], $page['template'], $page['theme_mod'], $page['homepage'], $page['hide_title'], $page['menu_badge'], $page['type'], $page['url'] );
		}

		// Add image covers to taxonomies
		$terms_city = get_terms( 'property-city', array('orderby' => 'count', 'order' => 'DESC', 'hide_empty' => 0) );
        $current_city = 0;
		if ( $terms_city ) {
			foreach ( $terms_city as $term_city ) {
				if( $current_city > 4) {
					$current_city = 0;
				}
				$current_city++;
				$image_id_city = get_option('properties_images_'.$current_city);
				if( !empty($image_id_city) ) {
                	update_term_meta( $term_city->term_id, 'pix_term_image', $image_id_city );
                }
			}
		} 

		$terms_type = get_terms( 'property-type', array('orderby' => 'count', 'order' => 'DESC', 'hide_empty' => 0) );
        $current_type = 0;
		if ( $terms_type ) {
			foreach ( $terms_type as $term_type ) {
				if( $current_type > 4) {
					$current_type = 0;
				}
				$current_type++;
				$image_id_type = get_option('properties_images_'.$current_type);
				if( !empty($image_id_type) ) {
                	update_term_meta( $term_type->term_id, 'pix_term_image', $image_id_type );
                }
			}
		} 

		// declare variables for widget
		$counter = 1;
		$active_widgets = array();
		$sidebars = array();

		// Register two sidebars.
		register_sidebar(array(
			'name' => esc_html__( 'Listing Sidebar', 'casaroyal' ),
			'id' => 'property-sidebar',
			'description' => esc_html__( 'Widgets in this area will be shown in the listing sidebar.', 'casaroyal' ),
			'before_title' => '<div class="widget-title-container"><h3 class="widget-title">',
			'after_title' => '</h3></div>',
			'before_widget' => '<div class="widget %2$s"><div class="widget-content">',
			'after_widget' => '</div><div class="clear"></div></div>'
		));
		register_sidebar(array(
			'name' => esc_html__( 'Single Listing Sidebar', 'casaroyal' ),
			'id' => 'single-property-sidebar',
			'description' => esc_html__( 'Widgets in this area will be shown in the single listing page sidebar.', 'casaroyal' ),
			'before_title' => '<div class="widget-title-container"><h3 class="widget-title">',
			'after_title' => '</h3></div>',
			'before_widget' => '<div class="widget %2$s"><div class="widget-content">',
			'after_widget' => '</div><div class="clear"></div></div>'
		));
		register_sidebar(array(
			'name' => esc_html__( 'Footer One (1/6)', 'casaroyal' ),
			'id' => 'footer-one',
			'description' => esc_html__( 'Widgets in this area will be shown in the footer one area.', 'casaroyal' ),
			'before_title' => '<div class="widget-title-container"><h3 class="widget-title">',
			'after_title' => '</h3></div>',
			'before_widget' => '<div class="widget %2$s"><div class="widget-content">',
			'after_widget' => '</div><div class="clear"></div></div>'
		));
		register_sidebar(array(
			'name' => esc_html__( 'Footer Two (1/6)', 'casaroyal' ),
			'id' => 'footer-two',
			'description' => esc_html__( 'Widgets in this area will be shown in the footer two area.', 'casaroyal' ),
			'before_title' => '<div class="widget-title-container"><h3 class="widget-title">',
			'after_title' => '</h3></div>',
			'before_widget' => '<div class="widget %2$s"><div class="widget-content">',
			'after_widget' => '</div><div class="clear"></div></div>'
		));
		register_sidebar(array(
			'name' => esc_html__( 'Footer Three (1/6)', 'casaroyal' ),
			'id' => 'footer-three',
			'description' => esc_html__( 'Widgets in this area will be shown in the footer three area.', 'casaroyal' ),
			'before_title' => '<div class="widget-title-container"><h3 class="widget-title">',
			'after_title' => '</h3></div>',
			'before_widget' => '<div class="widget %2$s"><div class="widget-content">',
			'after_widget' => '</div><div class="clear"></div></div>'
		));
		register_sidebar(array(
			'name' => esc_html__( 'Footer Four (1/6)', 'casaroyal' ),
			'id' => 'footer-four',
			'description' => esc_html__( 'Widgets in this area will be shown in the footer four area.', 'casaroyal' ),
			'before_title' => '<div class="widget-title-container"><h3 class="widget-title">',
			'after_title' => '</h3></div>',
			'before_widget' => '<div class="widget %2$s"><div class="widget-content">',
			'after_widget' => '</div><div class="clear"></div></div>'
		));
		register_sidebar(array(
			'name' => esc_html__( 'Footer Five (2/6)', 'casaroyal' ),
			'id' => 'footer-five',
			'description' => esc_html__( 'Widgets in this area will be shown in the footer five area.', 'casaroyal' ),
			'before_title' => '<div class="widget-title-container"><h3 class="widget-title">',
			'after_title' => '</h3></div>',
			'before_widget' => '<div class="widget %2$s"><div class="widget-content">',
			'after_widget' => '</div><div class="clear"></div></div>'
		));

		$active_widgets = array();

	    // Populate property-sidebar
	    $active_widgets['property-sidebar'][] = 'advance_search_widget-' . $counter;
	    $demo_widget_content[ $counter ] = array ( 'title' => 'Find Your Place' );
	    update_option( 'widget_advance_search_widget', $demo_widget_content );
	    $counter++;

	    // Populate single-property-sidebar
	    $active_widgets['single-property-sidebar'][] = 'advance_search_widget-' . $counter;
	    $demo_widget_content[ $counter ] = array ( 'title' => 'Find Your Place' );
	    update_option( 'widget_advance_search_widget', $demo_widget_content );
	    $counter++;

	    $active_widgets['single-property-sidebar'][] = 'ft_featured_properties_widget-' . $counter;
	    $demo_widget_content[ $counter ] = array ( 'widget_title' => 'Featured <strong>Properties</strong>', 'number' => '3' );
	    update_option( 'widget_ft_featured_properties_widget', $demo_widget_content );
	    $counter++;

	    $active_widgets['single-property-sidebar'][] = 'casaroyal_recent_properties_widget-' . $counter;
	    $demo_widget_content[ $counter ] = array ( 'widget_title' => 'Recent Properties', 'number' => '3' );
	    update_option( 'widget_casaroyal_recent_properties_widget', $demo_widget_content );
	    $counter++;

	    // Footer Widget One
	    $active_widgets['footer-one'][] = 'nav_menu-' . $counter;
	    // Delete menu if exists ro create a new one
	    $menu = get_term_by( 'name', 'casaroyal Information Menu - Footer Widget', 'nav_menu' );
		if( $menu ) {
			$menu_id = $menu->term_id;
			wp_delete_term( $menu_id, 'nav_menu' );
		}
		// Generate menu
	    $name = 'casaroyal Information Menu - Footer Widget';
		$menu_id = wp_create_nav_menu($name);
		if( $menu_id ) {
			$menu_items = array ( 'Our Contacts', 'Privacy Policy', 'Terms and Conditions', 'FAQs' );
			foreach ( $menu_items as $menu_item ) {
				$menuitem_id = wp_update_nav_menu_item($menu_id, 0, array(
					'menu-item-title' => $menu_item,
					'menu-item-db-id' => 0,
					'menu-item-url' => '#',
					'menu-item-status' => 'publish',
					'menu-item-type' => 'custom',
				));
			}
		}
	    //
	    $demo_widget_content[ $counter ] = array ( 'title' => 'Information', 'nav_menu' => $menu_id );
	    update_option( 'widget_nav_menu', $demo_widget_content );
	    $counter++;
	    // End Footer Widget One

	    // Footer Widget Two
	    $active_widgets['footer-two'][] = 'nav_menu-' . $counter;
	    // Delete menu if exists ro create a new one
	    $menu = get_term_by( 'name', 'casaroyal Properties Menu - Footer Widget', 'nav_menu' );
		if( $menu ) {
			$menu_id = $menu->term_id;
			wp_delete_term( $menu_id, 'nav_menu' );
		}
		// Generate menu
	    $name_properties = 'casaroyal Properties Menu - Footer Widget';
		$menu_properties_id = wp_create_nav_menu($name_properties);
		if( $menu_properties_id ) {
			$the_cats = get_terms( 'property-type', array('number' => 5) );
	        if (count($the_cats) > 0){
	            foreach($the_cats as $term){
	            	$term_url = get_term_link($term->slug, 'property-type');
					wp_update_nav_menu_item($menu_properties_id, 0, array(
					    'menu-item-title' => $term->name,
					    'menu-item-object-id' => $term->term_id,
					    'menu-item-db-id' => 0,
					    'menu-item-object' => 'property-type',
					    'menu-item-depth' => 1,
					    'menu-item-type' => 'taxonomy',
					    'menu-item-url' => $term_url,
					    'menu-item-status' => 'publish',)
					);
				}
	        }
		}
	    //
	    $demo_widget_content[ $counter ] = array ( 'title' => 'Properties', 'nav_menu' => $menu_properties_id );
	    update_option( 'widget_nav_menu', $demo_widget_content );
	    $counter++;
	    // End Footer Widget Two

	    // Footer Widget Three
	    $active_widgets['footer-three'][] = 'nav_menu-' . $counter;
	    // Delete menu if exists ro create a new one
	    $menu = get_term_by( 'name', 'casaroyal Locations Menu - Footer Widget', 'nav_menu' );
		if( $menu ) {
			$menu_id = $menu->term_id;
			wp_delete_term( $menu_id, 'nav_menu' );
		}
	    // Generate menu
	    $name_locations = 'casaroyal Locations Menu - Footer Widget';
		$menu_locations_id = wp_create_nav_menu($name_locations);
		if( $menu_locations_id ) {
			$the_cats = get_terms( 'property-city', array('number' => 5) );
	        if (count($the_cats) > 0){
	            foreach($the_cats as $term){
	            	$term_url = get_term_link($term->slug, 'property-city');
					wp_update_nav_menu_item($menu_locations_id, 0, array(
					    'menu-item-title' => $term->name,
					    'menu-item-object-id' => $term->term_id,
					    'menu-item-db-id' => 0,
					    'menu-item-object' => 'property-city',
					    'menu-item-depth' => 1,
					    'menu-item-type' => 'taxonomy',
					    'menu-item-url' => $term_url,
					    'menu-item-status' => 'publish',)
					);
				}
	        }
		}
	    //
	    $demo_widget_content[ $counter ] = array ( 'title' => 'Locations', 'nav_menu' => $menu_locations_id );
	    update_option( 'widget_nav_menu', $demo_widget_content );
	    $counter++;
	    // End Footer Widget Three

	    // Footer Widget Four
	    $active_widgets['footer-four'][] = 'nav_menu-' . $counter;
	    // Delete menu if exists ro create a new one
	    $menu = get_term_by( 'name', 'casaroyal Useful Links Menu - Footer Widget', 'nav_menu' );
		if( $menu ) {
			$menu_id = $menu->term_id;
			wp_delete_term( $menu_id, 'nav_menu' );
		}
	    // Generate menu
	    $name = 'casaroyal Useful Links Menu - Footer Widget';
		$menu_links_id = wp_create_nav_menu($name);
		if( $menu_links_id ) {
			$menu_items = array ( 'Blog', 'Our Contacts', 'Submit Listing', 'Support' );
			foreach ( $menu_items as $menu_item ) {
				$menuitem_id = wp_update_nav_menu_item($menu_links_id, 0, array(
					'menu-item-title' => $menu_item,
					'menu-item-db-id' => 0,
					'menu-item-url' => '#',
					'menu-item-status' => 'publish',
					'menu-item-type' => 'custom',
				));
			}
		}
	    //
	    $demo_widget_content[ $counter ] = array ( 'title' => 'Useful Links', 'nav_menu' => $menu_links_id );
	    update_option( 'widget_nav_menu', $demo_widget_content );
	    $counter++;
	    // End Footer Widget Four

	    $active_widgets['footer-five'][] = 'text-' . $counter;
	    $demo_widget_content[ $counter ] = array ( 'title' => 'About casaroyal', 'text' => '<p>casaroyal - Premium Real Estate Wordpress Theme by <a href="https://themeforest.net/user/fantasythemes/portfolio">FantasyThemes</a>.</p>

<p><i class="fa fa-location-arrow" style="width: 15px; text-align: center; margin-right: 4px; color: #676767;"></i> 111 Wall Street, USA, New York<br>
<i class="fa fa-mobile" style="width: 15px; text-align: center; margin-right: 4px; color: #676767;"></i> Phone: (123) 456-7890<br></p>

' );
	    update_option( 'widget_text', $demo_widget_content );
	    $counter++;

	    update_option( 'sidebars_widgets', $active_widgets );

	    // Delete Footer Menu if exists ro create a new one
	    $menu = get_term_by( 'name', 'casaroyal Footer Menu', 'nav_menu' );
		if( $menu ) {
			$menu_id = $menu->term_id;
			wp_delete_term( $menu_id, 'nav_menu' );
		}
	    // Footer Menu
	    $name_footer_menu = 'casaroyal Footer Menu';
		$menu_links_id = wp_create_nav_menu($name_footer_menu);
		if( $menu_links_id ) {
			$menu_items = array ( 'Privacy Policy', 'Terms and Conditions', 'Contact Us' );
			foreach ( $menu_items as $menu_item ) {
				$menuitem_id = wp_update_nav_menu_item($menu_links_id, 0, array(
					'menu-item-title' => $menu_item,
					'menu-item-db-id' => 0,
					'menu-item-url' => '#',
					'menu-item-status' => 'publish',
					'menu-item-type' => 'custom',
				));
			}
		}
		$locations = get_theme_mod('nav_menu_locations');
		$locations['secondary'] = $menu_links_id;
		set_theme_mod( 'nav_menu_locations', $locations );
	    //

	    // Add Snazzy Map Style
	    $map_style = Array(
					    'id' => '38',
					    'name' => 'Shades of Grey',
					    'description' => 'A map with various shades of grey. Great for a website with a really dark theme. ',
					    'url' => 'https://snazzymaps.com/style/38/shades-of-grey',
					    'imageUrl' => 'https://snazzy-maps-cdn.azureedge.net/assets/38-shades-of-grey.png?v=20170626083726',
					    'json' => '[{"featureType":"all","elementType":"labels.text.fill","stylers":[{"saturation":36},{"color":"#000000"},{"lightness":40}]},{"featureType":"all","elementType":"labels.text.stroke","stylers":[{"visibility":"on"},{"color":"#000000"},{"lightness":16}]},{"featureType":"all","elementType":"labels.icon","stylers":[{"visibility":"off"}]},{"featureType":"administrative","elementType":"geometry.fill","stylers":[{"color":"#000000"},{"lightness":20}]},{"featureType":"administrative","elementType":"geometry.stroke","stylers":[{"color":"#000000"},{"lightness":17},{"weight":1.2}]},{"featureType":"landscape","elementType":"geometry","stylers":[{"color":"#000000"},{"lightness":20}]},{"featureType":"poi","elementType":"geometry","stylers":[{"color":"#000000"},{"lightness":21}]},{"featureType":"road.highway","elementType":"geometry.fill","stylers":[{"color":"#000000"},{"lightness":17}]},{"featureType":"road.highway","elementType":"geometry.stroke","stylers":[{"color":"#000000"},{"lightness":29},{"weight":0.2}]},{"featureType":"road.arterial","elementType":"geometry","stylers":[{"color":"#000000"},{"lightness":18}]},{"featureType":"road.local","elementType":"geometry","stylers":[{"color":"#000000"},{"lightness":16}]},{"featureType":"transit","elementType":"geometry","stylers":[{"color":"#000000"},{"lightness":19}]},{"featureType":"water","elementType":"geometry","stylers":[{"color":"#000000"},{"lightness":17}]}]',
					    'views' => '339982',
					    'favorites' => '770',
					    'createdBy' => Array(
							            'name' => 'Adam Krogh',
							            'url' => 'https://twitter.com/adamkrogh',
							        ),
					    'createdOn' => '2013-11-12T18:21:41.94',
					    'tags' => Array('dark','greyscale' ),
					    'colors' => Array('black', 'gray'),
					);
		update_option( 'SnazzyMapDefaultStyle', $map_style );

	}

	public static function casaroyal_create_demo_property( $slug, $page_title = '', $post_parent = 0, $status = '', $type = '', $city = '', $feature = '', $meta = ''  ) {
		global $wpdb;

		$content = '';
		if( !empty($meta) ) {
			$content = $meta['casaroyal_property_description'];
		}

		$post_parent_id = '0';
		if( !empty($post_parent) ) {
			$property = get_page_by_path( $post_parent, OBJECT, 'property' );
			if( $property ) {
				$post_parent_id = $property->ID;
			}
		}

		$post_data = array(
			'post_status'    => 'publish',
			'post_type'      => 'property',
			'post_content'   => $content,
			'post_author'    => 1,
			'post_name'      => $slug,
			'post_title'     => $page_title,
			'comment_status' => 'closed',
			'post_parent'    => $post_parent_id,
		);
		$post_id = wp_insert_post( $post_data );

		if( !empty($status) ) {
			$term = get_term_by('name', $status, 'property-status');
			if( !empty($term) ) {
				$term_id = $term->term_id;
				wp_set_post_terms( $post_id, array( $term_id ), 'property-status' );
			}
		}

		if( !empty($type) ) {
			$term = get_term_by('name', $type, 'property-type');
			if( !empty($term) ) {
				$term_id = $term->term_id;
				wp_set_post_terms( $post_id, array( $term_id ), 'property-type' );
			}
		}

		if( !empty($city) ) {
			$term = get_term_by('name', $city, 'property-city');
			if( !empty($term) ) {
				$term_id = $term->term_id;
				wp_set_post_terms( $post_id, array( $term_id ), 'property-city' );
			}
		}

		if( !empty($feature) AND is_array($feature) ) {
			$term_id = array();
			foreach( $feature as $feature_one ) {
				$term = get_term_by('name', $feature_one, 'property-feature');
				if( !empty($term) ) {
					$term_id[] = $term->term_id;
				}
			}
			wp_set_post_terms( $post_id, $term_id, 'property-feature' );
		}

		if( !empty($meta) ) {

			foreach( $meta as $key => $meta_item ) {

				if( $key != "ft_agents" OR $key != "ft_property_images" OR $key != "ft_attachments" OR $key != "ft_add_in_slider" ) {
					update_post_meta( $post_id, $key, $meta_item );
				}

				if( $key == "ft_agents" ) {
					$all_agents_ids = get_posts(array(
				        'post_type' => 'agent',
				        'posts_per_page'=> -1,
				        'fields'        => 'ids', // Only get post IDs
				    ));
				    $unique_id = array_rand(array('0', '1', '2', '3'));
				    $agent_id = $all_agents_ids[$unique_id];
					update_post_meta( $post_id, $key, $agent_id );
				}

				if( $key == "ft_property_images" ) {
					$image_id = '';
					$rand_keys = array('1', '2', '3', '4');
					shuffle($rand_keys);
					foreach( $rand_keys as $rand_keys_item ) {
						$image_id = get_option('properties_images_'.$rand_keys_item);
						if( !empty($image_id) ) {
							add_post_meta( $post_id, $key, $image_id );
						}
					}
					if( !empty($image_id) ) {
						set_post_thumbnail( $post_id, $image_id );
					}
				}

				if( $key == "ft_add_in_slider" ) {
					if( $meta_item == "yes" ){
						$post_thumbnail_id = get_post_thumbnail_id( $post_id );
						if( !empty($post_thumbnail_id) ) {
							add_post_meta( $post_id, 'ft_slider_image', $post_thumbnail_id );
						}
					}
				}

				if( $key == "ft_attachments" ) {
					$attachment_id = '';
					$attachment_array_of_image_ids = array(1, 2, 3);
					$attachment_rand_keys = array_rand($attachment_array_of_image_ids, $meta_item);
					foreach( $attachment_rand_keys as $attachment_rand_keys_item ) {
						$attachment_id = get_option('properties_attachments_'.$attachment_rand_keys_item);
						if( !empty($attachment_id) ) {
							add_post_meta( $post_id, $key, $attachment_id );
						}
					}
				}

			}

		}

		return $post_id;

	}

	/**
	 * Create properties that the plugin relies on, storing property IDs in variables.
	 */
	public static function create_demo_properties() { 

		$properties = apply_filters( 'casaroyal_create_demo_properties', array(
			'property_1' => array(
				'name'       => _x( 'apartment-building-having-29-apartments', 'Page slug', 'casaroyal' ),
				'title'      => _x( 'Apartment Building Having 29 Apartments', 'Page title', 'casaroyal' ),
				'parent'     => '',
				'status'     => 'For Rent',
				'type'       => 'Residential Tower',
				'city'       => 'Los Angeles',
				'feature'    => array(
					'2 Stories',
					"26' Ceilings",
					'Central Heating',
					'Dual Sinks',
					'Electric Range',
					'Emergency Exit',
					'Fire Alarm',
					'Fire Place',
					'Hurricane Shutters',
					'Laundry Room',
					'Marble Floors',
					'NEXT to busway',
					'Swimming Pool',
					'Wifi',
				),
				'meta'       => array(
					'_promoted' => 0,
					'ft_featured' => 1,
					'casaroyal_property_description' => '<p>Lorem ipsum dolor sit amet, consectetuer adipiscing elit, sed diam nonummy nibh euismod tincidunt ut laoreet dolore magna aliquam erat volutpat. Ut wisi enim ad minim veniam, quis nostrud exerci tation ullamcorper suscipit lobortis nisl ut aliquip ex ea commodo consequat. Duis autem vel eum iriure dolor in hendrerit in vulputate velit esse molestie consequat, vel illum dolore eu feugiat nulla facilisis at vero eros et accumsan et iusto odio dignissim qui blandit praesent luptatum zzril delenit augue duis dolore te feugait nulla facilisi.</p><p>Nam liber tempor cum soluta nobis eleifend option congue nihil imperdiet doming id quod mazim placerat facer possim assum. Typi non habent claritatem insitam; est usus legentis in iis qui facit eorum claritatem. Investigationes demonstraverunt lectores legere me lius quod ii legunt saepius. Claritas est etiam processus dynamicus, qui sequitur mutationem consuetudium lectorum. Mirum est notare quam littera gothica, quam nunc putamus parum claram, anteposuerit litterarum formas humanitatis per seacula quarta decima et quinta decima. Eodem modo typi, qui nunc nobis videntur parum clari, fiant sollemnes in futurum.</p>', 
					'_sold' => 0,
					'_sold_date' => 0,
					'_paid_ft_featured' => 0,
					'ft_property_sku' => 'TXZ98666CCC',
					'ft_property_price' => '350',
					'ft_property_currency' => '$',
					'ft_property_size' => '1400',
					'ft_property_size_postfix' => 'Sq Ft',
					'ft_property_bedrooms' => '3',
					'ft_property_bathrooms' => '2',
					'ft_property_garage' => '2',
					'casaroyal_property_map' => 0,
					'ft_property_address' => '928-930 Geraghty Ave, Los Angeles, CA 90063, USA',
					'casaroyal_property_latitude' => '34.0469716687473',
					'casaroyal_property_longitude' => '-118.18308843393555',
					'ft_property_location' => '34.0469716687473,-118.18308843393555,14',
					'ft_property_address_city' => 'Los Angeles',
					'ft_property_address_zip' => '90063',
					'ft_property_address_state' => 'CA',
					'ft_property_address_country' => 'United States',
					'ft_agent_display_option' => 'agent_info',
					'ft_agents' => 'agent_id_1',
					'ft_property_price_prefix' => 'From',
					'ft_property_price_postfix' => 'Per Month',
					'ft_tour_video_url' => '<iframe width="930" height="525" src="https://www.youtube.com/embed/zvL0UmvPSEA" frameborder="0" allowfullscreen></iframe>',
					'casaroyal_additional_details' => array( 
						'No. Units' => '29',
						'Year Built' => '2011',
						'No. of Parking Spaces' => '36',
						'AC' => 'Ceiling Fan(s), Central',
						'Exterior Type' => 'Stucco',
					),
					'ft_virtual_tour_url' => '<iframe width="930" height="525" src="https://my.matterport.com/show/?m=JGPnGQ6hosj&play=1&qs=1" frameborder="0" allowfullscreen></iframe>',
					'ft_floor_plans' => array(
						'floor_1' => array(
							'ft_floor_plan_name' => '3 Bedrooms Apartment',
							'ft_floor_plan_price' => '210000',
							'ft_floor_plan_price_postfix' => '',
							'ft_floor_plan_size' => '2400',
							'ft_floor_plan_size_postfix' => 'Sq Ft',
							'ft_floor_plan_bedrooms' => '3',
							'ft_floor_plan_bathrooms' => '2',
							'ft_floor_plan_descr' => 'Claritas est etiam processus dynamicus, qui sequitur mutationem consuetudium lectorum. Mirum est notare quam littera gothica, quam nunc putamus parum claram, anteposuerit litterarum formas humanitatis per seacula quarta decima et quinta decima. Eodem modo typi, qui nunc nobis videntur parum clari, fiant sollemnes in futurum',
							'ft_floor_plan_image' => 'http:\/\/alexgurghis.com\/themes\/casaroyal\/wp-content\/uploads\/2014\/06\/plan-1.jpg',
						),
						'floor_2' => array(
							'ft_floor_plan_name' => '2 Bedrooms Apartment',
							'ft_floor_plan_price' => '230',
							'ft_floor_plan_price_postfix' => 'Per Month',
							'ft_floor_plan_size' => '1900',
							'ft_floor_plan_size_postfix' => 'Sq Ft',
							'ft_floor_plan_bedrooms' => '2',
							'ft_floor_plan_bathrooms' => '1',
							'ft_floor_plan_descr' => 'Duis autem vel eum iriure dolor in hendrerit in vulputate velit esse molestie consequat, vel illum dolore eu feugiat nulla facilisis at vero eros et accumsan et iusto odio dignissim qui blandit praesent luptatum zzril delenit augue duis dolore te feugait nulla facilisi',
							'ft_floor_plan_image' => 'http:\/\/alexgurghis.com\/themes\/casaroyal\/wp-content\/uploads\/2014\/06\/plan-2.jpg',
						),
					),
					'ft_nearby_health' => array(
						'1' => array( 
							'name' => 'Complete Care Community Health',
							'distance' => '2.5 miles',
						),
						'2' => array(
							'name' => 'Bascoy Medical Clinic: Bascoy Louis T MD',
							'distance' => '3.1 miles',
						),
					),
					'ft_nearby_transport' => array(
						'1' => array(
						 	'name' => 'Blanchard St. & Rowan Ave.',
						 	'distance' => '0.5 miles',
						),
						'2' => array(
							'name' => 'Easter Marianna',
							'distance' => '0.7 miles',
						),
						'3' => array(
							'name' => 'Hazard Ave & Dobinson S',
							'distance' => '0.9 miles',
						),
					),
					'ft_nearby_edu' => array(
						'1' => array(
							'name' => 'Belvedere Middle School',
							'distance' => '1.7 miles',
						),
						'2' => array(
							'name' => 'William R. Anton Elementary School',
							'distance' => '.3 miles',
						),
						'3' => array(
							'name' => 'Social Justice Leadership Academy',
							'distance' => '2.4 miles',
						),
					),
					'ft_property_images' => '4',
					'ft_attachments' => '2',
					'ft_add_in_slider' => 'yes',
				),
			),
			'property_2' => array(
				'name'       => _x( '14-apartments-of-type-a', 'Page slug', 'casaroyal' ),
				'title'      => _x( '14 Apartments of Type A', 'Page title', 'casaroyal' ),
				'parent'     => 'apartment-building-having-29-apartments',
				'status'     => 'For Sale',
				'type'       => 'Residential Tower',
				'city'       => 'Los Angeles',
				'feature'    => array(
					'2 Stories',
					"26' Ceilings",
					'Central Heating',
					'Dual Sinks',
					'Electric Range',
					'Emergency Exit',
					'Fire Alarm',
					'Fire Place',
					'Hurricane Shutters',
					'Laundry Room',
					'Marble Floors',
					'NEXT to busway',
					'Swimming Pool',
					'Wifi',
				),
				'meta'       => array(
					'_promoted' => 0,
					'ft_featured' => 1,
					'casaroyal_property_description' => '<p>Lorem ipsum dolor sit amet, consectetuer adipiscing elit, sed diam nonummy nibh euismod tincidunt ut laoreet dolore magna aliquam erat volutpat. Ut wisi enim ad minim veniam, quis nostrud exerci tation ullamcorper suscipit lobortis nisl ut aliquip ex ea commodo consequat. Duis autem vel eum iriure dolor in hendrerit in vulputate velit esse molestie consequat, vel illum dolore eu feugiat nulla facilisis at vero eros et accumsan et iusto odio dignissim qui blandit praesent luptatum zzril delenit augue duis dolore te feugait nulla facilisi.</p><p>Nam liber tempor cum soluta nobis eleifend option congue nihil imperdiet doming id quod mazim placerat facer possim assum. Typi non habent claritatem insitam; est usus legentis in iis qui facit eorum claritatem. Investigationes demonstraverunt lectores legere me lius quod ii legunt saepius. Claritas est etiam processus dynamicus, qui sequitur mutationem consuetudium lectorum. Mirum est notare quam littera gothica, quam nunc putamus parum claram, anteposuerit litterarum formas humanitatis per seacula quarta decima et quinta decima. Eodem modo typi, qui nunc nobis videntur parum clari, fiant sollemnes in futurum.</p>', 
					'_sold' => 0,
					'_sold_date' => 0,
					'_paid_ft_featured' => 0,
					'ft_property_sku' => 'RTD999ZZZI',
					'ft_property_price' => '310000',
					'ft_property_currency' => '$',
					'ft_property_size' => '1600',
					'ft_property_size_postfix' => 'Sq Ft',
					'ft_property_bedrooms' => '2',
					'ft_property_bathrooms' => '1',
					'ft_property_garage' => '1',
					'casaroyal_property_map' => 0,
					'ft_property_address' => '928-930 Geraghty Ave, Los Angeles, CA 90063, USA',
					'casaroyal_property_latitude' => '34.0469716687473',
					'casaroyal_property_longitude' => '-118.18308843393555',
					'ft_property_location' => '34.0469716687473,-118.18308843393555,14',
					'ft_property_address_city' => 'Los Angeles',
					'ft_property_address_zip' => '90063',
					'ft_property_address_state' => 'CA',
					'ft_property_address_country' => 'United States',
					'ft_agent_display_option' => 'agent_info',
					'ft_agents' => 'agent_id_1',
					'ft_tour_video_url' => '<iframe width="930" height="525" src="https://www.youtube.com/embed/zvL0UmvPSEA" frameborder="0" allowfullscreen></iframe>',
					'casaroyal_additional_details' => array( 
						'Year Built' => '2011',
						'AC' => 'Ceiling Fan(s), Central',
						'Exterior Type' => 'Stucco',
					),
					'ft_virtual_tour_url' => '<iframe width="930" height="525" src="https://my.matterport.com/show/?m=JGPnGQ6hosj&play=1&qs=1" frameborder="0" allowfullscreen></iframe>',
					'ft_nearby_health' => array(
						'1' => array( 
							'name' => 'Complete Care Community Health',
							'distance' => '2.5 miles',
						),
						'2' => array(
							'name' => 'Bascoy Medical Clinic: Bascoy Louis T MD',
							'distance' => '3.1 miles',
						),
					),
					'ft_nearby_transport' => array(
						'1' => array(
						 	'name' => 'Blanchard St. & Rowan Ave.',
						 	'distance' => '0.5 miles',
						),
						'2' => array(
							'name' => 'Easter Marianna',
							'distance' => '0.7 miles',
						),
						'3' => array(
							'name' => 'Hazard Ave & Dobinson S',
							'distance' => '0.9 miles',
						),
					),
					'ft_nearby_edu' => array(
						'1' => array(
							'name' => 'Belvedere Middle School',
							'distance' => '1.7 miles',
						),
						'2' => array(
							'name' => 'William R. Anton Elementary School',
							'distance' => '.3 miles',
						),
						'3' => array(
							'name' => 'Social Justice Leadership Academy',
							'distance' => '2.4 miles',
						),
					),
					'ft_property_images' => '4',
					'ft_attachments' => '2',
				),
			),
			'property_3' => array(
				'name'       => _x( '15-apartments-of-type-b', 'Page slug', 'casaroyal' ),
				'title'      => _x( '15 Apartments of Type B', 'Page title', 'casaroyal' ),
				'parent'     => 'apartment-building-having-29-apartments',
				'status'     => 'For Rent',
				'type'       => 'Residential Tower',
				'city'       => 'Los Angeles',
				'feature'    => array(
					'2 Stories',
					"26' Ceilings",
					'Central Heating',
					'Dual Sinks',
					'Electric Range',
					'Emergency Exit',
					'Fire Alarm',
					'Fire Place',
					'Hurricane Shutters',
					'Laundry Room',
					'Marble Floors',
					'NEXT to busway',
					'Swimming Pool',
					'Wifi',
				),
				'meta'       => array(
					'_sold' => 0,
					'_sold_date' => 0,
					'_promoted' => 0,
					'ft_featured' => 0,
					'_paid_ft_featured' => 0,
					'casaroyal_property_description' => '<p>Lorem ipsum dolor sit amet, consectetuer adipiscing elit, sed diam nonummy nibh euismod tincidunt ut laoreet dolore magna aliquam erat volutpat. Ut wisi enim ad minim veniam, quis nostrud exerci tation ullamcorper suscipit lobortis nisl ut aliquip ex ea commodo consequat. Duis autem vel eum iriure dolor in hendrerit in vulputate velit esse molestie consequat, vel illum dolore eu feugiat nulla facilisis at vero eros et accumsan et iusto odio dignissim qui blandit praesent luptatum zzril delenit augue duis dolore te feugait nulla facilisi.</p><p>Nam liber tempor cum soluta nobis eleifend option congue nihil imperdiet doming id quod mazim placerat facer possim assum. Typi non habent claritatem insitam; est usus legentis in iis qui facit eorum claritatem. Investigationes demonstraverunt lectores legere me lius quod ii legunt saepius. Claritas est etiam processus dynamicus, qui sequitur mutationem consuetudium lectorum. Mirum est notare quam littera gothica, quam nunc putamus parum claram, anteposuerit litterarum formas humanitatis per seacula quarta decima et quinta decima. Eodem modo typi, qui nunc nobis videntur parum clari, fiant sollemnes in futurum.</p>', 
					'ft_property_sku' => 'RTD777ZZZI',
					'ft_property_price' => '1700',
					'ft_property_currency' => '$',
					'ft_property_size' => '1600',
					'ft_property_price_prefix' => 'From',
					'ft_property_price_postfix' => 'Per Month',
					'ft_property_size_postfix' => 'Sq Ft',
					'ft_property_bedrooms' => '2',
					'ft_property_bathrooms' => '1',
					'ft_property_garage' => '1',
					'casaroyal_property_map' => 0,
					'ft_property_address' => '928-930 Geraghty Ave, Los Angeles, CA 90063, USA',
					'casaroyal_property_latitude' => '34.0469716687473',
					'casaroyal_property_longitude' => '-118.18308843393555',
					'ft_property_location' => '34.0469716687473,-118.18308843393555,14',
					'ft_property_address_city' => 'Los Angeles',
					'ft_property_address_zip' => '90063',
					'ft_property_address_state' => 'CA',
					'ft_property_address_country' => 'United States',
					'ft_agent_display_option' => 'agent_info',
					'ft_agents' => 'agent_id_1',
					'ft_tour_video_url' => '<iframe width="930" height="525" src="https://www.youtube.com/embed/zvL0UmvPSEA" frameborder="0" allowfullscreen></iframe>',
					'casaroyal_additional_details' => array( 
						'Year Built' => '2011',
						'No. of Parking Spaces' => '1',
						'AC' => 'Ceiling Fan(s), Central',
						'Exterior Type' => 'Stucco',
					),
					'ft_virtual_tour_url' => '<iframe width="930" height="525" src="https://my.matterport.com/show/?m=JGPnGQ6hosj&play=1&qs=1" frameborder="0" allowfullscreen></iframe>',
					'ft_nearby_health' => array(
						'1' => array( 
							'name' => 'Complete Care Community Health',
							'distance' => '2.5 miles',
						),
						'2' => array(
							'name' => 'Bascoy Medical Clinic: Bascoy Louis T MD',
							'distance' => '3.1 miles',
						),
					),
					'ft_nearby_transport' => array(
						'1' => array(
						 	'name' => 'Blanchard St. & Rowan Ave.',
						 	'distance' => '0.5 miles',
						),
						'2' => array(
							'name' => 'Easter Marianna',
							'distance' => '0.7 miles',
						),
						'3' => array(
							'name' => 'Hazard Ave & Dobinson S',
							'distance' => '0.9 miles',
						),
					),
					'ft_nearby_edu' => array(
						'1' => array(
							'name' => 'Belvedere Middle School',
							'distance' => '1.7 miles',
						),
						'2' => array(
							'name' => 'William R. Anton Elementary School',
							'distance' => '.3 miles',
						),
						'3' => array(
							'name' => 'Social Justice Leadership Academy',
							'distance' => '2.4 miles',
						),
					),
					'ft_property_images' => '4',
					'ft_attachments' => '2',
				),
			),
			'property_4' => array(
				'name'       => _x( 'countryside-modern-summer-house', 'Page slug', 'casaroyal' ),
				'title'      => _x( 'Countryside Modern Summer House', 'Page title', 'casaroyal' ),
				'parent'     => '',
				'status'     => 'For Rent',
				'type'       => 'Summer House',
				'city'       => 'Pasadena',
				'feature'    => array(
					'Central Heating',
					'Fire Alarm',
					'Fire Place',
					'Laundry Room',
					'Marble Floors',
					'Lawn',
					'Swimming Pool',
					'Wifi',
				),
				'meta'       => array(
					'_sold' => 0,
					'_sold_date' => 0,
					'_promoted' => 0,
					'ft_featured' => 1,
					'_paid_ft_featured' => 0,
					'casaroyal_property_description' => '<p>Lorem ipsum dolor sit amet, consectetuer adipiscing elit, sed diam nonummy nibh euismod tincidunt ut laoreet dolore magna aliquam erat volutpat. Ut wisi enim ad minim veniam, quis nostrud exerci tation ullamcorper suscipit lobortis nisl ut aliquip ex ea commodo consequat. Duis autem vel eum iriure dolor in hendrerit in vulputate velit esse molestie consequat, vel illum dolore eu feugiat nulla facilisis at vero eros et accumsan et iusto odio dignissim qui blandit praesent luptatum zzril delenit augue duis dolore te feugait nulla facilisi.</p><p>Nam liber tempor cum soluta nobis eleifend option congue nihil imperdiet doming id quod mazim placerat facer possim assum. Typi non habent claritatem insitam; est usus legentis in iis qui facit eorum claritatem. Investigationes demonstraverunt lectores legere me lius quod ii legunt saepius. Claritas est etiam processus dynamicus, qui sequitur mutationem consuetudium lectorum. Mirum est notare quam littera gothica, quam nunc putamus parum claram, anteposuerit litterarum formas humanitatis per seacula quarta decima et quinta decima. Eodem modo typi, qui nunc nobis videntur parum clari, fiant sollemnes in futurum.</p>', 
					'ft_property_sku' => 'BDD111-RTY768',
					'ft_property_price' => '1300',
					'ft_property_currency' => '$',
					'ft_property_size' => '3200',
					'ft_property_price_prefix' => 'From',
					'ft_property_price_postfix' => 'Per Month',
					'ft_property_size_postfix' => 'Sq Ft',
					'ft_property_bedrooms' => '4',
					'ft_property_bathrooms' => '3',
					'ft_property_garage' => '4',
					'casaroyal_property_map' => 0,
					'ft_property_address' => '940 N Lake Ave, Pasadena, CA 91104, USA',
					'casaroyal_property_latitude' => '34.16212464691759',
					'casaroyal_property_longitude' => '-118.13206066015624',
					'ft_property_location' => '34.16212464691759,-118.13206066015624',
					'ft_property_address_city' => 'Pasadena',
					'ft_property_address_zip' => '91104',
					'ft_property_address_state' => 'CA',
					'ft_property_address_country' => 'United States',
					'ft_agent_display_option' => 'agent_info',
					'ft_agents' => 'agent_id_2',
					'ft_tour_video_url' => '<iframe width="930" height="525" src="https://www.youtube.com/embed/zvL0UmvPSEA" frameborder="0" allowfullscreen></iframe>',
					'casaroyal_additional_details' => array( 
						'Year Built' => '2016',
						'No. of Parking Spaces' => '4',
						'AC' => 'Ceiling Fan(s), Central',
						'Exterior Type' => 'Stucco',
					),
					'ft_virtual_tour_url' => '<iframe width="930" height="525" src="https://my.matterport.com/show/?m=JGPnGQ6hosj&play=1&qs=1" frameborder="0" allowfullscreen></iframe>',
					'ft_floor_plans' => array(
						'floor_1' => array(
							'ft_floor_plan_name' => '3 Bedrooms',
							'ft_floor_plan_price' => '',
							'ft_floor_plan_price_postfix' => '',
							'ft_floor_plan_size' => '2400',
							'ft_floor_plan_size_postfix' => 'Sq Ft',
							'ft_floor_plan_bedrooms' => '3',
							'ft_floor_plan_bathrooms' => '2',
							'ft_floor_plan_descr' => 'Claritas est etiam processus dynamicus, qui sequitur mutationem consuetudium lectorum. Mirum est notare quam littera gothica, quam nunc putamus parum claram, anteposuerit litterarum formas humanitatis per seacula quarta decima et quinta decima. Eodem modo typi, qui nunc nobis videntur parum clari, fiant sollemnes in futurum',
							'ft_floor_plan_image' => 'http:\/\/alexgurghis.com\/themes\/casaroyal\/wp-content\/uploads\/2014\/06\/plan-1.jpg',
						),
						'floor_2' => array(
							'ft_floor_plan_name' => '2 Bedrooms',
							'ft_floor_plan_price' => '',
							'ft_floor_plan_price_postfix' => '',
							'ft_floor_plan_size' => '1900',
							'ft_floor_plan_size_postfix' => 'Sq Ft',
							'ft_floor_plan_bedrooms' => '2',
							'ft_floor_plan_bathrooms' => '1',
							'ft_floor_plan_descr' => 'Duis autem vel eum iriure dolor in hendrerit in vulputate velit esse molestie consequat, vel illum dolore eu feugiat nulla facilisis at vero eros et accumsan et iusto odio dignissim qui blandit praesent luptatum zzril delenit augue duis dolore te feugait nulla facilisi',
							'ft_floor_plan_image' => 'http:\/\/alexgurghis.com\/themes\/casaroyal\/wp-content\/uploads\/2014\/06\/plan-2.jpg',
						),
					),
					'ft_nearby_health' => array(
						'1' => array( 
							'name' => 'Planned Parenthood - Pasadena Health Center',
							'distance' => '0.3 miles',
						),
						'2' => array(
							'name' => 'Pasadena Urgent Care & Mediccal Center',
							'distance' => '3.4 miles',
						),
					),
					'ft_nearby_transport' => array(
						'1' => array(
						 	'name' => 'Lake / Orange Grove',
						 	'distance' => '0.7 miles',
						),
						'2' => array(
							'name' => 'Lake Ave. & Santa Barbara St',
							'distance' => '1.2 miles',
						),
						'3' => array(
							'name' => 'Los Robles / Mountain',
							'distance' => '0.9 miles',
						),
					),
					'ft_nearby_edu' => array(
						'1' => array(
							'name' => 'Pasadena Forward School',
							'distance' => '0.2 miles',
						),
						'2' => array(
							'name' => 'Madison Elementary School',
							'distance' => '1.3 miles',
						),
						'3' => array(
							'name' => 'Friends Western School',
							'distance' => '1.4 miles',
						),
					),
					'ft_property_images' => '4',
					'ft_attachments' => '2',
				),
			),
			'property_5' => array(
				'name'       => _x( '26502-via-cuervo-mission-viejo-ca-92691-usa', 'Page slug', 'casaroyal' ),
				'title'      => _x( '26502 Vía Cuervo, Mission Viejo, CA 92691, USA', 'Page title', 'casaroyal' ),
				'parent'     => '',
				'status'     => 'For Sale',
				'type'       => 'House',
				'city'       => 'Mission Viejo',
				'feature'    => array(
					'2 Stories',
					'Central Heating',
					'Fire Alarm',
					'Fire Place',
					'Laundry Room',
					'Marble Floors',
					'Lawn',
					'Swimming Pool',
					'Wifi',
				),
				'meta'       => array(
					'_sold' => 0,
					'_sold_date' => 0,
					'_promoted' => 0,
					'ft_featured' => 1,
					'_paid_ft_featured' => 0,
					'casaroyal_property_description' => '<p>Lorem ipsum dolor sit amet, consectetuer adipiscing elit, sed diam nonummy nibh euismod tincidunt ut laoreet dolore magna aliquam erat volutpat. Ut wisi enim ad minim veniam, quis nostrud exerci tation ullamcorper suscipit lobortis nisl ut aliquip ex ea commodo consequat. Duis autem vel eum iriure dolor in hendrerit in vulputate velit esse molestie consequat, vel illum dolore eu feugiat nulla facilisis at vero eros et accumsan et iusto odio dignissim qui blandit praesent luptatum zzril delenit augue duis dolore te feugait nulla facilisi.</p><p>Nam liber tempor cum soluta nobis eleifend option congue nihil imperdiet doming id quod mazim placerat facer possim assum. Typi non habent claritatem insitam; est usus legentis in iis qui facit eorum claritatem. Investigationes demonstraverunt lectores legere me lius quod ii legunt saepius. Claritas est etiam processus dynamicus, qui sequitur mutationem consuetudium lectorum. Mirum est notare quam littera gothica, quam nunc putamus parum claram, anteposuerit litterarum formas humanitatis per seacula quarta decima et quinta decima. Eodem modo typi, qui nunc nobis videntur parum clari, fiant sollemnes in futurum.</p>', 
					'ft_property_sku' => 'RJT67345GH',
					'ft_property_price' => '160000',
					'ft_property_currency' => '$',
					'ft_property_size' => '1400',
					'ft_property_price_prefix' => '',
					'ft_property_price_postfix' => '',
					'ft_property_size_postfix' => 'Sq Ft',
					'ft_property_bedrooms' => '3',
					'ft_property_bathrooms' => '4',
					'ft_property_garage' => '2',
					'casaroyal_property_map' => 0,
					'ft_property_address' => '26502 Vía Cuervo, Mission Viejo, CA 92691, USA',
					'casaroyal_property_latitude' => '33.62437995917103',
					'casaroyal_property_longitude' => '-117.66748949726559',
					'ft_property_location' => '33.62437995917103,-117.66748949726559',
					'ft_property_address_city' => 'Mission Viejo',
					'ft_property_address_zip' => '92691',
					'ft_property_address_state' => 'CA',
					'ft_property_address_country' => 'United States',
					'ft_agent_display_option' => 'agent_info',
					'ft_agents' => 'agent_id_2',
					'ft_tour_video_url' => '<iframe width="930" height="525" src="https://www.youtube.com/embed/zvL0UmvPSEA" frameborder="0" allowfullscreen></iframe>',
					'casaroyal_additional_details' => array( 
						'Year Built' => '2012',
						'No. of Parking Spaces' => '2',
						'AC' => 'Ceiling Fan(s), Central',
						'Exterior Type' => 'Stucco',
					),
					'ft_virtual_tour_url' => '<iframe width="930" height="525" src="https://my.matterport.com/show/?m=JGPnGQ6hosj&play=1&qs=1" frameborder="0" allowfullscreen></iframe>',
					'ft_nearby_health' => array(
						'1' => array( 
							'name' => 'Fountain Valley Orthotics',
							'distance' => '3.3 miles',
						),
						'2' => array(
							'name' => 'Royale Mission Viejo Health',
							'distance' => '3.5 miles',
						),
						'3' => array(
							'name' => 'Royale Mission Viejo Health',
							'distance' => '3.6 miles',
						),
					),
					'ft_nearby_transport' => array(
						'1' => array(
						 	'name' => 'Alicia-Via Leon',
						 	'distance' => '1.2 miles',
						),
						'2' => array(
							'name' => 'Alicia-Coronel',
							'distance' => '1.2 miles',
						),
						'3' => array(
							'name' => 'Los Alisos-Madero',
							'distance' => '1.9 miles',
						),
					),
					'ft_nearby_edu' => array(
						'1' => array(
							'name' => 'Glen Yermo Elementary School',
							'distance' => '0.3 miles',
						),
						'2' => array(
							'name' => 'Mission Viejo Montessori',
							'distance' => '0.7 miles',
						),
						'3' => array(
							'name' => 'Oxford Preparatory Academy',
							'distance' => '0.9 miles',
						),
					),
					'ft_property_images' => '4',
					'ft_attachments' => '2',
					'ft_add_in_slider' => 'yes',
				),
			),
			'property_6' => array(
				'name'       => _x( '2710-hilltop-dr-newport-beach-ca-92660-usa', 'Page slug', 'casaroyal' ),
				'title'      => _x( '2710 Hilltop Dr, Newport Beach, CA 92660, USA', 'Page title', 'casaroyal' ),
				'parent'     => '',
				'status'     => 'For Rent',
				'type'       => 'Office',
				'city'       => 'Newport Beach',
				'feature'    => array(
					'Emergency Exit',
					'Fire Alarm',
					'NEXT to busway',
					'Wifi',
				),
				'meta'       => array(
					'_sold' => 0,
					'_sold_date' => 0,
					'_promoted' => 0,
					'ft_featured' => 1,
					'_paid_ft_featured' => 0,
					'casaroyal_property_description' => '<p>Lorem ipsum dolor sit amet, consectetuer adipiscing elit, sed diam nonummy nibh euismod tincidunt ut laoreet dolore magna aliquam erat volutpat. Ut wisi enim ad minim veniam, quis nostrud exerci tation ullamcorper suscipit lobortis nisl ut aliquip ex ea commodo consequat. Duis autem vel eum iriure dolor in hendrerit in vulputate velit esse molestie consequat, vel illum dolore eu feugiat nulla facilisis at vero eros et accumsan et iusto odio dignissim qui blandit praesent luptatum zzril delenit augue duis dolore te feugait nulla facilisi.</p><p>Nam liber tempor cum soluta nobis eleifend option congue nihil imperdiet doming id quod mazim placerat facer possim assum. Typi non habent claritatem insitam; est usus legentis in iis qui facit eorum claritatem. Investigationes demonstraverunt lectores legere me lius quod ii legunt saepius. Claritas est etiam processus dynamicus, qui sequitur mutationem consuetudium lectorum. Mirum est notare quam littera gothica, quam nunc putamus parum claram, anteposuerit litterarum formas humanitatis per seacula quarta decima et quinta decima. Eodem modo typi, qui nunc nobis videntur parum clari, fiant sollemnes in futurum.</p>', 
					'ft_property_sku' => 'TGUY23487ZXC',
					'ft_property_price' => '900',
					'ft_property_currency' => '$',
					'ft_property_size' => '1300',
					'ft_property_price_prefix' => '',
					'ft_property_price_postfix' => '',
					'ft_property_size_postfix' => 'Sq Ft',
					'ft_property_bedrooms' => '3',
					'ft_property_bathrooms' => '3',
					'ft_property_garage' => '6',
					'casaroyal_property_map' => 0,
					'ft_property_address' => '2710 Hilltop Dr, Newport Beach, CA 92660, USA',
					'casaroyal_property_latitude' => '33.62597159612059',
					'casaroyal_property_longitude' => '-117.84682488359374',
					'ft_property_location' => '33.62597159612059,-117.84682488359374',
					'ft_property_address_city' => 'Newport Beach',
					'ft_property_address_zip' => '92660',
					'ft_property_address_state' => 'CA',
					'ft_property_address_country' => 'United States',
					'ft_agent_display_option' => 'agent_info',
					'ft_agents' => 'agent_id_2',
					'ft_tour_video_url' => '<iframe width="930" height="525" src="https://www.youtube.com/embed/zvL0UmvPSEA" frameborder="0" allowfullscreen></iframe>',
					'casaroyal_additional_details' => array( 
						'Year Built' => '2010',
						'No. of Parking Spaces' => '30',
						'AC' => 'Ceiling Fan(s), Central',
						'Exterior Type' => 'Stucco',
					),
					'ft_virtual_tour_url' => '<iframe width="930" height="525" src="https://my.matterport.com/show/?m=JGPnGQ6hosj&play=1&qs=1" frameborder="0" allowfullscreen></iframe>',
					'ft_nearby_health' => array(
						'1' => array( 
							'name' => 'Marque Urgen Care',
							'distance' => '3 miles',
						),
						'2' => array(
							'name' => 'Kan Newport Group LLC',
							'distance' => '3.2 miles',
						),
					),
					'ft_nearby_transport' => array(
						'1' => array(
						 	'name' => 'San Miguel - Port Ramsey',
						 	'distance' => '0.1 miles',
						),
						'2' => array(
							'name' => 'San Miguel Eastgate',
							'distance' => '0.2 miles',
						),
						'3' => array(
							'name' => 'San Miguel - Port Sutton',
							'distance' => '0.5 miles',
						),
						'4' => array(
							'name' => 'Ford-Mesa View',
							'distance' => '0.4 miles',
						),
					),
					'ft_nearby_edu' => array(
						'1' => array(
							'name' => 'Vista Verde Elementary School',
							'distance' => '0.3 miles',
						),
						'2' => array(
							'name' => 'Montessori Schools of Irvine',
							'distance' => '0.8 miles',
						),
						'3' => array(
							'name' => 'University of california Irvine',
							'distance' => '0.9 miles',
						),
					),
					'ft_property_images' => '4',
					'ft_attachments' => '2',
					'ft_add_in_slider' => 'no',
				),
			),
			'property_7' => array(
				'name'       => _x( '272-s-rexford-dr-beverly-hills-ca-90212-usa', 'Page slug', 'casaroyal' ),
				'title'      => _x( '272 S Rexford Dr, Beverly Hills, CA 90212, USA', 'Page title', 'casaroyal' ),
				'parent'     => '',
				'status'     => 'For Sale',
				'type'       => 'House',
				'city'       => 'Beverly Hills',
				'feature'    => array(
					'2 Stories',
					'Central Heating',
					'Dual Sinks',
					'Electric Range',
					'Fire Place',
					'Laundry Room',
					'Lawn',
					'Marble Floors',
					'Swimming Pool',
				),
				'meta'       => array(
					'_sold' => 0,
					'_sold_date' => 0,
					'_promoted' => 0,
					'ft_featured' => 1,
					'_paid_ft_featured' => 0,
					'casaroyal_property_description' => '<p>Lorem ipsum dolor sit amet, consectetuer adipiscing elit, sed diam nonummy nibh euismod tincidunt ut laoreet dolore magna aliquam erat volutpat. Ut wisi enim ad minim veniam, quis nostrud exerci tation ullamcorper suscipit lobortis nisl ut aliquip ex ea commodo consequat. Duis autem vel eum iriure dolor in hendrerit in vulputate velit esse molestie consequat, vel illum dolore eu feugiat nulla facilisis at vero eros et accumsan et iusto odio dignissim qui blandit praesent luptatum zzril delenit augue duis dolore te feugait nulla facilisi.</p><p>Nam liber tempor cum soluta nobis eleifend option congue nihil imperdiet doming id quod mazim placerat facer possim assum. Typi non habent claritatem insitam; est usus legentis in iis qui facit eorum claritatem. Investigationes demonstraverunt lectores legere me lius quod ii legunt saepius. Claritas est etiam processus dynamicus, qui sequitur mutationem consuetudium lectorum. Mirum est notare quam littera gothica, quam nunc putamus parum claram, anteposuerit litterarum formas humanitatis per seacula quarta decima et quinta decima. Eodem modo typi, qui nunc nobis videntur parum clari, fiant sollemnes in futurum.</p>', 
					'ft_property_sku' => 'GTHJ34667549RT',
					'ft_property_price' => '225000',
					'ft_property_currency' => '$',
					'ft_property_size' => '2400',
					'ft_property_price_prefix' => '',
					'ft_property_price_postfix' => '',
					'ft_property_size_postfix' => 'Sq Ft',
					'ft_property_bedrooms' => '3',
					'ft_property_bathrooms' => '3',
					'ft_property_garage' => '2',
					'casaroyal_property_map' => 0,
					'ft_property_address' => '272 S Rexford Dr, Beverly Hills, CA 90212, USA',
					'casaroyal_property_latitude' => '34.06245772828618',
					'casaroyal_property_longitude' => '-118.39366150629883',
					'ft_property_location' => '34.06245772828618,-118.39366150629883',
					'ft_property_address_city' => 'Beverly Hills',
					'ft_property_address_zip' => '90212',
					'ft_property_address_state' => 'CA',
					'ft_property_address_country' => 'United States',
					'ft_agent_display_option' => 'agent_info',
					'ft_agents' => 'agent_id_2',
					'ft_tour_video_url' => '<iframe width="930" height="525" src="https://www.youtube.com/embed/zvL0UmvPSEA" frameborder="0" allowfullscreen></iframe>',
					'casaroyal_additional_details' => array( 
						'Year Built' => '2012',
						'No. of Parking Spaces' => '30',
						'AC' => 'Ceiling Fan(s), Central',
					),
					'ft_virtual_tour_url' => '<iframe width="930" height="525" src="https://my.matterport.com/show/?m=JGPnGQ6hosj&play=1&qs=1" frameborder="0" allowfullscreen></iframe>',
					'ft_nearby_health' => array(
						'1' => array( 
							'name' => 'Plastic Surgery Center of Beverly Hills',
							'distance' => '2.3 miles',
						),
						'2' => array(
							'name' => 'Khalili Center - Weight Loss Surgery',
							'distance' => '1.2 miles',
						),
						'3' => array(
							'name' => 'Pink Lotus Breast Center',
							'distance' => '1.5 miles',
						),
						'4' => array(
							'name' => 'Cedars Sinai',
							'distance' => '1.9 miles',
						),
					),
					'ft_nearby_transport' => array(
						'1' => array(
						 	'name' => 'La Cienega / Olympic',
						 	'distance' => '0.8 miles',
						),
						'2' => array(
							'name' => 'Centurion Black Jets',
							'distance' => '1.1 miles',
						),
						'3' => array(
							'name' => 'Olympic / La Jolla',
							'distance' => '1.4 miles',
						),
					),
					'ft_nearby_edu' => array(
						'1' => array(
							'name' => 'Beverly Vista School',
							'distance' => '0.3 miles',
						),
						'2' => array(
							'name' => 'Horace Mann School',
							'distance' => '0.7 miles',
						),
						'3' => array(
							'name' => 'Star Makers International',
							'distance' => '1.4 miles',
						),
					),
					'ft_property_images' => '4',
					'ft_attachments' => '2',
					'ft_add_in_slider' => 'yes',
				),
			),
			'property_8' => array(
				'name'       => _x( '8191-sunnyslope-rd-laguna-beach-ca-92651-usa', 'Page slug', 'casaroyal' ),
				'title'      => _x( '8191 Sunnyslope Rd, Laguna Beach, CA 92651, USA', 'Page title', 'casaroyal' ),
				'parent'     => '',
				'status'     => 'For Sale',
				'type'       => 'Summer House',
				'city'       => 'Los Angeles',
				'feature'    => array(
					'2 Stories',
					'Central Heating',
					'Dual Sinks',
					'Electric Range',
					'Fire Place',
					'Laundry Room',
					'Lawn',
					'Marble Floors',
					'Swimming Pool',
				),
				'meta'       => array(
					'_sold' => 1,
					'_sold_date' => '1509616635',
					'_promoted' => 0,
					'ft_featured' => 0,
					'_paid_ft_featured' => 0,
					'casaroyal_property_description' => '<p>Lorem ipsum dolor sit amet, consectetuer adipiscing elit, sed diam nonummy nibh euismod tincidunt ut laoreet dolore magna aliquam erat volutpat. Ut wisi enim ad minim veniam, quis nostrud exerci tation ullamcorper suscipit lobortis nisl ut aliquip ex ea commodo consequat. Duis autem vel eum iriure dolor in hendrerit in vulputate velit esse molestie consequat, vel illum dolore eu feugiat nulla facilisis at vero eros et accumsan et iusto odio dignissim qui blandit praesent luptatum zzril delenit augue duis dolore te feugait nulla facilisi.</p><p>Nam liber tempor cum soluta nobis eleifend option congue nihil imperdiet doming id quod mazim placerat facer possim assum. Typi non habent claritatem insitam; est usus legentis in iis qui facit eorum claritatem. Investigationes demonstraverunt lectores legere me lius quod ii legunt saepius. Claritas est etiam processus dynamicus, qui sequitur mutationem consuetudium lectorum. Mirum est notare quam littera gothica, quam nunc putamus parum claram, anteposuerit litterarum formas humanitatis per seacula quarta decima et quinta decima. Eodem modo typi, qui nunc nobis videntur parum clari, fiant sollemnes in futurum.</p>', 
					'ft_property_sku' => 'RTGFSC989',
					'ft_property_price' => '120000',
					'ft_property_currency' => '$',
					'ft_property_size' => '1300',
					'ft_property_price_prefix' => '',
					'ft_property_price_postfix' => '',
					'ft_property_size_postfix' => 'Sq Ft',
					'ft_property_bedrooms' => '3',
					'ft_property_bathrooms' => '2',
					'ft_property_garage' => '2',
					'casaroyal_property_map' => 0,
					'ft_property_address' => '8191 Sunnyslope Rd, Laguna Beach, CA 92651, USA',
					'casaroyal_property_latitude' => '34.06245772828618',
					'casaroyal_property_longitude' => '-118.39366150629883',
					'ft_property_location' => '34.06245772828618,-118.39366150629883',
					'ft_property_address_city' => 'Laguna Beach',
					'ft_property_address_neighborhood' => 'Sunnyslope Road',
					'ft_property_address_zip' => '92651',
					'ft_property_address_state' => 'CA',
					'ft_property_address_country' => 'United States',
					'ft_agent_display_option' => 'agent_info',
					'ft_agents' => 'agent_id_2',
					'ft_tour_video_url' => '<iframe width="930" height="525" src="https://www.youtube.com/embed/zvL0UmvPSEA" frameborder="0" allowfullscreen></iframe>',
					'casaroyal_additional_details' => array( 
						'Year Built' => '2012',
						'No. of Parking Spaces' => '30',
						'AC' => 'Ceiling Fan(s), Central',
						'Acres' => '0.24',
						'MLS Listing ID' => '123456789',
						'Appliances' => 'Dishwasher, Freestanding Gas Range, Garbage Disposal, Microwave',
						'Bathroom Description' => 'Stall Shower',
						'Bedroom Features' => 'Main Floor Master Bedroom',
						'Parking Type' => 'Garage - Attached',
					),
					'ft_virtual_tour_url' => '<iframe width="930" height="525" src="https://my.matterport.com/show/?m=JGPnGQ6hosj&play=1&qs=1" frameborder="0" allowfullscreen></iframe>',
					'ft_nearby_health' => array(
						'1' => array( 
							'name' => 'The Wheeler Group',
							'distance' => '2.3 miles',
						),
					),
					'ft_nearby_transport' => array(
						'1' => array(
						 	'name' => 'Coast-Ent Emerald Bay',
						 	'distance' => '0.8 miles',
						),
						'2' => array(
							'name' => 'Coast-Ent Irvine Cove',
							'distance' => '1.4 miles',
						),
						'3' => array(
							'name' => 'Boat Canyon / PCH',
							'distance' => '1.9 miles',
						),
					),
					'ft_nearby_edu' => array(
						'1' => array(
							'name' => 'Glider Point',
							'distance' => '0.3 miles',
						),
						'2' => array(
							'name' => 'New School of Structural Integration',
							'distance' => '0.7 miles',
						),
					),
					'ft_property_images' => '4',
					'ft_attachments' => '2',
					'ft_add_in_slider' => 'no',
				),
			),
			'property_8' => array(
				'name'       => _x( 'retail-store-1020-18th-st-santa-monica', 'Page slug', 'casaroyal' ),
				'title'      => _x( 'Retail Store – 1020 18th St, Santa Monica', 'Page title', 'casaroyal' ),
				'parent'     => '',
				'status'     => 'For Rent',
				'type'       => 'Shop',
				'city'       => 'Santa Monica',
				'feature'    => array(
					'2 Stories',
					'Central Heating',
					'Dual Sinks',
					'Electric Range',
					'Fire Place',
					'Laundry Room',
					'Lawn',
					'Marble Floors',
					'Swimming Pool',
				),
				'meta'       => array(
					'_sold' => 1,
					'_sold_date' => '1509616635',
					'_promoted' => 0,
					'ft_featured' => 0,
					'_paid_ft_featured' => 0,
					'casaroyal_property_description' => '<p>Lorem ipsum dolor sit amet, consectetuer adipiscing elit, sed diam nonummy nibh euismod tincidunt ut laoreet dolore magna aliquam erat volutpat. Ut wisi enim ad minim veniam, quis nostrud exerci tation ullamcorper suscipit lobortis nisl ut aliquip ex ea commodo consequat. Duis autem vel eum iriure dolor in hendrerit in vulputate velit esse molestie consequat, vel illum dolore eu feugiat nulla facilisis at vero eros et accumsan et iusto odio dignissim qui blandit praesent luptatum zzril delenit augue duis dolore te feugait nulla facilisi.</p><p>Nam liber tempor cum soluta nobis eleifend option congue nihil imperdiet doming id quod mazim placerat facer possim assum. Typi non habent claritatem insitam; est usus legentis in iis qui facit eorum claritatem. Investigationes demonstraverunt lectores legere me lius quod ii legunt saepius. Claritas est etiam processus dynamicus, qui sequitur mutationem consuetudium lectorum. Mirum est notare quam littera gothica, quam nunc putamus parum claram, anteposuerit litterarum formas humanitatis per seacula quarta decima et quinta decima. Eodem modo typi, qui nunc nobis videntur parum clari, fiant sollemnes in futurum.</p>', 
					'ft_property_sku' => 'GFST7689',
					'ft_property_price' => '2500',
					'ft_property_currency' => '$',
					'ft_property_size' => '2200',
					'ft_property_price_prefix' => '',
					'ft_property_price_postfix' => '',
					'ft_property_size_postfix' => 'Sq Ft',
					'ft_property_bedrooms' => '3',
					'ft_property_bathrooms' => '2',
					'ft_property_garage' => '2',
					'casaroyal_property_map' => 0,
					'ft_property_address' => 'Boone Canyon Rd, Somis, CA 93066, USA',
					'casaroyal_property_latitude' => '34.305585525283846',
					'casaroyal_property_longitude' => '-119.02646077890626',
					'ft_property_location' => '34.305585525283846,-119.02646077890626',
					'ft_property_address_city' => 'Santa Monica',
					'ft_property_address_zip' => '90403',
					'ft_property_address_state' => 'CA',
					'ft_property_address_country' => 'United States',
					'ft_agent_display_option' => 'agent_info',
					'ft_agents' => 'agent_id_2',
					'ft_tour_video_url' => '<iframe width="930" height="525" src="https://www.youtube.com/embed/zvL0UmvPSEA" frameborder="0" allowfullscreen></iframe>',
					'casaroyal_additional_details' => array( 
						'Year Built' => '2012',
						'No. of Parking Spaces' => '30',
						'AC' => 'Ceiling Fan(s), Central',
						'Acres' => '0.24',
						'MLS Listing ID' => '123456789',
						'Appliances' => 'Dishwasher, Freestanding Gas Range, Garbage Disposal, Microwave',
						'Bathroom Description' => 'Stall Shower',
						'Bedroom Features' => 'Main Floor Master Bedroom',
						'Parking Type' => 'Garage - Attached',
					),
					'ft_virtual_tour_url' => '<iframe width="930" height="525" src="https://my.matterport.com/show/?m=JGPnGQ6hosj&play=1&qs=1" frameborder="0" allowfullscreen></iframe>',
					'ft_property_images' => '4',
					'ft_attachments' => '2',
					'ft_add_in_slider' => 'no',
				),
			),
		) );

		foreach ( $properties as $key => $property ) {
			self::casaroyal_create_demo_property( esc_sql( $property['name'] ), $property['title'], $property['parent'], $property['status'], $property['type'], $property['city'], $property['feature'], $property['meta'] );
		}

	}

	public static function casaroyal_create_demo_agent( $agent_num = '', $slug, $page_title = '', $content = '', $meta = ''  ) {
		global $wpdb;

		$post_data = array(
			'post_status'    => 'publish',
			'post_type'      => 'agent',
			'post_content'   => $content,
			'post_author'    => 1,
			'post_name'      => $slug,
			'post_title'     => $page_title,
			'comment_status' => 'closed',
		);
		$post_id = wp_insert_post( $post_data );

		if( !empty($meta) ) {

			foreach( $meta as $key => $meta_item ) {

				update_post_meta( $post_id, $key, $meta_item );

			}

		}

		$attachment_id = get_option( 'agents_avatar_'.$agent_num );
		set_post_thumbnail( $post_id, $attachment_id );

		$cover_id = get_option( 'properties_images_'.$agent_num );
		add_post_meta( $post_id, 'ft_agent_cover', $cover_id );

		$agent_url = get_permalink( $post_id );
		update_option( 'agent_page_url', $agent_url );

		return $post_id;

	}

	/**
	 * Create properties that the plugin relies on, storing property IDs in variables.
	 */
	public static function create_demo_agents() { 

		$agents = apply_filters( 'casaroyal_create_demo_agents', array(
			'agent_1' => array(
				'agent_num'  => '1',
				'name'       => _x( 'john-doe', 'Page slug', 'casaroyal' ),
				'title'      => _x( 'John Doe', 'Page title', 'casaroyal' ),
				'content'    => '<p>Lorem ipsum dolor sit amet, consectetuer adipiscing elit, sed diam nonummy nibh euismod tincidunt ut laoreet dolore magna aliquam erat volutpat. Ut wisi enim ad minim veniam, quis nostrud exerci tation ullamcorper suscipit lobortis nisl ut aliquip ex ea commodo consequat. Duis autem vel eum iriure dolor in hendrerit in vulputate velit esse molestie consequat, vel illum dolore eu feugiat nulla facilisis at vero eros et accumsan et iusto odio dignissim qui blandit praesent luptatum zzril delenit augue duis dolore te feugait nulla facilisi.</p><p>Nam liber tempor cum soluta nobis eleifend option congue nihil imperdiet doming id quod mazim placerat facer possim assum. Typi non habent claritatem insitam; est usus legentis in iis qui facit eorum claritatem. Investigationes demonstraverunt lectores legere me lius quod ii legunt saepius. Claritas est etiam processus dynamicus, qui sequitur mutationem consuetudium lectorum. Mirum est notare quam littera gothica, quam nunc putamus parum claram, anteposuerit litterarum formas humanitatis per seacula quarta decima et quinta decima. Eodem modo typi, qui nunc nobis videntur parum clari, fiant sollemnes in futurum.</p>',
				'meta'       => array(
					'ft_agent_position' => 'Buying Agent',
					'ft_agent_email' => 'agent@email.com',
					'ft_mobile_number' => '123 456 7890',
					'ft_office_number' => '123 456 7901',
					'ft_fax_number' => '123 456 0987',
					'ft_facebook_url' => '#',
					'ft_twitter_url' => '#',
					'casaroyal_google_plus_url' => '#',
					'ft_linked_in_url' => '#',
				),
			),
			'agent_2' => array(
				'agent_num'  => '2',
				'name'       => _x( 'lionel-richie', 'Page slug', 'casaroyal' ),
				'title'      => _x( 'Lionel Richie', 'Page title', 'casaroyal' ),
				'content'    => '<p>Lorem ipsum dolor sit amet, consectetuer adipiscing elit, sed diam nonummy nibh euismod tincidunt ut laoreet dolore magna aliquam erat volutpat. Ut wisi enim ad minim veniam, quis nostrud exerci tation ullamcorper suscipit lobortis nisl ut aliquip ex ea commodo consequat. Duis autem vel eum iriure dolor in hendrerit in vulputate velit esse molestie consequat, vel illum dolore eu feugiat nulla facilisis at vero eros et accumsan et iusto odio dignissim qui blandit praesent luptatum zzril delenit augue duis dolore te feugait nulla facilisi.</p><p>Nam liber tempor cum soluta nobis eleifend option congue nihil imperdiet doming id quod mazim placerat facer possim assum. Typi non habent claritatem insitam; est usus legentis in iis qui facit eorum claritatem. Investigationes demonstraverunt lectores legere me lius quod ii legunt saepius. Claritas est etiam processus dynamicus, qui sequitur mutationem consuetudium lectorum. Mirum est notare quam littera gothica, quam nunc putamus parum claram, anteposuerit litterarum formas humanitatis per seacula quarta decima et quinta decima. Eodem modo typi, qui nunc nobis videntur parum clari, fiant sollemnes in futurum.</p>',
				'meta'       => array(
					'ft_agent_position' => 'Selling Agent',
					'ft_agent_email' => 'agent@email.com',
					'ft_mobile_number' => '123 456 7890',
					'ft_office_number' => '123 456 7901',
					'ft_fax_number' => '123 456 0987',
					'ft_facebook_url' => '#',
					'ft_twitter_url' => '#',
					'casaroyal_google_plus_url' => '#',
					'ft_linked_in_url' => '#',
				),
			),
			'agent_3' => array(
				'agent_num'  => '3',
				'name'       => _x( 'brianne-smith', 'Page slug', 'casaroyal' ),
				'title'      => _x( 'Brianne Smith', 'Page title', 'casaroyal' ),
				'content'    => '<p>Lorem ipsum dolor sit amet, consectetuer adipiscing elit, sed diam nonummy nibh euismod tincidunt ut laoreet dolore magna aliquam erat volutpat. Ut wisi enim ad minim veniam, quis nostrud exerci tation ullamcorper suscipit lobortis nisl ut aliquip ex ea commodo consequat. Duis autem vel eum iriure dolor in hendrerit in vulputate velit esse molestie consequat, vel illum dolore eu feugiat nulla facilisis at vero eros et accumsan et iusto odio dignissim qui blandit praesent luptatum zzril delenit augue duis dolore te feugait nulla facilisi.</p><p>Nam liber tempor cum soluta nobis eleifend option congue nihil imperdiet doming id quod mazim placerat facer possim assum. Typi non habent claritatem insitam; est usus legentis in iis qui facit eorum claritatem. Investigationes demonstraverunt lectores legere me lius quod ii legunt saepius. Claritas est etiam processus dynamicus, qui sequitur mutationem consuetudium lectorum. Mirum est notare quam littera gothica, quam nunc putamus parum claram, anteposuerit litterarum formas humanitatis per seacula quarta decima et quinta decima. Eodem modo typi, qui nunc nobis videntur parum clari, fiant sollemnes in futurum.</p>',
				'meta'       => array(
					'ft_agent_position' => 'Selling Agent',
					'ft_agent_email' => 'agent@email.com',
					'ft_mobile_number' => '123 456 7890',
					'ft_office_number' => '123 456 7901',
					'ft_fax_number' => '123 456 0987',
					'ft_facebook_url' => '#',
					'ft_twitter_url' => '#',
					'casaroyal_google_plus_url' => '#',
					'ft_linked_in_url' => '#',
				),
			),
			'agent_4' => array(
				'agent_num'  => '4',
				'name'       => _x( 'rachel-dawes', 'Page slug', 'casaroyal' ),
				'title'      => _x( 'Rachel Dawes', 'Page title', 'casaroyal' ),
				'content'    => '<p>Lorem ipsum dolor sit amet, consectetuer adipiscing elit, sed diam nonummy nibh euismod tincidunt ut laoreet dolore magna aliquam erat volutpat. Ut wisi enim ad minim veniam, quis nostrud exerci tation ullamcorper suscipit lobortis nisl ut aliquip ex ea commodo consequat. Duis autem vel eum iriure dolor in hendrerit in vulputate velit esse molestie consequat, vel illum dolore eu feugiat nulla facilisis at vero eros et accumsan et iusto odio dignissim qui blandit praesent luptatum zzril delenit augue duis dolore te feugait nulla facilisi.</p><p>Nam liber tempor cum soluta nobis eleifend option congue nihil imperdiet doming id quod mazim placerat facer possim assum. Typi non habent claritatem insitam; est usus legentis in iis qui facit eorum claritatem. Investigationes demonstraverunt lectores legere me lius quod ii legunt saepius. Claritas est etiam processus dynamicus, qui sequitur mutationem consuetudium lectorum. Mirum est notare quam littera gothica, quam nunc putamus parum claram, anteposuerit litterarum formas humanitatis per seacula quarta decima et quinta decima. Eodem modo typi, qui nunc nobis videntur parum clari, fiant sollemnes in futurum.</p>',
				'meta'       => array(
					'ft_agent_position' => 'Real Estate Broker',
					'ft_agent_email' => 'agent@email.com',
					'ft_mobile_number' => '123 456 7890',
					'ft_office_number' => '123 456 7901',
					'ft_fax_number' => '123 456 0987',
					'ft_facebook_url' => '#',
					'ft_twitter_url' => '#',
					'casaroyal_google_plus_url' => '#',
					'ft_linked_in_url' => '#',
				),
			),
		) );

		foreach ( $agents as $key => $agent ) {
			self::casaroyal_create_demo_agent( $agent['agent_num'], esc_sql( $agent['name'] ), $agent['title'], $agent['content'], $agent['meta'] );
		}

	}

	public static function casaroyal_create_demo_testimonial( $testimonial_num = '', $slug, $page_title = '', $content = '', $ft_testimonial_position = ''  ) {
		global $wpdb;

		$post_data = array(
			'post_status'    => 'publish',
			'post_type'      => 'testimonial',
			'post_content'   => $content,
			'post_author'    => 1,
			'post_name'      => $slug,
			'post_title'     => $page_title,
			'comment_status' => 'closed',
		);
		$post_id = wp_insert_post( $post_data );

		if( !empty($ft_testimonial_position) ) {

			update_post_meta( $post_id, 'ft_testimonial_position', $ft_testimonial_position );

		}

		$attachment_id = get_option( 'agents_avatar_'.$testimonial_num );
		set_post_thumbnail( $post_id, $attachment_id );

		return $post_id;

	}

	/**
	 * Create properties that the plugin relies on, storing property IDs in variables.
	 */
	public static function create_demo_testimonials() { 

		$agents = apply_filters( 'casaroyal_create_demo_testimonials', array(
			'testimonial_1' => array(
				'testimonial_num'  => '1',
				'name'       => _x( 'alan-poe', 'Page slug', 'casaroyal' ),
				'title'      => _x( 'Alan Poe', 'Page title', 'casaroyal' ),
				'content'    => 'Lorem ipsum dolor sit amet, consectetur adipiscing elit. Aliquam eleifend nunc sem, sit amet luctus tellus tempus tempor. Interdum et malesuada fames ac ante ipsum primis in faucibus.',
				'ft_testimonial_position' => 'San Francisco',
			),
			'testimonial_2' => array(
				'testimonial_num'  => '2',
				'name'       => _x( 'chris-derosa', 'Page slug', 'casaroyal' ),
				'title'      => _x( 'Chris DeRosa', 'Page title', 'casaroyal' ),
				'content'    => 'Lorem ipsum dolor sit amet, consectetur adipiscing elit. Aliquam eleifend nunc sem, sit amet luctus tellus tempus tempor. Interdum et malesuada fames ac ante ipsum primis in faucibus.',
				'ft_testimonial_position' => 'Los Angeles',
			),
			'testimonial_3' => array(
				'testimonial_num'  => '3',
				'name'       => _x( 'helen-mcdonald', 'Page slug', 'casaroyal' ),
				'title'      => _x( 'Helen McDonald', 'Page title', 'casaroyal' ),
				'content'    => 'Lorem ipsum dolor sit amet, consectetur adipiscing elit. Aliquam eleifend nunc sem, sit amet luctus tellus tempus tempor. Interdum et malesuada fames ac ante ipsum primis in faucibus.',
				'ft_testimonial_position' => 'New York',
			),
		) );

		foreach ( $agents as $key => $agent ) {
			self::casaroyal_create_demo_testimonial( $agent['testimonial_num'], esc_sql( $agent['name'] ), $agent['title'], $agent['content'], $agent['ft_testimonial_position'] );
		}

	}

	public static function casaroyal_create_demo_post( $post_num = '', $slug, $page_title = '', $content = '' ) {
		global $wpdb;

		$post_data = array(
			'post_status'    => 'publish',
			'post_type'      => 'post',
			'post_content'   => $content,
			'post_author'    => 1,
			'post_name'      => $slug,
			'post_title'     => $page_title,
		);
		$post_id = wp_insert_post( $post_data );

		$attachment_id = get_option( 'properties_images_'.$post_num );
		set_post_thumbnail( $post_id, $attachment_id );

		return $post_id;

	}

	/**
	 * Create properties that the plugin relies on, storing property IDs in variables.
	 */
	public static function create_demo_posts() { 

		$posts = apply_filters( 'casaroyal_create_demo_posts', array(
			'post_1' => array(
				'post_num'  => '1',
				'name'       => _x( 'buying-a-home', 'Page slug', 'casaroyal' ),
				'title'      => _x( 'Buying a Home', 'Page title', 'casaroyal' ),
				'content'    => 'Eam tum adesse, cum dolor omnis absit; Et quidem iure fortasse, sed tamen non gravissimum est testimonium multitudinis. Callipho ad virtutem nihil adiunxit nisi voluptatem, Diodorus vacuitatem doloris. <mark>Sint modo partes vitae beatae.</mark> Iam in altera philosophiae parte. Apud ceteros autem philosophos, qui quaesivit aliquid, tacet; Conferam tecum, quam cuique verso rem subicias; Ita enim vivunt quidam, ut eorum vita refellatur oratio. Ergo adhuc, quantum equidem intellego, causa non videtur fuisse mutandi nominis.
<blockquote cite="http://loripsum.net/">Si vero id etiam explanare velles apertiusque diceres nihil eum fecisse nisi voluptatis causa, quo modo eum tandem laturum fuisse existimas?</blockquote>
Nummus in Croesi divitiis obscuratur, pars est tamen divitiarum. Tum mihi Piso: Quid ergo? Ita fit cum gravior, tum etiam splendidior oratio. Fortitudinis quaedam praecepta sunt ac paene leges, quae effeminari virum vetant in dolore.',
			),
			'post_2' => array(
				'post_num'  => '2',
				'name'       => _x( 'pros-and-cons-on-a-countryside-house', 'Page slug', 'casaroyal' ),
				'title'      => _x( 'Pros and cons on a countryside house', 'Page title', 'casaroyal' ),
				'content'    => 'Eam tum adesse, cum dolor omnis absit; Et quidem iure fortasse, sed tamen non gravissimum est testimonium multitudinis. Callipho ad virtutem nihil adiunxit nisi voluptatem, Diodorus vacuitatem doloris. <mark>Sint modo partes vitae beatae.</mark> Iam in altera philosophiae parte. Apud ceteros autem philosophos, qui quaesivit aliquid, tacet; Conferam tecum, quam cuique verso rem subicias; Ita enim vivunt quidam, ut eorum vita refellatur oratio. Ergo adhuc, quantum equidem intellego, causa non videtur fuisse mutandi nominis.
<blockquote cite="http://loripsum.net/">Si vero id etiam explanare velles apertiusque diceres nihil eum fecisse nisi voluptatis causa, quo modo eum tandem laturum fuisse existimas?</blockquote>
Nummus in Croesi divitiis obscuratur, pars est tamen divitiarum. Tum mihi Piso: Quid ergo? Ita fit cum gravior, tum etiam splendidior oratio. Fortitudinis quaedam praecepta sunt ac paene leges, quae effeminari virum vetant in dolore.',
			)
		) );

		foreach ( $posts as $key => $post ) {
			self::casaroyal_create_demo_post( $post['post_num'], esc_sql( $post['name'] ), $post['title'], $post['content'] );
		}

	}

	public static function casaroyal_create_demo_contact_form( $slug, $page_title = '', $content = '' ) {
		global $wpdb;

		$post_data = array(
			'post_status'    => 'publish',
			'post_type'      => 'wpcf7_contact_form',
			'post_content'   => $content,
			'post_author'    => 1,
			'post_name'      => $slug,
			'post_title'     => $page_title,
		);
		$post_id = wp_insert_post( $post_data );

		update_post_meta( $post_id, '_form', $content );

		add_option('contact_form_7_id', $post_id);

		return $post_id;

	}

	/**
	 * Create properties that the plugin relies on, storing property IDs in variables.
	 */
	public static function create_demo_contact_forms() { 

		$posts = apply_filters( 'casaroyal_create_demo_contact_forms', array(
			'post_1' => array(
				'name'       => _x( 'Ccntact-corm-book-a-viewing', 'Page slug', 'casaroyal' ),
				'title'      => _x( 'Contact form - Book A Viewing', 'Page title', 'casaroyal' ),
				'content'    => '<div class="row">

<div class="col-sm-6">
    [text* your-name placeholder "Name*"]
</div>

<div class="col-sm-6">
    [tel* PhoneNumber placeholder "Phone*"]
</div>

<div class="col-sm-12">
    [email* your-email placeholder "Email*"]
</div>

<div class="col-sm-12">
    [textarea your-message placeholder "Your Message"]
</div>

<div class="col-sm-12">[submit "Send Message"]</div>

</div>',
			),
		) );

		foreach ( $posts as $key => $post ) {
			self::casaroyal_create_demo_contact_form( esc_sql( $post['name'] ), $post['title'], $post['content'] );
		}

	}

	/**
	 * Create properties that the plugin relies on, storing property IDs in variables.
	 */
	public static function create_demo_properties_images() {

		$files_images = array(
            'image_1' => array(
                'url'  => casaroyal_PLUGIN_URL . '/setup-wizard/assets/images/property-1.jpg',
            ),
            'image_2' => array(
                'url'  => casaroyal_PLUGIN_URL . '/setup-wizard/assets/images/property-2.jpg',
            ),
            'image_3' => array(
                'url'  => casaroyal_PLUGIN_URL . '/setup-wizard/assets/images/property-3.jpg',
            ),
            'image_4' => array(
                'url'  => casaroyal_PLUGIN_URL . '/setup-wizard/assets/images/property-4.jpg',
            ),
        );

        $current = 0;

        foreach ( $files_images as $key => $file_o ) {
        	$current++;
            $parent_post_id = 0;
            $file = $file_o['url'];
            $filename = basename($file);
            $upload_file = wp_upload_bits($filename, null, file_get_contents($file));
            if (!$upload_file['error']) {
                $wp_filetype = wp_check_filetype($filename, null );
                $attachment = array(
                    'post_mime_type' => $wp_filetype['type'],
                    'post_parent' => $parent_post_id,
                    'post_title' => preg_replace('/\.[^.]+$/', '', $filename),
                    'post_content' => '',
                    'post_status' => 'inherit'
                );
                $attachment_id = wp_insert_attachment( $attachment, $upload_file['file'], $parent_post_id );
                if (!is_wp_error($attachment_id)) {
                    require_once(ABSPATH . "wp-admin" . '/includes/image.php');
                    $attachment_data = wp_generate_attachment_metadata( $attachment_id, $upload_file['file'] );
                    wp_update_attachment_metadata( $attachment_id,  $attachment_data );
                    update_option( 'properties_images_'.$current, $attachment_id );
                }
            }
        }

        $file_testimonials = array(
            'image_1' => array(
                'url'  => casaroyal_PLUGIN_URL . '/setup-wizard/assets/images/testimonials-bg.jpg',
            )
        );

        foreach ( $file_testimonials as $key => $file_o ) {
        	$current++;
            $parent_post_id = 0;
            $file = $file_o['url'];
            $filename = basename($file);
            $upload_file = wp_upload_bits($filename, null, file_get_contents($file));
            if (!$upload_file['error']) {
                $wp_filetype = wp_check_filetype($filename, null );
                $attachment = array(
                    'post_mime_type' => $wp_filetype['type'],
                    'post_parent' => $parent_post_id,
                    'post_title' => preg_replace('/\.[^.]+$/', '', $filename),
                    'post_content' => '',
                    'post_status' => 'inherit'
                );
                $attachment_id = wp_insert_attachment( $attachment, $upload_file['file'], $parent_post_id );
                if (!is_wp_error($attachment_id)) {
                    require_once(ABSPATH . "wp-admin" . '/includes/image.php');
                    $attachment_data = wp_generate_attachment_metadata( $attachment_id, $upload_file['file'] );
                    wp_update_attachment_metadata( $attachment_id,  $attachment_data );
                    $image_url = wp_get_attachment_url( $attachment_id );
	                update_option( 'testimonial_bg_id', $attachment_id );
	                update_option( 'testimonial_bg_url', $image_url );
                }
            }
	    }

        $options = array(
			'taxonomies' => array(
				'category' => 'on',
				'post_tag' => 'on',
				'property-type' => 'on',
				'property-city' => 'on'
			)
		);
		update_option( 'category-icon', $options);

        //
        $files_taxonomy = array(
            'image_1' => array(
                'url'  => casaroyal_PLUGIN_URL . '/setup-wizard/assets/images/commercial.png',
                'name' => 'Commercial',
            ),
            'image_2' => array(
                'url'  => casaroyal_PLUGIN_URL . '/setup-wizard/assets/images/commercial.png',
                'name' => 'Office',
            ),
            'image_3' => array(
                'url'  => casaroyal_PLUGIN_URL . '/setup-wizard/assets/images/shop.png',
                'name' => 'Shop',
            ),
            'image_4' => array(
                'url'  => casaroyal_PLUGIN_URL . '/setup-wizard/assets/images/building.png',
                'name' => 'Apartment',
            ),
            'image_5' => array(
                'url'  => casaroyal_PLUGIN_URL . '/setup-wizard/assets/images/building.png',
                'name' => 'Residential Tower',
            ),
            'image_6' => array(
                'url'  => casaroyal_PLUGIN_URL . '/setup-wizard/assets/images/condo.png',
                'name' => 'condo',
            ),
            'image_7' => array(
                'url'  => casaroyal_PLUGIN_URL . '/setup-wizard/assets/images/house.png',
                'name' => 'Residential',
            ),
            'image_8' => array(
                'url'  => casaroyal_PLUGIN_URL . '/setup-wizard/assets/images/house.png',
                'name' => 'House',
            ),
            'image_9' => array(
                'url'  => casaroyal_PLUGIN_URL . '/setup-wizard/assets/images/summer.png',
                'name' => 'Summer House',
            ),
        );

        foreach ( $files_taxonomy as $key => $file_o ) {
            $parent_post_id = 0;
            $file = $file_o['url'];
            $filename = basename($file);
            $upload_file = wp_upload_bits($filename, null, file_get_contents($file));
            if (!$upload_file['error']) {
                $wp_filetype = wp_check_filetype($filename, null );
                $attachment = array(
                    'post_mime_type' => $wp_filetype['type'],
                    'post_parent' => $parent_post_id,
                    'post_title' => preg_replace('/\.[^.]+$/', '', $filename),
                    'post_content' => '',
                    'post_status' => 'inherit'
                );
                $attachment_id = wp_insert_attachment( $attachment, $upload_file['file'], $parent_post_id );
                if (!is_wp_error($attachment_id)) {
                    require_once(ABSPATH . "wp-admin" . '/includes/image.php');
                    $attachment_data = wp_generate_attachment_metadata( $attachment_id, $upload_file['file'] );
                    wp_update_attachment_metadata( $attachment_id,  $attachment_data );

                    $term = get_term_by('name', $file_o['name'], 'property-type');
                    update_term_meta( $term->term_id, 'pix_term_icon', $attachment_id );

                    if( $file_o['name'] == "House" ) {
	                	update_option('house-map-pin', $attachment_id);
	                }

                }
            }
        }
        //
        
	}

	/**
	 * Create properties that the plugin relies on, storing property IDs in variables.
	 */
	public static function create_demo_attachments() {

		$files_images = array(
            'image_1' => array(
                'url'  => casaroyal_PLUGIN_URL . '/setup-wizard/assets/images/attachment-1.pdf',
            ),
            'image_2' => array(
                'url'  => casaroyal_PLUGIN_URL . '/setup-wizard/assets/images/attachment-1.pdf',
            ),
            'image_3' => array(
                'url'  => casaroyal_PLUGIN_URL . '/setup-wizard/assets/images/attachment-1.pdf',
            ),
        );

        $current = 0;

        foreach ( $files_images as $key => $file_o ) {
        	$current++;
            $parent_post_id = 0;
            $file = $file_o['url'];
            $filename = basename($file);
            $upload_file = wp_upload_bits($filename, null, file_get_contents($file));
            if (!$upload_file['error']) {
                $wp_filetype = wp_check_filetype($filename, null );
                $attachment = array(
                    'post_mime_type' => $wp_filetype['type'],
                    'post_parent' => $parent_post_id,
                    'post_title' => preg_replace('/\.[^.]+$/', '', $filename),
                    'post_content' => '',
                    'post_status' => 'inherit'
                );
                $attachment_id = wp_insert_attachment( $attachment, $upload_file['file'], $parent_post_id );
                if (!is_wp_error($attachment_id)) {
                    require_once(ABSPATH . "wp-admin" . '/includes/image.php');
                    $attachment_data = wp_generate_attachment_metadata( $attachment_id, $upload_file['file'] );
                    wp_update_attachment_metadata( $attachment_id,  $attachment_data );
                    update_option( 'properties_attachments_'.$current, $attachment_id );
                }
            }
        }
	}

	/**
	 * Create properties that the plugin relies on, storing property IDs in variables.
	 */
	public static function create_demo_agents_images() {

		$files_images = array(
            'image_1' => array(
                'url'  => casaroyal_PLUGIN_URL . '/setup-wizard/assets/images/agent-1.jpg',
            ),
            'image_2' => array(
                'url'  => casaroyal_PLUGIN_URL . '/setup-wizard/assets/images/agent-2.jpg',
            ),
            'image_3' => array(
                'url'  => casaroyal_PLUGIN_URL . '/setup-wizard/assets/images/agent-3.jpg',
            ),
            'image_4' => array(
                'url'  => casaroyal_PLUGIN_URL . '/setup-wizard/assets/images/agent-4.jpg',
            ),
        );

        $current = 0;

        foreach ( $files_images as $key => $file_o ) {
        	$current++;
            $parent_post_id = 0;
            $file = $file_o['url'];
            $filename = basename($file);
            $upload_file = wp_upload_bits($filename, null, file_get_contents($file));
            if (!$upload_file['error']) {
                $wp_filetype = wp_check_filetype($filename, null );
                $attachment = array(
                    'post_mime_type' => $wp_filetype['type'],
                    'post_parent' => $parent_post_id,
                    'post_title' => preg_replace('/\.[^.]+$/', '', $filename),
                    'post_content' => '',
                    'post_status' => 'inherit'
                );
                $attachment_id = wp_insert_attachment( $attachment, $upload_file['file'], $parent_post_id );
                if (!is_wp_error($attachment_id)) {
                    require_once(ABSPATH . "wp-admin" . '/includes/image.php');
                    $attachment_data = wp_generate_attachment_metadata( $attachment_id, $upload_file['file'] );
                    wp_update_attachment_metadata( $attachment_id,  $attachment_data );
                    update_option( 'agents_avatar_'.$current, $attachment_id );
                }
            }
        }
	}
}

/*
|--------------------------------------------------------------------------
| Post views function
|--------------------------------------------------------------------------
*/

// function to display number of posts.
function casaroyal_getPostViews($postID){
    $count_key = 'post_views_count';
    $count = get_post_meta($postID, $count_key, true);
    if($count==''){
        delete_post_meta($postID, $count_key);
        add_post_meta($postID, $count_key, '0');
        return "0";
    }
    return $count.'';
}

// function to count views.
function casaroyal_setPostViews($postID) {
    $count_key = 'post_views_count';
    $count = get_post_meta($postID, $count_key, true);
    if($count==''){
        $count = 0;
        delete_post_meta($postID, $count_key);
        add_post_meta($postID, $count_key, '0');
    }else{
        $count++;
        update_post_meta($postID, $count_key, $count);
    }
}

// function to set post visited by specific user ( new when added in filter ).
function casaroyal_setPostVisited($postID) {

	if ( is_user_logged_in() ) {

		$user_id = get_current_user_id();

		if( !empty($user_id) ) {
			$filter_user_id = get_post_meta($postID, 'filter_user_'.$user_id, true);
			if( !empty($filter_user_id) ) {
				update_post_meta($postID, 'filter_user_'.$user_id, 'old');
			}
		}

	}

}

function casaroyal_upload_dir( $pathdata ) {

	$dir = untrailingslashit( apply_filters( 'casaroyal_upload_dir', 'casaroyal-uploads/' ) );

	if ( empty( $pathdata['subdir'] ) ) {
		$pathdata['path']   = $pathdata['path'] . '/' . $dir;
		$pathdata['url']    = $pathdata['url'] . '/' . $dir;
		$pathdata['subdir'] = '/' . $dir;
	} else {
		$new_subdir         = '/' . $dir . $pathdata['subdir'];
		$pathdata['path']   = str_replace( $pathdata['subdir'], $new_subdir, $pathdata['path'] );
		$pathdata['url']    = str_replace( $pathdata['subdir'], $new_subdir, $pathdata['url'] );
		$pathdata['subdir'] = $new_subdir;
	}

	return $pathdata;
}

// Upload file and show in Media Library
function upload_user_file( $file = array(), $title = false ) {

	add_filter( 'upload_dir', 'casaroyal_upload_dir' );

	require_once ABSPATH . 'wp-admin/includes/admin.php';

	$classyads_upload = true;
	$classyads_uploading_file = $file;

	$file_return = wp_handle_upload($file, array('test_form' => false));

	if(isset($file_return['error']) || isset($file_return['upload_error_handler'])){

		return false;

	} else {

		$filename = $file_return['file'];

		$attachment = array(
			'post_mime_type' => $file_return['type'],
			'post_content' => '',
			'post_type' => 'attachment',
			'post_status' => 'inherit',
			'guid' => $file_return['url']
		);

		if($title){
			$attachment['post_title'] = $title;
		}

		$attachment_id = wp_insert_attachment( $attachment, $filename );

		require_once(ABSPATH . 'wp-admin/includes/image.php');
		
		$attachment_data = wp_generate_attachment_metadata( $attachment_id, $filename );

		wp_update_attachment_metadata( $attachment_id, $attachment_data );

		if( 0 < intval( $attachment_id ) ) {
			return $attachment_id;
		}
	}

	remove_filter( 'upload_dir', 'casaroyal_upload_dir' );

	return false;
}

function casaroyal_custom_submit_image_gallery() {

	ob_start();

	$response['html'] = '';
	$response['image_url'] = '';

	//
	$attachment_id = "0";
	if ( !empty($_FILES['file']) ) {
		$file = $_FILES['file'];
		if( is_array($file) ){
			$attachment_id = upload_user_file( $file, false );
		}
	}
	//

	$response['image_id'] = $attachment_id;
	$response['image_url'] = wp_get_attachment_url( $attachment_id );
	//$response['image_url'] = $attachment_id->url;
	$response['html'] = ob_get_clean();

	echo json_encode($response);

	exit;

}
add_action( 'wp_ajax_casaroyal_custom_submit_image_gallery', 'casaroyal_custom_submit_image_gallery' );
add_action( 'wp_ajax_nopriv_casaroyal_custom_submit_image_gallery', 'casaroyal_custom_submit_image_gallery' );

/**
 * Like get_template_part() put lets you pass args to the template file
 * Args are available in the template as $template_args array
 * @param string filepart
 * @param mixed wp_args style argument list
 */
function casaroyal_get_template_part( $file, $template_args = array(), $cache_args = array() ) {
	$template_args = wp_parse_args( $template_args );
	$cache_args = wp_parse_args( $cache_args );
	if ( $cache_args ) {
		foreach ( $template_args as $key => $value ) {
			if ( is_scalar( $value ) || is_array( $value ) ) {
				$cache_args[$key] = $value;
			} else if ( is_object( $value ) && method_exists( $value, 'get_id' ) ) {
				$cache_args[$key] = call_user_method( 'get_id', $value );
			}
		}
		if ( ( $cache = wp_cache_get( $file, serialize( $cache_args ) ) ) !== false ) {
			if ( ! empty( $template_args['return'] ) )
				return $cache;
			echo $cache;
			return;
		}
	}
	$file_handle = $file;
	do_action( 'start_operation', 'hm_template_part::' . $file_handle );
	if ( file_exists( get_stylesheet_directory() . '/' . $file . '.php' ) )
		$file = get_stylesheet_directory() . '/' . $file . '.php';
	elseif ( file_exists( get_template_directory() . '/' . $file . '.php' ) )
		$file = get_template_directory() . '/' . $file . '.php';
	ob_start();
	$return = require( $file );
	$data = ob_get_clean();
	do_action( 'end_operation', 'hm_template_part::' . $file_handle );
	if ( $cache_args ) {
		wp_cache_set( $file, $data, serialize( $cache_args ), 3600 );
	}
	if ( ! empty( $template_args['return'] ) )
		if ( $return === false )
			return false;
		else
			return $data;
	echo $data;
}

if ( ! function_exists( 'custom_taxonomy_page_url' ) ) {
	/**
	 * Current Page URL
	 *
	 * @return string
	 */
	function custom_taxonomy_page_url() {
		$pageURL = 'http';
		if ( isset( $_SERVER[ "HTTPS" ] ) && $_SERVER[ "HTTPS" ] == "on" ) {
			$pageURL .= "s";
		}

		$pageURL .= "://";
		if ( $_SERVER[ "SERVER_PORT" ] != "80" ) {
			$pageURL .= $_SERVER[ "SERVER_NAME" ] . ":" . $_SERVER[ "SERVER_PORT" ] . $_SERVER[ "REQUEST_URI" ];
		} else {
			$pageURL .= $_SERVER[ "SERVER_NAME" ] . $_SERVER[ "REQUEST_URI" ];
		}

		if ( $_SERVER[ 'QUERY_STRING' ] ) {
			$pos = strpos( $pageURL, 'view' );
			if ( $pos ) {
				$pageURL = substr( $pageURL, 0, $pos - 1 );
			}
		}

		return $pageURL;
	}
}

if ( ! function_exists( 'casaroyal_approve_pending_review' ) ) {
	/**
	 * Current Page URL
	 *
	 * @return string
	 */
	function casaroyal_approve_pending_review( $property_id ) {

		// Sene email to user to notify about approve
		if (strtoupper(substr(PHP_OS,0,3)=='WIN')) {
			$eol="\r\n";
		} elseif (strtoupper(substr(PHP_OS,0,3)=='MAC')) {
			$eol="\r";
		} else {
			$eol="\n";
		}

		//
		$site_name = get_bloginfo('name');
		$post_author_id = get_post_field( 'post_author', $property_id );
		$author_email = get_the_author_meta( 'user_email', $post_author_id );
		$from = get_option('admin_email');
	  	$subject = esc_html__('Message from ', 'casaroyal').$site_name;
	  	$headers = "From: " . $from . $eol;
		$headers .= "Reply-To: " . $from . $eol;
		$headers .= "MIME-Version: 1.0".$eol;
		$headers .= "Content-Type: text/html; charset=ISO-8859-1".$eol;

		$email_content = esc_html__( 'Congratulations! Your property submission has beed approved.', 'casaroyal' );

	  	add_filter('wp_mail_content_type', create_function('', 'return "text/html";'));
	  	$mail_sent = wp_mail( $author_email, $subject, $email_content, $headers );

	}

}

if ( ! function_exists( 'casaroyal_reject_pending_review' ) ) {
	/**
	 * Current Page URL
	 *
	 * @return string
	 */
	function casaroyal_reject_pending_review( $property_id ) {

		// Sene email to user to notify about approve
		if (strtoupper(substr(PHP_OS,0,3)=='WIN')) {
			$eol="\r\n";
		} elseif (strtoupper(substr(PHP_OS,0,3)=='MAC')) {
			$eol="\r";
		} else {
			$eol="\n";
		}

		//
		$site_name = get_bloginfo('name');
		$post_author_id = get_post_field( 'post_author', $property_id );
		$author_email = get_the_author_meta( 'user_email', $post_author_id );
		$from = get_option('admin_email');
	  	$subject = esc_html__('Message from ', 'casaroyal').$site_name;
	  	$headers = "From: " . $from . $eol;
		$headers .= "Reply-To: " . $from . $eol;
		$headers .= "MIME-Version: 1.0".$eol;
		$headers .= "Content-Type: text/html; charset=ISO-8859-1".$eol;

		$email_content = esc_html__( 'Your property submission has beed rejected.', 'casaroyal' );

	  	add_filter('wp_mail_content_type', create_function('', 'return "text/html";'));
	  	$mail_sent = wp_mail( $author_email, $subject, $email_content, $headers );

	}

}


/*
|--------------------------------------------------------------------------
| Register Form
|--------------------------------------------------------------------------
*/
function casaroyal_register_widget() {

	$response['status'] = '';
	$response['error_user'] = '';
	$response['error_email'] = '';
	$response['error_default'] = '';

  	$username = sanitize_text_field($_POST['casaroyal_user_login']);
  	$email = sanitize_email($_POST['casaroyal_user_email']);
  	$password = $_POST['casaroyal_user_pass'];


  	if ( username_exists($username) ) {

	  	$response['status'] = 'error';
		$response['error_user'] = '<span class="error-title">Error:</span> Username exists. Please try another one.';

  	} 

  	if( email_exists( $email )) {

	  	$response['status'] = 'error';
		$response['error_email'] = '<span class="error-title">Error:</span> Email exists. Please try another one.';

  	} 

  	$user_ID = wp_create_user( $username, $password, $email );

  	$login_data = array();
  	$login_data['user_login'] = $username;
  	$login_data['user_password'] = $password;
  	$user = wp_signon( $login_data, false );

  	if ( ! is_wp_error( $user ) ) {

		$response['status'] = 'success';

		$from = get_option('admin_email');
	  	$headers = 'From: '.$from . "\r\n";
	  	$subject = "Registration successful";
	  	$msg = "Registration successful.\nYour login details\nUsername: $username\nPassword: $password";
	  	wp_mail( $email, $subject, $msg, $headers );

	}

	ob_start();

	?>

	<div class="col-md-12">

		<?php 

			$user_id = get_current_user_id(); $user_info = get_userdata( $user_id ); 

			$MODS = get_theme_mods();
			foreach(casaroyal_defaults() as $mod=>$def) {if(!isset($MODS[$mod])){$MODS[$mod]=$def;}}

			$privacy_policy_text = "";
			if(strlen($MODS['privacy_policy_text']) > 0) {

				$privacy_policy_text = $MODS['privacy_policy_text'];

			}

		?>

		<p><?php esc_html_e('You are currently signed in as', 'casaroyal' ); ?> <strong><?php echo esc_attr($user_info->user_login); ?></strong>. <a id="casaroyal-signout" href="#"><?php esc_html_e('Sign Out', 'casaroyal' ); ?></a></p>
		
		<?php if(!empty($privacy_policy_text)) { ?>
		<div class="custom-checkbox pull-left">
          	<label>
            	<input type="checkbox" class="property_submit_agree" name="property_submit_agree">
            	<?php echo wp_kses(($privacy_policy_text), true); ?>
          	</label>
        </div>
    	<?php } ?>

	</div>

	<div class="col-md-12">

		<a id="casaroyal_submit_property_loggedout" href="#" class="btn btn-default disabled"><?php esc_html_e( 'Submit Property', 'casaroyal' ) ?></a>

	</div>

	<?php

	$response['html'] = ob_get_clean();

  	echo json_encode($response);

	exit;

}
add_action( 'wp_ajax_casaroyal_register_widget', 'casaroyal_register_widget' );
add_action( 'wp_ajax_nopriv_casaroyal_register_widget', 'casaroyal_register_widget' );